@@ -2,7 +2,7 @@
     This file is part of Akregator.
 
     Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-                  2005 Frank Osterfeld <frank.osterfeld at kdemail.net>
+                  2005 Frank Osterfeld <osterfeld@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,73 +22,67 @@
     with any edition of Qt, and distribute the resulting executable,
     without including the source code for Qt in the source distribution.
 */
-#include <dcopclient.h>
+
+#include "aboutdata.h"
+#include "actionmanagerimpl.h"
+#include "akregatorconfig.h"
+#include "akregator_part.h"
+#include "article.h"
+#include "fetchqueue.h"
+#include "feediconmanager.h"
+#include "framemanager.h"
+#include "kernel.h"
+#include "mainwidget.h"
+#include "notificationmanager.h"
+#include "plugin.h"
+#include "pluginmanager.h"
+#include "storage.h"
+#include "storagefactory.h"
+#include "storagefactoryregistry.h"
+#include "trayicon.h"
+#include "dummystorage/storagefactorydummyimpl.h"
+
+#include <knotifyconfigwidget.h>
 #include <kaboutdata.h>
-#include <kaction.h>
-#include <kactionclasses.h>
-#include <kactioncollection.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kconfigdialog.h>
 #include <kfiledialog.h>
 #include <kglobalsettings.h>
-#include <khtmldefaults.h>
-#include <kinstance.h>
-#include <kmainwindow.h>
 #include <kmessagebox.h>
-#include <knotifyclient.h>
-#include <knotifydialog.h>
-#include <kpopupmenu.h>
-#include <kservice.h>
 #include <kstandarddirs.h>
-#include <kstdaction.h>
-#include <ktempfile.h>
-#include <ktrader.h>
+#include <ktemporaryfile.h>
+#include <kservice.h>
+#include <kxmlguifactory.h>
 #include <kio/netaccess.h>
-#include <kparts/browserinterface.h>
-#include <kparts/genericfactory.h>
-#include <kparts/partmanager.h>
+#include <KParts/GenericFactory>
+#include <KParts/Plugin>
+#include <KCMultiDialog>
 
-#include <qfile.h>
-#include <qobjectlist.h>
-#include <qstringlist.h>
-#include <qtimer.h>
-#include <qwidgetlist.h>
-#include <private/qucomextra_p.h>
-
-#include "aboutdata.h"
-#include "actionmanagerimpl.h"
-#include "akregator_part.h"
-#include "akregator_view.h"
-#include "akregatorconfig.h"
-#include "articlefilter.h"
-#include "articleinterceptor.h"
-#include "configdialog.h"
-#include "fetchqueue.h"
-#include "frame.h"
-#include "article.h"
-#include "kernel.h"
-#include "notificationmanager.h"
-#include "pageviewer.h"
-#include "plugin.h"
-#include "pluginmanager.h"
-#include "storage.h"
-#include "storagefactory.h"
-#include "storagefactorydummyimpl.h"
-#include "storagefactoryregistry.h"
-#include "speechclient.h"
-#include "trayicon.h"
-#include "tagset.h"
-#include "tag.h"
+#include <QFile>
+#include <QObject>
+#include <QStringList>
+#include <QTextStream>
+#include <QTimer>
+#include <QWidget>
+#include <QDomDocument>
+#include "partadaptor.h"
 
 namespace Akregator {
 
-typedef KParts::GenericFactory<Part> AkregatorFactory;
-K_EXPORT_COMPONENT_FACTORY( libakregatorpart, AkregatorFactory )
+static const KAboutData &createAboutData()
+{
+  static Akregator::AboutData about;
+  return about;
+}
+
+K_PLUGIN_FACTORY(AkregatorFactory, registerPlugin<Part>();)
+K_EXPORT_PLUGIN(AkregatorFactory(createAboutData()))
 
 BrowserExtension::BrowserExtension(Part *p, const char *name)
-	    : KParts::BrowserExtension( p, name )
+	    : KParts::BrowserExtension( p)
 {
+    setObjectName(name);
     m_part=p;
 }
 
@@ -97,86 +91,64 @@ void BrowserExtension::saveSettings()
     m_part->saveSettings();
 }
 
-class Part::ApplyFiltersInterceptor : public ArticleInterceptor
-{
-    public:
-    virtual void processArticle(Article& article)
-    {
-        Filters::ArticleFilterList list = Kernel::self()->articleFilterList();
-        for (Filters::ArticleFilterList::ConstIterator it = list.begin(); it != list.end(); ++it)
-            (*it).applyTo(article);
-    }
-};
-
-Part::Part( QWidget *parentWidget, const char * /*widgetName*/,
-                              QObject *parent, const char *name, const QStringList& )
-    : DCOPObject("AkregatorIface")
-       , MyBasePart(parent, name)
+Part::Part( QWidget *parentWidget, QObject *parent, const QVariantList& )
+    : MyBasePart(parent)
        , m_standardListLoaded(false)
        , m_shuttingDown(false)
        , m_mergedPart(0)
        , m_backedUpList(false)
-       , m_view(0)
+       , m_mainWidget(0)
        , m_storage(0)
-       
-{
-    // we need an instance
-    setInstance( AkregatorFactory::instance() );
+       , m_dialog(0)
 
-    // start knotifyclient if not already started. makes it work for people who doesn't use full kde, according to kmail devels
-    KNotifyClient::startDaemon();
+{
+    setPluginLoadingMode( LoadPluginsIfEnabled );
+    setPluginInterfaceVersion( AKREGATOR_PLUGIN_INTERFACE_VERSION );
+
+    setComponentData( AkregatorFactory::componentData() );
+
+    new PartAdaptor( this );
+    QDBusConnection::sessionBus().registerObject("/Akregator", this);
+
+    FeedIconManager::self(); // FIXME: registering the icon manager dbus iface here,
+                               // because otherwise we get a deadlock later
 
     m_standardFeedList = KGlobal::dirs()->saveLocation("data", "akregator/data") + "/feeds.opml";
 
-    m_tagSetPath = KGlobal::dirs()->saveLocation("data", "akregator/data") + "/tagset.xml";
-
     Backend::StorageFactoryDummyImpl* dummyFactory = new Backend::StorageFactoryDummyImpl();
     Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key());
-    loadPlugins(); // FIXME: also unload them!
+    loadStoragePlugins(); // FIXME: also unload them!
 
     m_storage = 0;
-    Backend::StorageFactory* factory = Backend::StorageFactoryRegistry::self()->getFactory(Settings::archiveBackend());
-    if (factory != 0)
-        m_storage = factory->createStorage(QStringList());
+    Backend::StorageFactory* storageFactory = Backend::StorageFactoryRegistry::self()->getFactory(Settings::archiveBackend());
+    if (storageFactory != 0)
+        m_storage = storageFactory->createStorage(QStringList());
 
     if (!m_storage) // Houston, we have a problem
     {
         m_storage = Backend::StorageFactoryRegistry::self()->getFactory("dummy")->createStorage(QStringList());
 
-        KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").arg(Settings::archiveBackend()), i18n("Plugin error") );
+        KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.", Settings::archiveBackend()), i18n("Plugin error") );
     }
 
-    Filters::ArticleFilterList list;
-    list.readConfig(Settings::self()->config());
-    Kernel::self()->setArticleFilterList(list);
-
-    m_applyFiltersInterceptor = new ApplyFiltersInterceptor();
-    ArticleInterceptorManager::self()->addInterceptor(m_applyFiltersInterceptor);
-
     m_storage->open(true);
     Kernel::self()->setStorage(m_storage);
-    Backend::Storage::setInstance(m_storage); // TODO: kill this one
-
-    loadTagSet(m_tagSetPath);
 
     m_actionManager = new ActionManagerImpl(this);
     ActionManager::setInstance(m_actionManager);
 
-    m_view = new Akregator::View(this, parentWidget, m_actionManager, "akregator_view");
-    m_actionManager->initView(m_view);
-    m_actionManager->setTagSet(Kernel::self()->tagSet());
-
+    m_mainWidget = new Akregator::MainWidget(this, parentWidget, m_actionManager, "akregator_view");
     m_extension = new BrowserExtension(this, "ak_extension");
 
-    connect(m_view, SIGNAL(setWindowCaption(const QString&)), this, SIGNAL(setWindowCaption(const QString&)));
-    connect(m_view, SIGNAL(setStatusBarText(const QString&)), this, SIGNAL(setStatusBarText(const QString&)));
-    connect(m_view, SIGNAL(setProgress(int)), m_extension, SIGNAL(loadingProgress(int)));
-    connect(m_view, SIGNAL(signalCanceled(const QString&)), this, SIGNAL(canceled(const QString&)));
-    connect(m_view, SIGNAL(signalStarted(KIO::Job*)), this, SIGNAL(started(KIO::Job*)));
-    connect(m_view, SIGNAL(signalCompleted()), this, SIGNAL(completed()));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalCaptionChanged(const QString&)), this, SIGNAL(setWindowCaption(const QString&)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalStatusText(const QString&)), this, SIGNAL(setStatusBarText(const QString&)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalLoadingProgress(int)), m_extension, SIGNAL(loadingProgress(int)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalCanceled(const QString&)), this, SIGNAL(canceled(const QString&)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalStarted()), this, SLOT(slotStarted()));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalCompleted()), this, SIGNAL(completed()));
 
     // notify the part that this is our internal widget
-    setWidget(m_view);
+    setWidget(m_mainWidget);
 
     TrayIcon* trayIcon = new TrayIcon( getMainWindow() );
     TrayIcon::setInstance(trayIcon);
@@ -187,17 +159,20 @@ Part::Part( QWidget *parentWidget, const char * /*widgetName*/,
     if ( isTrayIconEnabled() )
     {
         trayIcon->show();
-        NotificationManager::self()->setWidget(trayIcon, instance());
+#ifdef __GNUC__
+#warning this needs a way to get the position of the systray
+#endif
+        NotificationManager::self()->setWidget(0, componentData());
     }
     else
-        NotificationManager::self()->setWidget(getMainWindow(), instance());
+        NotificationManager::self()->setWidget(getMainWindow(), componentData());
 
     connect( trayIcon, SIGNAL(quitSelected()),
             kapp, SLOT(quit())) ;
 
-    connect( m_view, SIGNAL(signalUnreadCountChanged(int)), trayIcon, SLOT(slotSetUnread(int)) );
+    connect( m_mainWidget, SIGNAL(signalUnreadCountChanged(int)), trayIcon, SLOT(slotSetUnread(int)) );
 
-    connect(kapp, SIGNAL(shutDown()), this, SLOT(slotOnShutdown()));
+    connect(kapp, SIGNAL(aboutToQuit()), this, SLOT(slotOnShutdown()));
 
     m_autosaveTimer = new QTimer(this);
     connect(m_autosaveTimer, SIGNAL(timeout()), this, SLOT(slotSaveFeedList()));
@@ -207,31 +182,40 @@ Part::Part( QWidget *parentWidget, const char * /*widgetName*/,
 
     initFonts();
 
-    RSS::FileRetriever::setUserAgent(QString("Akregator/%1; librss/remnants").arg(AKREGATOR_VERSION));
+    QString useragent = QString( "Akregator/%1; syndication" ).arg( AKREGATOR_VERSION );
+
+    if( !Settings::customUserAgent().isEmpty() )
+        useragent = Settings::customUserAgent();
+
+    Syndication::FileRetriever::setUserAgent( useragent );
 }
 
-void Part::loadPlugins()
+void Part::loadStoragePlugins()
 {
-    // "[X-KDE-akregator-plugintype] == 'storage'"
-    KTrader::OfferList offers = PluginManager::query();
-
-    for( KTrader::OfferList::ConstIterator it = offers.begin(), end = offers.end(); it != end; ++it )
+    KService::List offers = PluginManager::query( "[X-KDE-akregator-plugintype] == 'storage'" );
+    for ( KService::List::ConstIterator it = offers.begin(), end = offers.end(); it != end; ++it )
     {
         Akregator::Plugin* plugin = PluginManager::createFromService(*it);
         if (plugin)
-            plugin->init();
+            plugin->initialize();
     }
 }
 
+void Part::slotStarted()
+{
+    emit started(0L);
+}
+
 void Part::slotOnShutdown()
 {
     m_shuttingDown = true;
     m_autosaveTimer->stop();
     saveSettings();
     slotSaveFeedList();
-    saveTagSet(m_tagSetPath);
-    m_view->slotOnShutdown();
-    //delete m_view;
+    m_mainWidget->slotOnShutdown();
+    //delete m_mainWidget;
+    delete TrayIcon::getInstance();
+    TrayIcon::setInstance(0L);
     delete m_storage;
     m_storage = 0;
     //delete m_actionManager;
@@ -239,9 +223,13 @@ void Part::slotOnShutdown()
 
 void Part::slotSettingsChanged()
 {
-    NotificationManager::self()->setWidget(isTrayIconEnabled() ? TrayIcon::getInstance() : getMainWindow(), instance());
+#ifdef __GNUC__
+#warning Tray icons are no longer widgets
+#endif
+//    NotificationManager::self()->setWidget(isTrayIconEnabled() ? TrayIcon::getInstance() : getMainWindow(), instance());
+    NotificationManager::self()->setWidget( getMainWindow(), componentData());
 
-    RSS::FileRetriever::setUseCache(Settings::useHTMLCache());
+    Syndication::FileRetriever::setUseCache(Settings::useHTMLCache());
 
     QStringList fonts;
     fonts.append(Settings::standardFont());
@@ -256,52 +244,49 @@ void Part::slotSettingsChanged()
     if (Settings::minimumFontSize() > Settings::mediumFontSize())
         Settings::setMediumFontSize(Settings::minimumFontSize());
     saveSettings();
-    m_view->slotSettingsChanged();
     emit signalSettingsChanged();
 }
 void Part::saveSettings()
 {
-    Kernel::self()->articleFilterList().writeConfig(Settings::self()->config());
-    m_view->saveSettings();
+    m_mainWidget->saveSettings();
 }
 
 Part::~Part()
 {
-    kdDebug() << "Part::~Part() enter" << endl;
+    kDebug() <<"Part::~Part() enter";
     if (!m_shuttingDown)
         slotOnShutdown();
-    kdDebug() << "Part::~Part(): leaving" << endl;
-    ArticleInterceptorManager::self()->removeInterceptor(m_applyFiltersInterceptor);
-    delete m_applyFiltersInterceptor;
+    delete m_dialog;
+    kDebug() <<"Part::~Part(): leaving";
 }
 
-void Part::readProperties(KConfig* config)
+void Part::readProperties(const KConfigGroup & config)
 {
     m_backedUpList = false;
     openStandardFeedList();
 
-    if(m_view)
-        m_view->readProperties(config);
+    if(m_mainWidget)
+        m_mainWidget->readProperties(config);
 }
 
-void Part::saveProperties(KConfig* config)
+void Part::saveProperties(KConfigGroup & config)
 {
-    if (m_view)
+    if (m_mainWidget)
     {
         slotSaveFeedList();
-        m_view->saveProperties(config);
+        m_mainWidget->saveProperties(config);
     }
 }
 
-bool Part::openURL(const KURL& url)
+bool Part::openUrl(const KUrl& url)
 {
-    m_file = url.path();
+    setLocalFilePath(url.path());
     return openFile();
 }
 
 void Part::openStandardFeedList()
 {
-    if ( !m_standardFeedList.isEmpty() && openURL(m_standardFeedList) )
+    if ( !m_standardFeedList.isEmpty() && openUrl(KUrl::fromPath(m_standardFeedList)) )
         m_standardListLoaded = true;
 }
 
@@ -368,60 +353,65 @@ bool Part::openFile()
 
     QString str;
     // m_file is always local so we can use QFile on it
-    QFile file(m_file);
+    QFile file(localFilePath());
 
     bool fileExists = file.exists();
     QString listBackup = m_storage->restoreFeedList();
-     
+
     QDomDocument doc;
 
     if (!fileExists)
     {
         doc = createDefaultFeedList();
     }
-    else 
+    else
     {
-        if (file.open(IO_ReadOnly))
+        if (file.open(QIODevice::ReadOnly))
         {
             // Read OPML feeds list and build QDom tree.
             QTextStream stream(&file);
-            stream.setEncoding(QTextStream::UnicodeUTF8); // FIXME not all opmls are in utf8
-            str = stream.read();
+            stream.setCodec("UTF-8"); // FIXME not all opmls are in utf8
+            str = stream.readAll();
             file.close();
         }
 
         if (!doc.setContent(str))
         {
 
-            QString backup = m_file + "-backup." +  QString::number(QDateTime::currentDateTime().toTime_t());
+            QString backup = localFilePath()
+                + QLatin1String("-backup.")
+                + QString::number(QDateTime::currentDateTime().toTime_t());
 
             copyFile(backup);
 
-            KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("XML Parsing Error") );
+            KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%1</b></p></qt>", backup), i18n("XML Parsing Error") );
 
             if (!doc.setContent(listBackup))
                 doc = createDefaultFeedList();
         }
     }
 
-    if (!m_view->loadFeeds(doc))
+    if (!m_mainWidget->loadFeeds(doc))
     {
-        QString backup = m_file + "-backup." +  QString::number(QDateTime::currentDateTime().toTime_t());
+        QString backup = localFilePath()
+            + QLatin1String("-backup.")
+            + QString::number(QDateTime::currentDateTime().toTime_t());
+
         copyFile(backup);
 
-        KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("OPML Parsing Error") );
+        KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%1</b></p></qt>", backup), i18n("OPML Parsing Error") );
 
-        m_view->loadFeeds(createDefaultFeedList());
+        m_mainWidget->loadFeeds(createDefaultFeedList());
     }
 
-    emit setStatusBarText(QString::null);
-    
+    emit setStatusBarText(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
+
 
     if( Settings::markAllFeedsReadOnStartup() )
-        m_view->slotMarkAllFeedsRead();
+        m_mainWidget->slotMarkAllFeedsRead();
 
     if (Settings::fetchOnStartup())
-            m_view->slotFetchAllFeeds();
+            m_mainWidget->slotFetchAllFeeds();
 
     return true;
 }
@@ -435,26 +425,26 @@ void Part::slotSaveFeedList()
     // the first time we overwrite the feed list, we create a backup
     if (!m_backedUpList)
     {
-        QString backup = m_file + "~";
+        QString backup = localFilePath() + QLatin1String("~");
 
         if (copyFile(backup))
             m_backedUpList = true;
     }
 
-    QString xmlStr = m_view->feedListToOPML().toString();
+    QString xmlStr = m_mainWidget->feedListToOPML().toString();
     m_storage->storeFeedList(xmlStr);
 
-    QFile file(m_file);
-    if (file.open(IO_WriteOnly) == false)
+    QFile file(localFilePath());
+    if (file.open(QIODevice::WriteOnly) == false)
     {
         //FIXME: allow to save the feedlist into different location -tpr 20041118
-        KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").arg(m_file), i18n("Write error") );
+        KMessageBox::error(m_mainWidget, i18n("Access denied: cannot save feed list (%1)", localFilePath()), i18n("Write error") );
         return;
     }
 
     // use QTextStream to dump the text to the file
     QTextStream stream(&file);
-    stream.setEncoding(QTextStream::UnicodeUTF8);
+    stream.setCodec("UTF-8");
 
     // Write OPML data file.
     // Archive data files are saved elsewhere.
@@ -475,7 +465,7 @@ bool Part::mergePart(KParts::Part* part)
     {
         if (!factory())
         {
-            kdDebug() << "Akregator::Part::mergePart(): factory() returns NULL" << endl;
+            kDebug() <<"Akregator::Part::mergePart(): factory() returns NULL";
             return false;
         }
         if (m_mergedPart)
@@ -490,76 +480,28 @@ bool Part::mergePart(KParts::Part* part)
 
 QWidget* Part::getMainWindow()
 {
-        // this is a dirty fix to get the main window used for the tray icon
+    // this is a dirty fix to get the main window used for the tray icon
+    QWidgetList l = QApplication::topLevelWidgets();
+    QWidget* wid = 0L;
 
-        QWidgetList *l = kapp->topLevelWidgets();
-        QWidgetListIt it( *l );
-        QWidget *wid;
-
-        // check if there is an akregator main window
-        while ( (wid = it.current()) != 0 )
-        {
-        ++it;
-        //kdDebug() << "win name: " << wid->name() << endl;
-        if (QString(wid->name()) == "akregator_mainwindow")
+    // check if there is an akregator main window
+    foreach (wid, QApplication::topLevelWidgets())
+    {
+        if (wid->objectName() == "akregator_mainwindow")
             return wid;
-        }
-        // if not, check for kontact main window
-        QWidgetListIt it2( *l );
-        while ( (wid = it2.current()) != 0 )
-        {
-            ++it2;
-            if (QString(wid->name()).startsWith("kontact-mainwindow"))
-                return wid;
-        }
+    }
+
+    // if not, check if there is an kontact main window
+    foreach (wid, QApplication::topLevelWidgets())
+    {
+        if (wid->objectName().startsWith("kontact-mainwindow"))
+            return wid;
+    }
+
     return 0;
 }
 
-void Part::loadTagSet(const QString& path)
-{
-    QDomDocument doc;
-
-    QFile file(path);
-    if (file.open(IO_ReadOnly))
-    {
-        doc.setContent(file.readAll());
-        file.close();
-    }
-    // if we can't load the tagset from the xml file, check for the backup in the backend
-    if (doc.isNull())
-    {
-        doc.setContent(m_storage->restoreTagSet());
-    }
-
-    if (!doc.isNull())
-    {
-        Kernel::self()->tagSet()->readFromXML(doc);
-    }
-    else
-    {
-        Kernel::self()->tagSet()->insert(Tag("http://akregator.sf.net/tags/Interesting", i18n("Interesting")));
-    }
-}
-
-void Part::saveTagSet(const QString& path)
-{
-    QString xmlStr = Kernel::self()->tagSet()->toXML().toString();
-
-    m_storage->storeTagSet(xmlStr);
-    
-    QFile file(path);
-    
-    if ( file.open(IO_WriteOnly) )
-    {
-
-        QTextStream stream(&file);
-        stream.setEncoding(QTextStream::UnicodeUTF8);
-        stream << xmlStr << "\n";
-        file.close();
-    }
-}
-
-void Part::importFile(const KURL& url)
+void Part::importFile(const KUrl& url)
 {
     QString filename;
 
@@ -571,75 +513,75 @@ void Part::importFile(const KURL& url)
     {
         isRemote = true;
 
-        if (!KIO::NetAccess::download(url, filename, m_view) )
+        if (!KIO::NetAccess::download(url, filename, m_mainWidget) )
         {
-            KMessageBox::error(m_view, KIO::NetAccess::lastErrorString() );
+            KMessageBox::error(m_mainWidget, KIO::NetAccess::lastErrorString() );
             return;
         }
     }
 
     QFile file(filename);
-    if (file.open(IO_ReadOnly))
+    if (file.open(QIODevice::ReadOnly))
     {
         // Read OPML feeds list and build QDom tree.
         QDomDocument doc;
         if (doc.setContent(file.readAll()))
-            m_view->importFeeds(doc);
+            m_mainWidget->importFeeds(doc);
         else
-            KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").arg(filename), i18n("OPML Parsing Error") );
+            KMessageBox::error(m_mainWidget, i18n("Could not import the file %1 (no valid OPML)", filename), i18n("OPML Parsing Error") );
     }
     else
-        KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").arg(filename), i18n("Read Error"));
+        KMessageBox::error(m_mainWidget, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.", filename), i18n("Read Error"));
 
     if (isRemote)
         KIO::NetAccess::removeTempFile(filename);
 }
 
-void Part::exportFile(const KURL& url)
+void Part::exportFile(const KUrl& url)
 {
     if (url.isLocalFile())
     {
         QFile file(url.path());
 
         if ( file.exists() &&
-                KMessageBox::questionYesNo(m_view,
-            i18n("The file %1 already exists; do you want to overwrite it?").arg(file.name()),
+                KMessageBox::questionYesNo(m_mainWidget,
+            i18n("The file %1 already exists; do you want to overwrite it?", file.fileName()),
             i18n("Export"),
-            i18n("Overwrite"),
-            KStdGuiItem::cancel()) == KMessageBox::No )
+            KGuiItem(i18n("Overwrite")),
+            KStandardGuiItem::cancel()) == KMessageBox::No )
             return;
 
-        if ( !file.open(IO_WriteOnly) )
+        if ( !file.open(QIODevice::WriteOnly) )
         {
-            KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").arg(file.name()), i18n("Write Error") );
+            KMessageBox::error(m_mainWidget, i18n("Access denied: cannot write to file %1", file.fileName()), i18n("Write Error") );
             return;
         }
 
         QTextStream stream(&file);
-        stream.setEncoding(QTextStream::UnicodeUTF8);
+        stream.setCodec("UTF-8");
 
-        stream << m_view->feedListToOPML().toString() << "\n";
+        stream << m_mainWidget->feedListToOPML().toString() << "\n";
         file.close();
     }
     else
     {
-        KTempFile tmpfile;
-        tmpfile.setAutoDelete(true);
+        KTemporaryFile tmpfile;
+        tmpfile.open();
 
-        QTextStream stream(tmpfile.file());
-        stream.setEncoding(QTextStream::UnicodeUTF8);
+        QTextStream stream(&tmpfile);
+        stream.setCodec("UTF-8");
 
-        stream << m_view->feedListToOPML().toString() << "\n";
-        tmpfile.close();
+        stream << m_mainWidget->feedListToOPML().toString() << "\n";
+        stream.flush();
 
-        if (!KIO::NetAccess::upload(tmpfile.name(), url, m_view))
-            KMessageBox::error(m_view, KIO::NetAccess::lastErrorString() );
+        if (!KIO::NetAccess::upload(tmpfile.fileName(), url, m_mainWidget))
+            KMessageBox::error(m_mainWidget, KIO::NetAccess::lastErrorString() );
     }
 }
 
 void Part::fileImport()
 {
-    KURL url = KFileDialog::getOpenURL( QString::null,
+    KUrl url = KFileDialog::getOpenUrl( KUrl(),
                         "*.opml *.xml|" + i18n("OPML Outlines (*.opml, *.xml)")
                         +"\n*|" + i18n("All Files") );
 
@@ -649,7 +591,7 @@ void Part::fileImport()
 
     void Part::fileExport()
 {
-    KURL url= KFileDialog::getSaveURL( QString::null,
+    KUrl url= KFileDialog::getSaveUrl( KUrl(),
                         "*.opml *.xml|" + i18n("OPML Outlines (*.opml, *.xml)")
                         +"\n*|" + i18n("All Files") );
 
@@ -657,92 +599,67 @@ void Part::fileImport()
         exportFile(url);
 }
 
-void Part::fileGetFeeds()
-{
-    /*GetFeeds *gf = new GetFeeds();
-    gf->show();*/
-     //KNS::DownloadDialog::open("akregator/feeds", i18n("Get New Feeds"));
-}
-
-void Part::fileSendArticle(bool attach)
-{
-    // FIXME: you have to open article to tab to be able to send...
-    QString title, text;
-
-    text = m_view->currentFrame()->part()->url().prettyURL();
-    if(text.isEmpty() || text.isNull())
-        return;
-
-    title = m_view->currentFrame()->title();
-
-    if(attach) {
-        kapp->invokeMailer("",
-                           "",
-                           "",
-                           title,
-                           text,
-                           "",
-                           text);
-    }
-    else {
-        kapp->invokeMailer("",
-                           "",
-                           "",
-                           title,
-                           text);
-    }
-}
-
 void Part::fetchAllFeeds()
 {
-    m_view->slotFetchAllFeeds();
+    m_mainWidget->slotFetchAllFeeds();
 }
 
 void Part::fetchFeedUrl(const QString&s)
 {
-    kdDebug() << "fetchFeedURL==" << s << endl;
+    kDebug() <<"fetchFeedURL==" << s;
 }
 
 void Part::addFeedsToGroup(const QStringList& urls, const QString& group)
 {
     for (QStringList::ConstIterator it = urls.begin(); it != urls.end(); ++it)
     {
-        kdDebug() << "Akregator::Part::addFeedToGroup adding feed with URL " << *it << " to group " << group << endl;
-        m_view->addFeedToGroup(*it, group);
+        kDebug() <<"Akregator::Part::addFeedToGroup adding feed with URL" << *it <<" to group" << group;
+        m_mainWidget->addFeedToGroup(*it, group);
     }
     NotificationManager::self()->slotNotifyFeeds(urls);
 }
 
 void Part::addFeed()
 {
-    m_view->slotFeedAdd();
-}
-
-KAboutData *Part::createAboutData()
-{
-    return new Akregator::AboutData;
+    m_mainWidget->slotFeedAdd();
 }
 
 void Part::showKNotifyOptions()
 {
     KAboutData* about = new Akregator::AboutData;
-    KNotifyDialog::configure(m_view, "akregator_knotify_config", about);
+    KNotifyConfigWidget::configure(m_mainWidget, about->appName() );
     delete about;
 }
 
 void Part::showOptions()
 {
-    if ( KConfigDialog::showDialog( "settings" ) )
-        return;
+    saveSettings();
 
-    KConfigDialog* dialog = new ConfigDialog( m_view, "settings", Settings::self() );
+    if ( !m_dialog ) {
+        m_dialog = new KCMultiDialog( m_mainWidget );
+        connect( m_dialog, SIGNAL(configCommitted()),
+                 this, SLOT(slotSettingsChanged()) );
+        connect( m_dialog, SIGNAL(configCommitted()),
+                 TrayIcon::getInstance(), SLOT(settingsChanged()) );
 
-    connect( dialog, SIGNAL(settingsChanged()),
-             this, SLOT(slotSettingsChanged()) );
-    connect( dialog, SIGNAL(settingsChanged()),
-             TrayIcon::getInstance(), SLOT(settingsChanged()) );
+        QStringList modules;
 
-    dialog->show();
+        modules.append( "akregator_config_general.desktop" );
+        modules.append( "akregator_config_onlinesync.desktop" );
+        modules.append( "akregator_config_archive.desktop" );
+        modules.append( "akregator_config_appearance.desktop" );
+        modules.append( "akregator_config_browser.desktop" );
+        modules.append( "akregator_config_advanced.desktop" );
+
+        // add them all
+        QStringList::iterator mit;
+        for ( mit = modules.begin(); mit != modules.end(); ++mit ) {
+            m_dialog->addModule( *mit );
+        }
+    }
+
+    m_dialog->show();
+    m_dialog->raise();
 }
 
 void Part::partActivateEvent(KParts::PartActivateEvent* event)
@@ -760,23 +677,29 @@ void Part::partActivateEvent(KParts::PartActivateEvent* event)
 
 KParts::Part* Part::hitTest(QWidget *widget, const QPoint &globalPos)
 {
-    bool child = false;
+/*    bool child = false;
     QWidget *me = this->widget();
-    while (widget) {
-        if (widget == me) {
+    while (widget)
+    {
+        if (widget == me)
+        {
             child = true;
             break;
         }
-        if (!widget) {
+        if (!widget)
+        {
             break;
         }
         widget = widget->parentWidget();
     }
-    if (m_view && m_view->currentFrame() && child) {
-        return m_view->currentFrame()->part();
-    } else {
-        return MyBasePart::hitTest(widget, globalPos);
+    if (m_mainWidget && m_mainWidget->currentFrame() && child)
+    {
+        return m_mainWidget->currentFrame()->part();
     }
+    else
+    {*/
+        return MyBasePart::hitTest(widget, globalPos);
+/*    }*/
 }
 
 void Part::initFonts()
@@ -800,41 +723,40 @@ void Part::initFonts()
     if (Settings::serifFont().isEmpty())
         Settings::setSerifFont(fonts[3]);
 
-    KConfig* conf = Settings::self()->config();
-    conf->setGroup("HTML Settings");
+    KConfigGroup conf( Settings::self()->config(), "HTML Settings");
 
-    KConfig konq("konquerorrc", true, false);
-    konq.setGroup("HTML Settings");
+    KConfig _konq( "konquerorrc", KConfig::NoGlobals  );
+    KConfigGroup konq(&_konq, "HTML Settings");
 
-    if (!conf->hasKey("MinimumFontSize"))
+    if (!conf.hasKey("MinimumFontSize"))
     {
         int minfs;
         if (konq.hasKey("MinimumFontSize"))
-            minfs = konq.readNumEntry("MinimumFontSize");
+            minfs = konq.readEntry("MinimumFontSize", 0);
         else
             minfs = KGlobalSettings::generalFont().pointSize();
-        kdDebug() << "Part::initFonts(): set MinimumFontSize to " << minfs << endl;
+        kDebug() <<"Part::initFonts(): set MinimumFontSize to" << minfs;
         Settings::setMinimumFontSize(minfs);
     }
 
-    if (!conf->hasKey("MediumFontSize"))
+    if (!conf.hasKey("MediumFontSize"))
     {
         int medfs;
         if (konq.hasKey("MediumFontSize"))
-            medfs = konq.readNumEntry("MediumFontSize");
+            medfs = konq.readEntry("MediumFontSize", 0);
         else
             medfs = KGlobalSettings::generalFont().pointSize();
-        kdDebug() << "Part::initFonts(): set MediumFontSize to " << medfs << endl;
+        kDebug() <<"Part::initFonts(): set MediumFontSize to" << medfs;
         Settings::setMediumFontSize(medfs);
     }
 
-    if (!conf->hasKey("UnderlineLinks"))
+    if (!conf.hasKey("UnderlineLinks"))
     {
         bool underline = true;
         if (konq.hasKey("UnderlineLinks"))
-            underline = konq.readBoolEntry("UnderlineLinks");
+            underline = konq.readEntry("UnderlineLinks", false);
 
-        kdDebug() << "Part::initFonts(): set UnderlineLinks to " << underline << endl;
+        kDebug() <<"Part::initFonts(): set UnderlineLinks to" << underline;
         Settings::setUnderlineLinks(underline);
     }
 
@@ -842,12 +764,12 @@ void Part::initFonts()
 
 bool Part::copyFile(const QString& backup)
 {
-    QFile file(m_file);
+    QFile file(localFilePath());
 
-    if (file.open(IO_ReadOnly))
+    if (file.open(QIODevice::ReadOnly))
     {
         QFile backupFile(backup);
-        if (backupFile.open(IO_WriteOnly))
+        if (backupFile.open(QIODevice::WriteOnly))
         {
             QTextStream in(&file);
             QTextStream out(&backupFile);
@@ -866,6 +788,6 @@ bool Part::copyFile(const QString& backup)
     return false;
 }
 
-
 } // namespace Akregator
+
 #include "akregator_part.moc"
