@@ -21,8 +21,9 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <qlayout.h>
-#include <qpopupmenu.h>
+#include <QMenu>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
 #include <kabc/addressbook.h>
 #include <kabc/distributionlistdialog.h>
@@ -31,15 +32,15 @@
 #include <klocale.h>
 #include <kxmlguifactory.h>
 #include <kxmlguiclient.h>
+#include <kconfiggroup.h>
 
 #include "core.h"
 #include "searchmanager.h"
 
 #include "kaddressbookview.h"
 
-KAddressBookView::KAddressBookView( KAB::Core *core, QWidget *parent,
-                                    const char *name )
-    : QWidget( parent, name ), mCore( core ), mFieldList()
+KAddressBookView::KAddressBookView( KAB::Core *core, QWidget *parent )
+    : QWidget( parent ), mCore( core ), mFieldList()
 {
   initGUI();
 
@@ -49,22 +50,22 @@ KAddressBookView::KAddressBookView( KAB::Core *core, QWidget *parent,
 
 KAddressBookView::~KAddressBookView()
 {
-  kdDebug(5720) << "KAddressBookView::~KAddressBookView: destroying - "
-                << name() << endl;
+  kDebug(5720) <<"KAddressBookView::~KAddressBookView: destroying -"
+                << objectName();
 }
 
-void KAddressBookView::readConfig( KConfig *config )
+void KAddressBookView::readConfig( KConfigGroup &config )
 {
   mFieldList = KABC::Field::restoreFields( config, "KABCFields" );
 
   if ( mFieldList.isEmpty() )
     mFieldList = KABC::Field::defaultFields();
 
-  mDefaultFilterType = (DefaultFilterType)config->readNumEntry( "DefaultFilterType", 1 );
-  mDefaultFilterName = config->readEntry( "DefaultFilterName" );
+  mDefaultFilterType = (DefaultFilterType)config.readEntry( "DefaultFilterType", 1 );
+  mDefaultFilterName = config.readEntry( "DefaultFilterName" );
 }
 
-void KAddressBookView::writeConfig( KConfig* )
+void KAddressBookView::writeConfig( KConfigGroup& )
 {
   // Most of writing the config is handled by the ConfigureViewDialog
 }
@@ -82,7 +83,7 @@ QString KAddressBookView::selectedEmails()
     addr = mCore->addressBook()->findByUid( *it );
 
     if ( !addr.isEmpty() ) {
-      QString m = QString::null;
+      QString m = QString();
 
       if ( addr.emails().count() > 1 )
         m = KABC::EmailSelector::getEmail( addr.emails(), addr.preferredEmail(), this );
@@ -123,6 +124,7 @@ void KAddressBookView::initGUI()
 {
   // Create the layout
   QVBoxLayout *layout = new QVBoxLayout( this );
+  layout->setMargin( 0 );
 
   // Add the view widget
   mViewWidget = new QWidget( this );
@@ -157,11 +159,11 @@ KAB::Core *KAddressBookView::core() const
 void KAddressBookView::popup( const QPoint &point )
 {
   if ( !mCore->guiClient() ) {
-    kdWarning() << "No GUI client set!" << endl;
+    kWarning() <<"No GUI client set!";
     return;
   }
 
-  QPopupMenu *menu = static_cast<QPopupMenu*>( mCore->guiClient()->factory()->container( "RMBPopup",
+  QMenu *menu = static_cast<QMenu*>( mCore->guiClient()->factory()->container( "RMBPopup",
                                                mCore->guiClient() ) );
   if ( menu )
     menu->popup( point );
@@ -189,15 +191,14 @@ void KAddressBookView::updateView()
     if ( !contacts.isEmpty() )
       setSelected( contacts.first().uid(), true );
     else
-      emit selected( QString::null );
+      emit selected( QString() );
   }
 }
 
 ViewConfigureWidget *ViewFactory::configureWidget( KABC::AddressBook *ab,
-                                                   QWidget *parent,
-                                                   const char *name )
+                                                   QWidget *parent )
 {
-  return new ViewConfigureWidget( ab, parent, name );
+  return new ViewConfigureWidget( ab, parent );
 }
 
 #include "kaddressbookview.moc"
