@@ -1,7 +1,7 @@
 /*
  *  alarmevent.h  -  represents calendar alarms and events
  *  Program:  kalarm
- *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,32 +23,36 @@
 
 /**  @file alarmevent.h - represents calendar alarms and events */
 
-#include <qcolor.h>
-#include <qfont.h>
+#include <QColor>
+#include <QFont>
+#include <QList>
 
-#include <libkcal/person.h>
-#include <libkcal/event.h>
-namespace KCal {
-	class Calendar;
-	class Recurrence;
-}
+#include <kcal/person.h>
+#include <kcal/event.h>
+#include <kcal/duration.h>
+namespace KCal { class CalendarLocal; }
 
 #include "datetime.h"
 #include "karecurrence.h"
+#include "kcalendar.h"
+#include "preferences.h"
 
-class AlarmCalendar;
+class AlarmResource;
 class KARecurrence;
 struct AlarmData;
 
 
 typedef KCal::Person  EmailAddress;
-class EmailAddressList : public QValueList<KCal::Person>
+class EmailAddressList : public QList<KCal::Person>
 {
 	public:
-		EmailAddressList() : QValueList<KCal::Person>() { }
-		EmailAddressList(const QValueList<KCal::Person>& list)  { operator=(list); }
-		EmailAddressList& operator=(const QValueList<KCal::Person>&);
+		EmailAddressList() : QList<KCal::Person>() { }
+		EmailAddressList(const QList<KCal::Person>& list)  { operator=(list); }
+		EmailAddressList& operator=(const QList<KCal::Person>&);
+		operator QStringList() const;
 		QString join(const QString& separator) const;
+	private:
+		QString address(int index) const;
 };
 
 
@@ -58,10 +62,10 @@ class KAAlarmEventBase
 	public:
 		~KAAlarmEventBase()  { }
 		const QString&     cleanText() const           { return mText; }
-		QString            message() const             { return (mActionType == T_MESSAGE || mActionType == T_EMAIL) ? mText : QString::null; }
-		QString            fileName() const            { return (mActionType == T_FILE) ? mText : QString::null; }
-		QString            command() const             { return (mActionType == T_COMMAND) ? mText : QString::null; }
-		QString            emailFromKMail() const      { return mEmailFromKMail; }
+		QString            message() const             { return (mActionType == T_MESSAGE || mActionType == T_EMAIL) ? mText : QString(); }
+		QString            fileName() const            { return (mActionType == T_FILE) ? mText : QString(); }
+		QString            command() const             { return (mActionType == T_COMMAND) ? mText : QString(); }
+		uint               emailFromId() const         { return mEmailFromIdentity; }
 		const EmailAddressList& emailAddresses() const { return mEmailAddresses; }
 		QString            emailAddresses(const QString& sep) const  { return mEmailAddresses.join(sep); }
 		const QString&     emailSubject() const        { return mEmailSubject; }
@@ -71,17 +75,16 @@ class KAAlarmEventBase
 		const QColor&      bgColour() const            { return mBgColour; }
 		const QColor&      fgColour() const            { return mFgColour; }
 		bool               defaultFont() const         { return mDefaultFont; }
-		const QFont&       font() const;
+		QFont              font() const;
 		int                lateCancel() const          { return mLateCancel; }
 		bool               autoClose() const           { return mAutoClose; }
 		bool               commandScript() const       { return mCommandScript; }
 		bool               confirmAck() const          { return mConfirmAck; }
 		bool               repeatAtLogin() const       { return mRepeatAtLogin; }
 		int                repeatCount() const         { return mRepeatCount; }
-		int                repeatInterval() const      { return mRepeatInterval; }
+		KCal::Duration     repeatInterval() const      { return mRepeatInterval; }
 		bool               displaying() const          { return mDisplaying; }
 		bool               beep() const                { return mBeep; }
-		bool               speak() const               { return (mActionType == T_MESSAGE) && mSpeak; }
 		int                flags() const;
 #ifdef NDEBUG
 		void               dumpDebug() const  { }
@@ -92,7 +95,8 @@ class KAAlarmEventBase
 	protected:
 		enum Type  { T_MESSAGE, T_FILE, T_COMMAND, T_AUDIO, T_EMAIL };
 
-		KAAlarmEventBase() : mLateCancel(0), mAutoClose(false), mBeep(false), mRepeatAtLogin(false),
+		KAAlarmEventBase() : mRepeatCount(0), mRepeatInterval(0), mNextRepeat(0), mLateCancel(0),
+		                     mAutoClose(false), mBeep(false), mRepeatAtLogin(false),
 		                     mDisplaying(false), mEmailBcc(false), mConfirmAck(false) { }
 		KAAlarmEventBase(const KAAlarmEventBase& rhs)             { copy(rhs); }
 		KAAlarmEventBase& operator=(const KAAlarmEventBase& rhs)  { copy(rhs);  return *this; }
@@ -105,7 +109,7 @@ class KAAlarmEventBase
 		QColor             mBgColour;         // background colour of alarm message
 		QColor             mFgColour;         // foreground colour of alarm message, or invalid for default
 		QFont              mFont;             // font of alarm message (ignored if mDefaultFont true)
-		QString            mEmailFromKMail;   // KMail identity for email 'From' field, or empty
+		uint               mEmailFromIdentity;// standard email identity uoid for 'From' field, or empty
 		EmailAddressList   mEmailAddresses;   // ATTENDEE: addresses to send email to
 		QString            mEmailSubject;     // SUMMARY: subject line of email
 		QStringList        mEmailAttachments; // ATTACH: email attachment file names
@@ -113,22 +117,21 @@ class KAAlarmEventBase
 		float              mFadeVolume;       // initial volume for sound file, or < 0 for no fade
 		int                mFadeSeconds;      // fade time for sound file, or 0 if none
 		Type               mActionType;       // alarm action type
-		int                mRepeatCount;      // simple repetition count (excluding the first time)
-		int                mRepeatInterval;   // simple repetition interval (minutes)
-		int                mNextRepeat;       // repetition count of next due repetition
+		int                mRepeatCount;      // sub-repetition count (excluding the first time)
+		KCal::Duration     mRepeatInterval;   // sub-repetition interval
+		int                mNextRepeat;       // repetition count of next due sub-repetition
 		int                mLateCancel;       // how many minutes late will cancel the alarm, or 0 for no cancellation
 		bool               mAutoClose;        // whether to close the alarm window after the late-cancel period
 		bool               mCommandScript;    // the command text is a script, not a shell command line
 		bool               mBeep;             // whether to beep when the alarm is displayed
-		bool               mSpeak;            // whether to speak the message when the alarm is displayed
 		bool               mRepeatSound;      // whether to repeat the sound file while the alarm is displayed
 		bool               mRepeatAtLogin;    // whether to repeat the alarm at every login
-		bool               mDisplaying;       // whether the alarm is currently being displayed
+		bool               mDisplaying;       // whether the alarm is currently being displayed (i.e. in displaying calendar)
 		bool               mEmailBcc;         // blind copy the email to the user
 		bool               mConfirmAck;       // alarm acknowledgement requires confirmation by user
 		bool               mDefaultFont;      // use default message font, not mFont
 
-	friend class AlarmData;
+	friend struct AlarmData;
 };
 
 
@@ -137,7 +140,7 @@ class KAAlarmEventBase
 class KAAlarm : public KAAlarmEventBase
 {
 	public:
-		// Define the basic KAAlaem action types
+		// Define the basic KAAlarm action types
 		enum Action
 		{
 			MESSAGE = T_MESSAGE,   // KCal::Alarm::Display type: display a text message
@@ -197,10 +200,10 @@ class KAAlarm : public KAAlarmEventBase
 		const QString&     eventID() const              { return mEventID; }
 		DateTime           dateTime(bool withRepeats = false) const
 		                                                { return (withRepeats && mNextRepeat && mRepeatInterval)
-		                                                    ? mNextMainDateTime.addSecs(mNextRepeat * mRepeatInterval * 60) : mNextMainDateTime; }
+		                                                    ? (mRepeatInterval * mNextRepeat).end(mNextMainDateTime.kDateTime()) : mNextMainDateTime; }
 		QDate              date() const                 { return mNextMainDateTime.date(); }
-		QTime              time() const                 { return mNextMainDateTime.time(); }
-		QString            audioFile() const            { return (mActionType == T_AUDIO) && !mBeep ? mText : QString::null; }
+		QTime              time() const                 { return mNextMainDateTime.effectiveTime(); }
+		QString            audioFile() const            { return (mActionType == T_AUDIO) && !mBeep ? mText : QString(); }
 		float              soundVolume() const          { return (mActionType == T_AUDIO) && !mBeep && !mText.isEmpty() ? mSoundVolume : -1; }
 		float              fadeVolume() const           { return (mActionType == T_AUDIO) && mSoundVolume >= 0 && mFadeSeconds && !mBeep && !mText.isEmpty() ? mFadeVolume : -1; }
 		int                fadeSeconds() const          { return (mActionType == T_AUDIO) && mSoundVolume >= 0 && mFadeVolume >= 0 && !mBeep && !mText.isEmpty() ? mFadeSeconds : 0; }
@@ -208,7 +211,7 @@ class KAAlarm : public KAAlarmEventBase
 		bool               reminder() const             { return mType == REMINDER__ALARM; }
 		bool               deferred() const             { return mDeferred; }
 		void               setTime(const DateTime& dt)  { mNextMainDateTime = dt; }
-		void               setTime(const QDateTime& dt) { mNextMainDateTime = dt; }
+		void               setTime(const KDateTime& dt) { mNextMainDateTime = dt; }
 		int                flags() const;
 #ifdef NDEBUG
 		void               dumpDebug() const  { }
@@ -231,14 +234,9 @@ class KAAlarm : public KAAlarmEventBase
 class KAEvent : public KAAlarmEventBase
 {
 	public:
+		typedef QList<KAEvent*> List;
 		enum            // flags for use in DCOP calls, etc.
 		{
-#ifdef OLD_DCOP
-			// *** DON'T CHANGE THESE VALUES ***
-			// because they are part of KAlarm's external DCOP interface.
-			// (But it's alright to add new values.)
-			LATE_CANCEL     = 0x01,    // cancel alarm if not triggered within a minute of its scheduled time
-#endif
 			BEEP            = 0x02,    // sound audible beep when alarm is displayed
 			REPEAT_AT_LOGIN = 0x04,    // repeat alarm at every login
 			ANY_TIME        = 0x08,    // only a date is specified for the alarm, not a time
@@ -251,12 +249,10 @@ class KAEvent : public KAAlarmEventBase
 			SCRIPT          = 0x400,   // command is a script, not a shell command line
 			EXEC_IN_XTERM   = 0x800,   // execute command in terminal window
 			SPEAK           = 0x1000,  // speak the message when the alarm is displayed
-		        COPY_KORGANIZER = 0x2000,  // KOrganizer should hold a copy of the event
-#ifdef OLD_DCOP
-			// The following are read-only internal values, and may be changed
-#else
+			COPY_KORGANIZER = 0x2000,  // KOrganizer should hold a copy of the event
+			WORK_TIME_ONLY  = 0x4000,  // trigger alarm only during working hours
+			DISPLAY_COMMAND = 0x8000,  // display command output in alarm window
 			// The following are read-only internal values
-#endif
 			REMINDER        = 0x10000,
 			DEFERRAL        = 0x20000,
 			TIMED_FLAG      = 0x40000,
@@ -265,15 +261,6 @@ class KAEvent : public KAAlarmEventBase
 			DISPLAYING_     = 0x80000,
 			READ_ONLY_FLAGS = 0xF0000   // mask for all read-only internal values
 		};
-		/** The category of an event, indicated by the middle part of its UID. */
-		enum Status
-		{
-			ACTIVE,      // the event is currently active
-			EXPIRED,     // the event has expired
-			DISPLAYING,  // the event is currently being displayed
-			TEMPLATE,    // the event is an alarm template
-			KORGANIZER   // the event is a copy of a KAlarm event, held by KOrganizer
-		};
 		enum Action
 		{
 			MESSAGE = T_MESSAGE,
@@ -290,9 +277,9 @@ class KAEvent : public KAAlarmEventBase
 			LAST_RECURRENCE             = 0x04,   // the last recurrence
 			OCCURRENCE_REPEAT = 0x10,    // (bitmask for a repetition of an occurrence)
 			FIRST_OR_ONLY_OCCURRENCE_REPEAT = OCCURRENCE_REPEAT | FIRST_OR_ONLY_OCCURRENCE,     // a repetition of the first occurrence
-			RECURRENCE_DATE_REPEAT      = OCCURRENCE_REPEAT | RECURRENCE_DATE,      // a repetition of a date-only recurrence
-			RECURRENCE_DATE_TIME_REPEAT = OCCURRENCE_REPEAT | RECURRENCE_DATE_TIME, // a repetition of a date/time recurrence
-			LAST_RECURRENCE_REPEAT      = OCCURRENCE_REPEAT | LAST_RECURRENCE       // a repetition of the last recurrence
+			RECURRENCE_DATE_REPEAT          = OCCURRENCE_REPEAT | RECURRENCE_DATE,      // a repetition of a date-only recurrence
+			RECURRENCE_DATE_TIME_REPEAT     = OCCURRENCE_REPEAT | RECURRENCE_DATE_TIME, // a repetition of a date/time recurrence
+			LAST_RECURRENCE_REPEAT          = OCCURRENCE_REPEAT | LAST_RECURRENCE       // a repetition of the last recurrence
 		};
 		enum OccurOption     // options for nextOccurrence()
 		{
@@ -308,48 +295,42 @@ class KAEvent : public KAAlarmEventBase
 			LIMIT_REPETITION,
 			LIMIT_REMINDER
 		};
+		enum TriggerType    // alarm trigger type
+		{
+			ALL_TRIGGER,       // next trigger, including reminders, ignoring working hours
+			MAIN_TRIGGER,      // next trigger, excluding reminders, ignoring working hours
+			WORK_TRIGGER,      // next main working time trigger, excluding reminders
+			ALL_WORK_TRIGGER,  // next actual working time trigger, including reminders
+			DISPLAY_TRIGGER    // next trigger time for display purposes (i.e. excluding reminders)
+		};
 
-		KAEvent()          : mRevision(0), mRecurrence(0), mAlarmCount(0) { }
-		KAEvent(const QDateTime& dt, const QString& message, const QColor& bg, const QColor& fg, const QFont& f, Action action, int lateCancel, int flags)
-		                                        : mRecurrence(0) { set(dt, message, bg, fg, f, action, lateCancel, flags); }
-		explicit KAEvent(const KCal::Event& e)  : mRecurrence(0) { set(e); }
+		KAEvent()          : mReminderMinutes(0), mRevision(0), mRecurrence(0), mAlarmCount(0),
+		                     mDeferral(NO_DEFERRAL), mChangeCount(0), mChanged(false), mWorkTimeOnly(false) { }
+		KAEvent(const KDateTime& dt, const QString& message, const QColor& bg, const QColor& fg, const QFont& f, Action action, int lateCancel, int flags, bool changesPending = false)
+		                                        : mRecurrence(0) { set(dt, message, bg, fg, f, action, lateCancel, flags, changesPending); }
+		explicit KAEvent(const KCal::Event* e)  : mRecurrence(0) { set(e); }
 		KAEvent(const KAEvent& e)               : KAAlarmEventBase(e), mRecurrence(0) { copy(e); }
 		~KAEvent()         { delete mRecurrence; }
 		KAEvent&           operator=(const KAEvent& e)       { if (&e != this) copy(e);  return *this; }
-		void               set(const KCal::Event&);
-		void               set(const QDate& d, const QString& message, const QColor& bg, const QColor& fg, const QFont& f, Action action, int lateCancel, int flags)
-		                            { set(d, message, bg, fg, f, action, lateCancel, flags | ANY_TIME); }
-		void               set(const QDateTime&, const QString& message, const QColor& bg, const QColor& fg, const QFont&, Action, int lateCancel, int flags);
-		void               setMessage(const QDate& d, const QString& message, const QColor& bg, const QColor& fg, const QFont& f, int lateCancel, int flags)
-		                            { set(d, message, bg, fg, f, MESSAGE, lateCancel, flags | ANY_TIME); }
-		void               setMessage(const QDateTime& dt, const QString& message, const QColor& bg, const QColor& fg, const QFont& f, int lateCancel, int flags)
-		                            { set(dt, message, bg, fg, f, MESSAGE, lateCancel, flags); }
-		void               setFileName(const QDate& d, const QString& filename, const QColor& bg, const QColor& fg, const QFont& f, int lateCancel, int flags)
-		                            { set(d, filename, bg, fg, f, FILE, lateCancel, flags | ANY_TIME); }
-		void               setFileName(const QDateTime& dt, const QString& filename, const QColor& bg, const QColor& fg, const QFont& f, int lateCancel, int flags)
-		                            { set(dt, filename, bg, fg, f, FILE, lateCancel, flags); }
-		void               setCommand(const QDate&, const QString& command, int lateCancel, int flags, const QString& logfile = QString::null);
-		void               setCommand(const QDateTime&, const QString& command, int lateCancel, int flags, const QString& logfile = QString::null);
-		void               setEmail(const QDate&, const QString& from, const EmailAddressList&, const QString& subject,
-		                            const QString& message, const QStringList& attachments, int lateCancel, int flags);
-		void               setEmail(const QDateTime&, const QString& from, const EmailAddressList&, const QString& subject,
-		                            const QString& message, const QStringList& attachments, int lateCancel, int flags);
-		void               setEmail(const QString& from, const EmailAddressList&, const QString& subject, const QStringList& attachments);
+		void               set(const KCal::Event*);
+		void               set(const KDateTime&, const QString& message, const QColor& bg, const QColor& fg, const QFont&, Action, int lateCancel, int flags, bool changesPending = false);
+		void               setEmail(uint from, const EmailAddressList&, const QString& subject, const QStringList& attachments);
+		void               setResource(AlarmResource* r)                    { mResource = r; }
 		void               setAudioFile(const QString& filename, float volume, float fadeVolume, int fadeSeconds);
-		void               setTemplate(const QString& name, int afterTime = -1)  { mTemplateName = name;  mTemplateAfterTime = afterTime;  mUpdated = true; }
-		void               setActions(const QString& pre, const QString& post)   { mPreAction = pre;  mPostAction = post;  mUpdated = true; }
-		OccurType          setNextOccurrence(const QDateTime& preDateTime);
+		void               setTemplate(const QString& name, int afterTime = -1);
+		void               setActions(const QString& pre, const QString& post, bool cancelOnError)
+		                                                                    { mPreAction = pre;  mPostAction = post;  mCancelOnPreActErr = cancelOnError;  mUpdated = true; }
+		OccurType          setNextOccurrence(const KDateTime& preDateTime);
 		void               setFirstRecurrence();
+		void               setCategory(KCalEvent::Status);
+		void               setUid(KCalEvent::Status s)                       { mEventID = KCalEvent::uid(mEventID, s);  mUpdated = true; }
 		void               setEventID(const QString& id)                     { mEventID = id;  mUpdated = true; }
-		void               adjustStartDate(const QDate&);
-		void               setDate(const QDate& d)                           { mNextMainDateTime.set(d);  mUpdated = true; }
-		void               setTime(const QDateTime& dt)                      { mNextMainDateTime.set(dt);  mUpdated = true; }
-		void               setSaveDateTime(const QDateTime& dt)              { mSaveDateTime = dt;  mUpdated = true; }
+		void               setTime(const KDateTime& dt)                      { mNextMainDateTime = dt;  mUpdated = true; }
+		void               setSaveDateTime(const KDateTime& dt)              { mSaveDateTime = dt;  mUpdated = true; }
 		void               setLateCancel(int lc)                             { mLateCancel = lc;  mUpdated = true; }
 		void               setAutoClose(bool ac)                             { mAutoClose = ac;  mUpdated = true; }
 		void               setRepeatAtLogin(bool rl)                         { mRepeatAtLogin = rl;  mUpdated = true; }
-		void               set(int flags);
-		void               setUid(Status s)                                  { mEventID = uid(mEventID, s);  mUpdated = true; }
+		void               setWorkTimeOnly(bool wto)                         { mWorkTimeOnly = wto; }
 		void               setKMailSerialNumber(unsigned long n)             { mKMailSerialNumber = n; }
 		void               setLogFile(const QString& logfile);
 		void               setReminder(int minutes, bool onceOnly);
@@ -357,16 +338,19 @@ class KAEvent : public KAAlarmEventBase
 		void               cancelDefer();
 		void               cancelCancelledDeferral();
 		void               setDeferDefaultMinutes(int minutes)               { mDeferDefaultMinutes = minutes;  mUpdated = true; }
-		bool               setDisplaying(const KAEvent&, KAAlarm::Type, const QDateTime&);
-		void               reinstateFromDisplaying(const KAEvent& dispEvent);
+		bool               setDisplaying(const KAEvent&, KAAlarm::Type, const QString& resourceID, const KDateTime&, bool showEdit, bool showDefer);
+		void               reinstateFromDisplaying(const KCal::Event*, QString& resourceID, bool& showEdit, bool& showDefer);
 		void               setArchive()                                      { mArchive = true;  mUpdated = true; }
 		void               setEnabled(bool enable)                           { mEnabled = enable;  mUpdated = true; }
+		void               startChanges()                                    { ++mChangeCount; }
+		void               endChanges();
 		void               setUpdated()                                      { mUpdated = true; }
 		void               clearUpdated() const                              { mUpdated = false; }
+		void               clearResourceID()                                 { mResourceId.clear(); }
+		void               updateWorkHours() const                           { if (mWorkTimeOnly) calcTriggerTimes(); }
 		void               removeExpiredAlarm(KAAlarm::Type);
 		void               incrementRevision()                               { ++mRevision;  mUpdated = true; }
 
-		KCal::Event*       event() const;    // convert to new Event
 		bool               isTemplate() const             { return !mTemplateName.isEmpty(); }
 		const QString&     templateName() const           { return mTemplateName; }
 		bool               usingDefaultTime() const       { return mTemplateAfterTime == 0; }
@@ -376,20 +360,21 @@ class KAEvent : public KAAlarmEventBase
 		KAAlarm            nextAlarm(const KAAlarm& al) const  { return nextAlarm(al.type()); }
 		KAAlarm            nextAlarm(KAAlarm::Type) const;
 		KAAlarm            convertDisplayingAlarm() const;
-		bool               updateKCalEvent(KCal::Event&, bool checkUid = true, bool original = false, bool cancelCancelledDefer = false) const;
+		bool               updateKCalEvent(KCal::Event*, bool checkUid = true, bool original = false, bool cancelCancelledDefer = false) const;
 		Action             action() const                 { return (Action)mActionType; }
-		bool               displayAction() const          { return mActionType == T_MESSAGE || mActionType == T_FILE; }
+		bool               displayAction() const          { return mActionType == T_MESSAGE || mActionType == T_FILE || (mActionType == T_COMMAND && mCommandDisplay); }
 		const QString&     id() const                     { return mEventID; }
 		bool               valid() const                  { return mAlarmCount  &&  (mAlarmCount != 1 || !mRepeatAtLogin); }
 		int                alarmCount() const             { return mAlarmCount; }
 		const DateTime&    startDateTime() const          { return mStartDateTime; }
 		DateTime           mainDateTime(bool withRepeats = false) const
 		                                                  { return (withRepeats && mNextRepeat && mRepeatInterval)
-		                                                    ? mNextMainDateTime.addSecs(mNextRepeat * mRepeatInterval * 60) : mNextMainDateTime; }
+		                                                    ? (mRepeatInterval * mNextRepeat).end(mNextMainDateTime.kDateTime()) : mNextMainDateTime; }
 		QDate              mainDate() const               { return mNextMainDateTime.date(); }
-		QTime              mainTime() const               { return mNextMainDateTime.time(); }
+		QTime              mainTime() const               { return mNextMainDateTime.effectiveTime(); }
 		DateTime           mainEndRepeatTime() const      { return (mRepeatCount > 0 && mRepeatInterval)
-		                                                    ? mNextMainDateTime.addSecs(mRepeatCount * mRepeatInterval * 60) : mNextMainDateTime; }
+		                                                    ? (mRepeatInterval * mRepeatCount).end(mNextMainDateTime.kDateTime()) : mNextMainDateTime; }
+		DateTime           nextTrigger(TriggerType) const;
 		int                reminder() const               { return mReminderMinutes; }
 		bool               reminderOnceOnly() const       { return mReminderOnceOnly; }
 		bool               reminderDeferral() const       { return mDeferral == REMINDER_DEFERRAL; }
@@ -397,12 +382,14 @@ class KAEvent : public KAAlarmEventBase
 		DateTime           deferDateTime() const          { return mDeferralTime; }
 		DateTime           deferralLimit(DeferLimitType* = 0) const;
 		int                deferDefaultMinutes() const    { return mDeferDefaultMinutes; }
-		DateTime           nextDateTime(bool includeReminders = true) const;
 		const QString&     messageFileOrCommand() const   { return mText; }
 		QString            logFile() const                { return mLogFile; }
 		bool               commandXterm() const           { return mCommandXterm; }
+		bool               commandDisplay() const         { return mCommandDisplay; }
 		unsigned long      kmailSerialNumber() const      { return mKMailSerialNumber; }
 		bool               copyToKOrganizer() const       { return mCopyToKOrganizer; }
+		bool               workTimeOnly() const           { return mWorkTimeOnly; }
+		bool               speak() const                  { return (mActionType == T_MESSAGE  ||  (mActionType == T_COMMAND && mCommandDisplay)) && mSpeak; }
 		const QString&     audioFile() const              { return mAudioFile; }
 		float              soundVolume() const            { return !mAudioFile.isEmpty() ? mSoundVolume : -1; }
 		float              fadeVolume() const             { return !mAudioFile.isEmpty() && mSoundVolume >= 0 && mFadeSeconds ? mFadeVolume : -1; }
@@ -410,28 +397,27 @@ class KAEvent : public KAAlarmEventBase
 		bool               repeatSound() const            { return mRepeatSound  &&  !mAudioFile.isEmpty(); }
 		const QString&     preAction() const              { return mPreAction; }
 		const QString&     postAction() const             { return mPostAction; }
+		bool               cancelOnPreActionError() const { return mCancelOnPreActErr; }
 		bool               recurs() const                 { return checkRecur() != KARecurrence::NO_RECUR; }
 		KARecurrence::Type recurType() const              { return checkRecur(); }
 		KARecurrence*      recurrence() const             { return mRecurrence; }
 		int                recurInterval() const;    // recurrence period in units of the recurrence period type (minutes, days, etc)
-		int                longestRecurrenceInterval() const    { return mRecurrence ? mRecurrence->longestInterval() : 0; }
+		KCal::Duration     longestRecurrenceInterval() const    { return mRecurrence ? mRecurrence->longestInterval() : KCal::Duration(0); }
 		QString            recurrenceText(bool brief = false) const;
 		QString            repetitionText(bool brief = false) const;
-		int                remainingRecurrences() const   { return mRemainingRecurrences; }
-		bool               occursAfter(const QDateTime& preDateTime, bool includeRepetitions) const;
-		OccurType          nextOccurrence(const QDateTime& preDateTime, DateTime& result, OccurOption = IGNORE_REPETITION) const;
-		OccurType          previousOccurrence(const QDateTime& afterDateTime, DateTime& result, bool includeRepetitions = false) const;
+		bool               occursAfter(const KDateTime& preDateTime, bool includeRepetitions) const;
+		OccurType          nextOccurrence(const KDateTime& preDateTime, DateTime& result, OccurOption = IGNORE_REPETITION) const;
+		OccurType          previousOccurrence(const KDateTime& afterDateTime, DateTime& result, bool includeRepetitions = false) const;
 		int                flags() const;
 		bool               deferred() const               { return mDeferral > 0; }
 		bool               toBeArchived() const           { return mArchive; }
 		bool               enabled() const                { return mEnabled; }
 		bool               updated() const                { return mUpdated; }
 		bool               mainExpired() const            { return mMainExpired; }
-		bool               expired() const                { return mDisplaying && mMainExpired  ||  uidStatus(mEventID) == EXPIRED; }
-		Status             uidStatus() const              { return uidStatus(mEventID); }
-		static Status      uidStatus(const QString& uid);
-		static QString     uid(const QString& id, Status);
-		static KAEvent     findTemplateName(AlarmCalendar&, const QString& name);
+		bool               expired() const                { return (mDisplaying && mMainExpired)  ||  mCategory == KCalEvent::ARCHIVED; }
+		KCalEvent::Status  category() const               { return mCategory; }
+		AlarmResource*     resource() const               { return mResource; }
+		QString            resourceID() const             { return mResourceId; }
 
 		struct MonthPos
 		{
@@ -439,16 +425,16 @@ class KAEvent : public KAAlarmEventBase
 			int        weeknum;     // week in month, or < 0 to count from end of month
 			QBitArray  days;        // days in week
 		};
-		bool               setRepetition(int interval, int count);
-		void               setNoRecur()                   { clearRecur(); }
+		bool               setRepetition(const KCal::Duration&, int count);
+		void               setNoRecur()                   { clearRecur(); calcTriggerTimes(); }
 		void               setRecurrence(const KARecurrence&);
-		bool               setRecurMinutely(int freq, int count, const QDateTime& end);
+		bool               setRecurMinutely(int freq, int count, const KDateTime& end);
 		bool               setRecurDaily(int freq, const QBitArray& days, int count, const QDate& end);
 		bool               setRecurWeekly(int freq, const QBitArray& days, int count, const QDate& end);
-		bool               setRecurMonthlyByDate(int freq, const QValueList<int>& days, int count, const QDate& end);
-		bool               setRecurMonthlyByPos(int freq, const QValueList<MonthPos>& pos, int count, const QDate& end);
-		bool               setRecurAnnualByDate(int freq, const QValueList<int>& months, int day, KARecurrence::Feb29Type, int count, const QDate& end);
-		bool               setRecurAnnualByPos(int freq, const QValueList<MonthPos>& pos, const QValueList<int>& months, int count, const QDate& end);
+		bool               setRecurMonthlyByDate(int freq, const QList<int>& days, int count, const QDate& end);
+		bool               setRecurMonthlyByPos(int freq, const QList<MonthPos>& pos, int count, const QDate& end);
+		bool               setRecurAnnualByDate(int freq, const QList<int>& months, int day, Preferences::Feb29Type, int count, const QDate& end);
+		bool               setRecurAnnualByPos(int freq, const QList<MonthPos>& pos, const QList<int>& months, int count, const QDate& end);
 //		static QValueList<MonthPos> convRecurPos(const QValueList<KCal::RecurrenceRule::WDayPos>&);
 #ifdef NDEBUG
 		void               dumpDebug() const  { }
@@ -458,7 +444,8 @@ class KAEvent : public KAAlarmEventBase
 		static int         calVersion();
 		static QString     calVersionString();
 		static bool        adjustStartOfDay(const KCal::Event::List&);
-		static void        convertKCalEvents(KCal::Calendar&, int version, bool adjustSummerTime);
+		static bool        convertKCalEvents(KCal::CalendarLocal&, int version, bool adjustSummerTime);
+//		static bool        convertRepetitions(KCal::CalendarLocal&);
 
 	private:
 		enum DeferType {
@@ -469,46 +456,69 @@ class KAEvent : public KAAlarmEventBase
 		};
 
 		void               copy(const KAEvent&);
-		bool               setRecur(KCal::RecurrenceRule::PeriodType, int freq, int count, const QDateTime& end, KARecurrence::Feb29Type = KARecurrence::FEB29_FEB29);
+		bool               mayOccurDailyDuringWork(const KDateTime&) const;
+		bool               setRecur(KCal::RecurrenceRule::PeriodType, int freq, int count, const QDate& end, Preferences::Feb29Type = Preferences::Feb29_None);
+		bool               setRecur(KCal::RecurrenceRule::PeriodType, int freq, int count, const KDateTime& end, Preferences::Feb29Type = Preferences::Feb29_None);
 		void               clearRecur();
 		KARecurrence::Type checkRecur() const;
-		OccurType          nextRecurrence(const QDateTime& preDateTime, DateTime& result, int& remainingCount) const;
-		OccurType          previousRecurrence(const QDateTime& afterDateTime, DateTime& result) const;
-		KCal::Alarm*       initKcalAlarm(KCal::Event&, const DateTime&, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
-		KCal::Alarm*       initKcalAlarm(KCal::Event&, int startOffsetSecs, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
-		static void        readAlarms(const KCal::Event&, void* alarmMap);
-		static void        readAlarm(const KCal::Alarm&, AlarmData&);
+		void               checkRepetition() const;
+		OccurType          nextRecurrence(const KDateTime& preDateTime, DateTime& result) const;
+		OccurType          previousRecurrence(const KDateTime& afterDateTime, DateTime& result) const;
+		int                nextWorkRepetition(const KDateTime& pre) const;
+		void               calcTriggerTimes() const;
+		void               calcNextWorkingTime() const;
+		DateTime           nextWorkingTime() const;
+		static bool        convertRepetition(KCal::Event*);
+		KCal::Alarm*       initKCalAlarm(KCal::Event*, const DateTime&, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
+		KCal::Alarm*       initKCalAlarm(KCal::Event*, int startOffsetSecs, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
+		static DateTime    readDateTime(const KCal::Event*, bool dateOnly, DateTime& start);
+		static void        readAlarms(const KCal::Event*, void* alarmMap, bool cmdDisplay = false);
+		static void        readAlarm(const KCal::Alarm*, AlarmData&, bool cmdDisplay = false);
 		inline void        set_deferral(DeferType);
 		inline void        set_reminder(int minutes);
 		inline void        set_archiveReminder();
 
 		QString            mTemplateName;     // alarm template's name, or null if normal event
+		AlarmResource*     mResource;         // resource which owns the event
+		QString            mResourceId;       // saved resource ID (not the resource the event is in)
 		QString            mAudioFile;        // ATTACH: audio file to play
 		QString            mPreAction;        // command to execute before alarm is displayed
 		QString            mPostAction;       // command to execute after alarm window is closed
 		DateTime           mStartDateTime;    // DTSTART and DTEND: start and end time for event
-		QDateTime          mSaveDateTime;     // CREATED: date event was created, or saved in expired calendar
-		QDateTime          mAtLoginDateTime;  // repeat-at-login time
+		KDateTime          mSaveDateTime;     // CREATED: date event was created, or saved in archive calendar
+		KDateTime          mAtLoginDateTime;  // repeat-at-login time
 		DateTime           mDeferralTime;     // extra time to trigger alarm (if alarm or reminder deferred)
+		mutable DateTime   mAllTrigger;       // next trigger time, including reminders, ignoring working hours
+		mutable DateTime   mMainTrigger;      // next trigger time, ignoring reminders and working hours
+		mutable DateTime   mAllWorkTrigger;   // next trigger time, taking account of reminders and working hours
+		mutable DateTime   mMainWorkTrigger;  // next trigger time, ignoring reminders but taking account of working hours
 		DateTime           mDisplayingTime;   // date/time shown in the alarm currently being displayed
 		int                mDisplayingFlags;  // type of alarm which is currently being displayed
 		int                mReminderMinutes;  // how long in advance reminder is to be, or 0 if none
 		int                mArchiveReminderMinutes;  // original reminder period if now expired, or 0 if none
-		int                mDeferDefaultMinutes; // default number of minutes for deferral dialogue, or 0 to select time control
+		int                mDeferDefaultMinutes; // default number of minutes for deferral dialog, or 0 to select time control
 		int                mRevision;         // SEQUENCE: revision number of the original alarm, or 0
 		KARecurrence*      mRecurrence;       // RECUR: recurrence specification, or 0 if none
-		int                mRemainingRecurrences; // remaining number of alarm recurrences including initial time, -1 to repeat indefinitely
 		int                mAlarmCount;       // number of alarms: count of !mMainExpired, mRepeatAtLogin, mDeferral, mReminderMinutes, mDisplaying
 		DeferType          mDeferral;         // whether the alarm is an extra deferred/deferred-reminder alarm
 		unsigned long      mKMailSerialNumber;// if email text, message's KMail serial number
 		int                mTemplateAfterTime;// time not specified: use n minutes after default time, or -1 (applies to templates only)
+		mutable int        mChangeCount;      // >0 = inhibit calling calcTriggerTimes()
+		mutable bool       mChanged;          // true if need to recalculate trigger times while mChangeCount > 0
 		QString            mLogFile;          // alarm output is to be logged to this URL
+		KCalEvent::Status  mCategory;         // event category (active, archived, template, ...)
+		bool               mCancelOnPreActErr;// cancel alarm if pre-alarm action fails
 		bool               mCommandXterm;     // command alarm is to be executed in a terminal window
+		bool               mCommandDisplay;   // command output is to be displayed in an alarm window
+		bool               mSpeak;            // whether to speak the message when the alarm is displayed
 		bool               mCopyToKOrganizer; // KOrganizer should hold a copy of the event
+		bool               mWorkTimeOnly;     // trigger alarm only during working hours
 		bool               mReminderOnceOnly; // the reminder is output only for the first recurrence
 		bool               mMainExpired;      // main alarm has expired (in which case a deferral alarm will exist)
-		bool               mArchiveRepeatAtLogin; // if now expired, original event was repeat-at-login
+		bool               mArchiveRepeatAtLogin; // if now archived, original event was repeat-at-login
 		bool               mArchive;          // event has triggered in the past, so archive it when closed
+		bool               mDisplayingDefer;  // show Defer button (applies to displaying calendar only)
+		bool               mDisplayingEdit;   // show Edit button (applies to displaying calendar only)
 		bool               mEnabled;          // false if event is disabled
 		mutable bool       mUpdated;          // event has been updated but not written to calendar file
 };
