@@ -22,17 +22,14 @@
 #ifndef CONFIGGUIIRMC_H
 #define CONFIGGUIIRMC_H
 
-#include <qcheckbox.h>
-#include <qdom.h>
+#include <QtGui/QCheckBox>
+#include <QtXml/QtXml>
 
 #include "configgui.h"
 #include "connectionwidgets.h"
 
 class KComboBox;
-class KLineEdit;
 class QCheckBox;
-class QPushButton;
-class QSpinBox;
 
 class ConfigGuiIRMC : public ConfigGui
 {
@@ -42,7 +39,7 @@ class ConfigGuiIRMC : public ConfigGui
     ConfigGuiIRMC( const QSync::Member &, QWidget *parent );
 
     void load( const QString &xml );
-    QString save();
+    QString save() const;
 
   protected slots:
     void connectionTypeChanged( int type );
