@@ -5,83 +5,112 @@
 #ifndef _CONFIGURE_DIALOG_PRIVATE_H_
 #define _CONFIGURE_DIALOG_PRIVATE_H_
 
-#include <klineedit.h>
-#include <qcombobox.h>
-#include <qguardedptr.h>
-#include <qptrlist.h>
-#include <qstring.h>
-#include <qvaluelist.h>
-#include <qstringlist.h>
-#include <dcopobject.h>
+#include "kmail_export.h"
 
-#include <kdialogbase.h>
-#include <klistview.h>
+#include <klineedit.h>
+#include <QComboBox>
+#include <QPointer>
+#include <QString>
+
+#include <QStringList>
+#include <QLabel>
+#include <QList>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <QStackedWidget>
+#include <QTreeWidget>
+#include <QHash>
+
+#include <kdialog.h>
 #include <kcmodule.h>
 #include <klocale.h>
-#include <kdepimmacros.h>
+#include "ui_composercryptoconfiguration.h"
+#include "ui_warningconfiguration.h"
+#include "ui_smimeconfiguration.h"
+#include "ui_customtemplates_base.h"
 
 class QPushButton;
 class QLabel;
 class QCheckBox;
-class KURLRequester;
-class KFontChooser;
-class QRadioButton;
-class ColorListBox;
 class QFont;
-class QListViewItem;
 class QTabWidget;
-class QListBox;
-class QButtonGroup;
 class QRegExpValidator;
-class QVBox;
+class QPoint;
+class QGroupBox;
+class QLineEdit;
+class QSpinBox;
+class QListWidget;
+
+class KButtonGroup;
+class KUrlRequester;
+class KFontChooser;
+class KVBox;
 class KMAccount;
-class KMTransportInfo;
 class ListView;
 class ConfigureDialog;
 class KIntSpinBox;
 class SimpleStringListEditor;
 class KConfig;
-class QPoint;
-class ComposerCryptoConfiguration;
-class WarningConfiguration;
 class SMimeConfiguration;
 class TemplatesConfiguration;
 class CustomTemplates;
-class QGroupBox;
-class QVGroupBox;
-#include <qdict.h>
-class QLineEdit;
-class KMMsgTagDesc;
-class KListBox;
+class KMMessageTagDescription;
 class KColorCombo;
 class KFontRequester;
 class KIconButton;
-class KKeyButton;
+class KKeySequenceWidget;
 
-namespace Kpgp {
-  class Config;
-}
 namespace KMail {
   class IdentityDialog;
   class IdentityListView;
+  class IdentityListViewItem;
   class AccountComboBox;
   class FolderRequester;
 }
 namespace Kleo {
   class BackendConfigWidget;
   class CryptoConfig;
-  class CryptoConfigEntry;
+  }
+
+namespace KPIM {
+  class ColorListBox;
 }
 
-class NewIdentityDialog : public KDialogBase
+class WarningConfiguration : public QWidget, public Ui::WarningConfiguration
+{
+public:
+  WarningConfiguration( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+class SMimeConfiguration : public QWidget, public Ui::SMimeConfiguration
+{
+public:
+  SMimeConfiguration( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
+class ComposerCryptoConfiguration : public QWidget, public Ui::ComposerCryptoConfiguration
+{
+public:
+  ComposerCryptoConfiguration( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
+class NewIdentityDialog : public KDialog
 {
   Q_OBJECT
 
 public:
   enum DuplicateMode { Empty, ControlCenter, ExistingEntry };
 
-  NewIdentityDialog( const QStringList & identities,
-                     QWidget *parent=0, const char *name=0, bool modal=true );
+  explicit NewIdentityDialog( const QStringList & identities,
+                     QWidget *parent=0 );
 
   QString identityName() const { return mLineEdit->text(); }
   QString duplicateIdentity() const { return mComboBox->currentText(); }
@@ -106,25 +135,24 @@ private:
 struct LanguageItem
 {
   LanguageItem() {}
-  LanguageItem( const QString & language, const QString & reply=QString::null,
-                const QString & replyAll=QString::null,
-                const QString & forward=QString::null,
-                const QString & indentPrefix=QString::null ) :
+  LanguageItem( const QString & language, const QString & reply=QString(),
+                const QString & replyAll=QString(),
+                const QString & forward=QString(),
+                const QString & indentPrefix=QString() ) :
     mLanguage( language ), mReply( reply ), mReplyAll( replyAll ),
     mForward( forward ), mIndentPrefix( indentPrefix ) {}
 
   QString mLanguage, mReply, mReplyAll, mForward, mIndentPrefix;
 };
 
-typedef QValueList<LanguageItem> LanguageItemList;
+typedef QList<LanguageItem> LanguageItemList;
 
-class NewLanguageDialog : public KDialogBase
+class NewLanguageDialog : public KDialog
 {
   Q_OBJECT
 
   public:
-    NewLanguageDialog( LanguageItemList & suppressedLangs, QWidget *parent=0,
-                       const char *name=0, bool modal=true );
+    explicit NewLanguageDialog( LanguageItemList & suppressedLangs, QWidget *parent=0 );
     QString language() const;
 
   private:
@@ -137,7 +165,7 @@ class LanguageComboBox : public QComboBox
   Q_OBJECT
 
   public:
-    LanguageComboBox( bool rw, QWidget *parent=0, const char *name=0 );
+    LanguageComboBox( QWidget *parent=0 );
     int insertLanguage( const QString & language );
     QString language() const;
     void setLanguage( const QString & language );
@@ -149,10 +177,10 @@ class LanguageComboBox : public QComboBox
 //
 //
 
-class ProfileDialog : public KDialogBase {
+class ProfileDialog : public KDialog {
   Q_OBJECT
 public:
-  ProfileDialog( QWidget * parent=0, const char * name=0, bool modal=false );
+  ProfileDialog( QWidget * parent=0 );
 
 signals:
   void profileSelected( KConfig * profile );
@@ -165,16 +193,16 @@ private:
   void setup();
 
 private:
-  KListView   *mListView;
+  QTreeWidget *mListView;
   QStringList mProfileList;
 };
 
-#include <kdialog.h>
+#include <kvbox.h>
 class ConfigModule : public KCModule {
   Q_OBJECT
 public:
-  ConfigModule( QWidget * parent=0, const char * name=0 )
-     : KCModule ( parent, name )
+  explicit ConfigModule( const KComponentData &instance, QWidget *parent=0 )
+     : KCModule ( instance, parent )
      {}
   ~ConfigModule() {}
 
@@ -200,15 +228,15 @@ signals:
 class ConfigModuleTab : public QWidget {
   Q_OBJECT
 public:
-   ConfigModuleTab( QWidget *parent=0, const char* name=0 )
-      :QWidget( parent, name )
+   ConfigModuleTab( QWidget *parent=0 )
+      : QWidget( parent )
       {}
   ~ConfigModuleTab() {}
   void load();
   virtual void save() = 0;
   void defaults();
   // the below are optional
-  virtual void installProfile(){}
+  virtual void installProfile( KConfig* ) {};
 signals:
    // forwarded to the ConfigModule
   void changed(bool);
@@ -231,10 +259,10 @@ private:
  * ConfigModuleWithTabs represents a kcm with several tabs.
  * It simply forwards load and save operations to all tabs.
  */
-class ConfigModuleWithTabs : public ConfigModule {
+class KMAIL_EXPORT ConfigModuleWithTabs : public ConfigModule {
   Q_OBJECT
 public:
-  ConfigModuleWithTabs( QWidget * parent=0, const char * name=0 );
+  explicit ConfigModuleWithTabs( const KComponentData &instance, QWidget *parent=0 );
    ~ConfigModuleWithTabs() {}
 
   // don't reimplement any of those methods
@@ -258,10 +286,10 @@ private:
 //
 //
 
-class KDE_EXPORT IdentityPage : public ConfigModule {
+class KMAIL_EXPORT IdentityPage : public ConfigModule {
   Q_OBJECT
 public:
-  IdentityPage( QWidget * parent=0, const char * name=0 );
+  explicit IdentityPage( const KComponentData &instance, QWidget *parent = 0 );
   ~IdentityPage() {}
 
   QString helpAnchor() const;
@@ -269,20 +297,17 @@ public:
   void load();
   void save();
 
-public slots:
-  void slotUpdateTransportCombo( const QStringList & );
-
 private slots:
   void slotNewIdentity();
   void slotModifyIdentity();
   void slotRemoveIdentity();
   /** Connected to @p mRenameButton's clicked() signal. Just does a
-      KListView::rename on the selected item */
+      QTreeWidget::editItem on the selected item */
   void slotRenameIdentity();
   /** connected to @p mIdentityList's renamed() signal. Validates the
-      new name and sets it in the KPIM::IdentityManager */
-  void slotRenameIdentity( QListViewItem *, const QString &, int );
-  void slotContextMenu( KListView*, QListViewItem *, const QPoint & );
+      new name and sets it in the KPIMIdentities::IdentityManager */
+  void slotRenameIdentity( KMail::IdentityListViewItem *, const QString & );
+  void slotContextMenu( KMail::IdentityListViewItem *, const QPoint & );
   void slotSetAsDefault();
   void slotIdentitySelectionChanged();
 
@@ -290,14 +315,14 @@ private: // methods
   void refreshList();
 
 private: // data members
-  KMail::IdentityDialog   * mIdentityDialog;
-  int            mOldNumberOfIdentities;
+  KMail::IdentityDialog   *mIdentityDialog;
+  int                      mOldNumberOfIdentities;
 
-  KMail::IdentityListView * mIdentityList;
-  QPushButton             * mModifyButton;
-  QPushButton             * mRenameButton;
-  QPushButton             * mRemoveButton;
-  QPushButton             * mSetAsDefaultButton;
+  KMail::IdentityListView *mIdentityList;
+  QPushButton             *mModifyButton;
+  QPushButton             *mRenameButton;
+  QPushButton             *mRemoveButton;
+  QPushButton             *mSetAsDefaultButton;
 };
 
 
@@ -311,44 +336,29 @@ private: // data members
 class AccountsPageSendingTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AccountsPageSendingTab( QWidget * parent=0, const char * name=0 );
+  AccountsPageSendingTab( QWidget * parent=0 );
+  virtual ~AccountsPageSendingTab();
   QString helpAnchor() const;
   void save();
 
-signals:
-  void transportListChanged( const QStringList & );
-
-private slots:
-  void slotTransportSelected();
-  void slotAddTransport();
-  void slotModifySelectedTransport();
-  void slotRemoveSelectedTransport();
-  void slotSetDefaultTransport();
-
 private:
   virtual void doLoadFromGlobalSettings();
   virtual void doLoadOther();
   //FIXME virtual void doResetToDefaultsOther();
 
 private:
-  ListView    *mTransportList;
-  QPushButton *mModifyTransportButton;
-  QPushButton *mRemoveTransportButton;
-  QPushButton *mSetDefaultTransportButton;
   QCheckBox   *mConfirmSendCheck;
   QComboBox   *mSendOnCheckCombo;
   QComboBox   *mSendMethodCombo;
   QComboBox   *mMessagePropertyCombo;
   QLineEdit   *mDefaultDomainEdit;
-
-  QPtrList< KMTransportInfo > mTransportInfoList;
 };
 
 
 class AccountsPageReceivingTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AccountsPageReceivingTab( QWidget * parent=0, const char * name=0 );
+  AccountsPageReceivingTab( QWidget * parent=0 );
   ~AccountsPageReceivingTab();
   QString helpAnchor() const;
   void save();
@@ -362,7 +372,6 @@ private slots:
   void slotModifySelectedAccount();
   void slotRemoveSelectedAccount();
   void slotEditNotifications();
-  void slotTweakAccountList();
 
 private:
   virtual void doLoadFromGlobalSettings();
@@ -379,20 +388,20 @@ private:
   QCheckBox     *mCheckmailStartupCheck;
   QPushButton   *mOtherNewMailActionsButton;
 
-  QValueList< QGuardedPtr<KMAccount> > mAccountsToDelete;
-  QValueList< QGuardedPtr<KMAccount> > mNewAccounts;
+  QList< QPointer<KMAccount> > mAccountsToDelete;
+  QList< QPointer<KMAccount> > mNewAccounts;
   struct ModifiedAccountsType {
-    QGuardedPtr< KMAccount > oldAccount;
-    QGuardedPtr< KMAccount > newAccount;
+    QPointer< KMAccount > oldAccount;
+    QPointer< KMAccount > newAccount;
   };
-  // ### make this value-based:
-  QValueList< ModifiedAccountsType* >  mModifiedAccounts;
+  // ### make this a qptrlist:
+  QList< ModifiedAccountsType* >  mModifiedAccounts;
 };
 
-class KDE_EXPORT AccountsPage : public ConfigModuleWithTabs {
+class KMAIL_EXPORT AccountsPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  AccountsPage( QWidget * parent=0, const char * name=0 );
+  explicit AccountsPage( const KComponentData &instance, QWidget *parent=0 );
   QString helpAnchor() const;
 
 
@@ -401,7 +410,6 @@ public:
   typedef AccountsPageReceivingTab ReceivingTab;
 
 signals:
-  void transportListChanged( const QStringList & );
   void accountListChanged( const QStringList & );
 
 private:
@@ -419,7 +427,7 @@ private:
 class AppearancePageFontsTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageFontsTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageFontsTab( QWidget * parent=0 );
   QString helpAnchor() const;
   void save();
 
@@ -446,7 +454,7 @@ private:
 class AppearancePageColorsTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageColorsTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageColorsTab( QWidget * parent=0 );
   QString helpAnchor() const;
   void save();
 
@@ -459,14 +467,15 @@ private:
 
 private:
   QCheckBox    *mCustomColorCheck;
-  ColorListBox *mColorList;
+  KPIM::ColorListBox *mColorList;
   QCheckBox    *mRecycleColorCheck;
+  QSpinBox     *mCloseToQuotaThreshold;
 };
 
 class AppearancePageLayoutTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageLayoutTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageLayoutTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -478,16 +487,22 @@ private:
   //FIXME virtual void doResetToDefaultsOther();
 
 private: // data
-  QButtonGroup *mFolderListGroup;
-  QButtonGroup *mMIMETreeLocationGroup;
-  QButtonGroup *mMIMETreeModeGroup;
-  QButtonGroup *mReaderWindowModeGroup;
+  QButtonGroup  *mFolderListGroup;
+  QGroupBox     *mFolderListGroupBox;
+  QButtonGroup  *mMIMETreeLocationGroup;
+  QGroupBox     *mMIMETreeLocationGroupBox;
+  QButtonGroup  *mMIMETreeModeGroup;
+  QGroupBox     *mMIMETreeModeGroupBox;
+  QButtonGroup  *mReaderWindowModeGroup;
+  QGroupBox     *mReaderWindowModeGroupBox;
+  QCheckBox     *mFavoriteFolderViewCB;
+  QCheckBox     *mFolderQuickSearchCB;
 };
 
 class AppearancePageHeadersTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageHeadersTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageHeadersTab( QWidget * parent=0 );
 
   QString helpAnchor() const;
 
@@ -501,19 +516,20 @@ private: // methods
   void setDateDisplay( int id, const QString & format );
 
 private: // data
+  QCheckBox    *mShowQuickSearch;
   QCheckBox    *mMessageSizeCheck;
   QCheckBox    *mAttachmentCheck;
   QCheckBox    *mNestedMessagesCheck;
   QCheckBox    *mCryptoIconsCheck;
-  QButtonGroup *mNestingPolicy;
-  QButtonGroup *mDateDisplay;
+  KButtonGroup *mNestingPolicy;
+  KButtonGroup *mDateDisplay;
   QLineEdit    *mCustomDateFormatEdit;
 };
 
 class AppearancePageReaderTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageReaderTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageReaderTab( QWidget * parent=0 );
 
   QString helpAnchor() const;
 
@@ -542,7 +558,7 @@ private: // data
 class AppearancePageSystemTrayTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePageSystemTrayTab( QWidget * parent=0, const char * name=0 );
+  AppearancePageSystemTrayTab( QWidget * parent=0 );
 
   QString helpAnchor() const;
 
@@ -554,13 +570,96 @@ private:
 
 private: // data
   QCheckBox    *mSystemTrayCheck;
-  QButtonGroup *mSystemTrayGroup;
+  KButtonGroup *mSystemTrayGroup;
 };
 
-class KDE_EXPORT AppearancePage : public ConfigModuleWithTabs {
+/**Configuration tab in the appearance page for modifying the available set of
++message tags*/
+class AppearancePageMessageTagTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  AppearancePage( QWidget * parent=0, const char * name=0 );
+  AppearancePageMessageTagTab( QWidget * parent=0);
+  ~AppearancePageMessageTagTab();
+
+  QString helpAnchor() const;
+
+  void save();
+  void installProfile( KConfig * profile );
+
+public slots:
+  /**Enables/disables Add button according to whether @p aText is empty.
+  Connected to signal of the line edit widget for adding tags
+  @param aText String to change add button according to
+  */
+  void slotAddLineTextChanged( const QString &aText );
+  /**Creates a generic tag with the visible name from the line edit widget for
+    adding tags. Adds it to the end of the list and selects. Empties the line
+    edit widget*/
+  void slotAddNewTag();
+  /**Removes the currently selected text in the list box.*/
+  void slotRemoveTag();
+  /**Increases the currently selected tag's priority and handles related visual
+  changes*/
+  void slotMoveTagUp();
+  /**Decreases the currently selected tag's priority and handles related visual
+  changes*/
+  void slotMoveTagDown();
+
+private slots:
+  /*Handles necessary processing when the selection in the edit box changes.
+  Records the unselected tag's information, and applies visual changes
+  necessary depending on the description of the new tag. Private since doesn't
+  change the selection of the edit box itself*/
+  void slotSelectionChanged();
+  /*This slot is necessary so that apply button is not activated when we are
+  only applying visual changes after selecting a new tag in the list box*/
+  void slotEmitChangeCheck();
+  /*Transfers the tag settings from the widgets to the internal data structures.
+  Private since passing a wrong parameter modifies another tag's data*/
+  void slotRecordTagSettings( int aIndex );
+  /*Transfers the tag settings from the internal data structures to the widgets.
+  Private since passing a wrong parameter visualizes another tag's data*/
+  void slotUpdateTagSettingWidgets( int aIndex );
+  /*Transfers changes in the tag name edit box to the list box for tags. Private
+  since calling externally decouples the name in the list box from name edit box*/
+  void slotNameLineTextChanged( const QString & );
+
+private:
+  virtual void doLoadFromGlobalSettings();
+  void swapTagsInListBox( const int first, const int second );
+
+private: // data
+  QLineEdit *mTagNameLineEdit, *mTagAddLineEdit;
+  QPushButton *mTagAddButton, *mTagRemoveButton,
+              *mTagUpButton, *mTagDownButton;
+
+  QListWidget *mTagListBox;
+
+  QCheckBox *mTextColorCheck,
+            *mTextFontCheck, *mInToolbarCheck;
+
+  QGroupBox *mTagsGroupBox, *mTagSettingGroupBox;
+
+  KColorCombo *mTextColorCombo;
+
+  KFontRequester *mFontRequester;
+
+  KIconButton *mIconButton;
+
+  KKeySequenceWidget *mKeySequenceWidget;
+
+  QHash<QString,KMMessageTagDescription*> *mMsgTagDict;
+  QList<KMMessageTagDescription*> *mMsgTagList;
+  /*If true, changes to the widgets activate the Apply button*/
+  bool mEmitChanges;
+  /*Used to safely call slotRecordTagSettings when the selection in
+    list box changes*/
+  int mPreviousTag;
+};
+class KMAIL_EXPORT AppearancePage : public ConfigModuleWithTabs {
+  Q_OBJECT
+public:
+  explicit AppearancePage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -571,6 +670,7 @@ public:
   typedef AppearancePageHeadersTab HeadersTab;
   typedef AppearancePageReaderTab ReaderTab;
   typedef AppearancePageSystemTrayTab SystemTrayTab;
+  typedef AppearancePageMessageTagTab MessageTagTab;
 
 private:
   FontsTab      *mFontsTab;
@@ -579,6 +679,7 @@ private:
   HeadersTab    *mHeadersTab;
   ReaderTab     *mReaderTab;
   SystemTrayTab *mSystemTrayTab;
+  MessageTagTab *mMessageTagTab;
 };
 
 //
@@ -590,7 +691,7 @@ private:
 class ComposerPageGeneralTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageGeneralTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageGeneralTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -604,6 +705,8 @@ private:
 
 private:
   QCheckBox     *mAutoAppSignFileCheck;
+  QCheckBox     *mTopQuoteCheck;
+  QCheckBox     *mDashDashCheck;
   QCheckBox     *mSmartQuoteCheck;
   QCheckBox     *mAutoRequestMDNCheck;
   QCheckBox	*mShowRecentAddressesInComposer;
@@ -611,13 +714,13 @@ private:
   KIntSpinBox   *mWrapColumnSpin;
   KIntSpinBox   *mAutoSave;
   QCheckBox     *mExternalEditorCheck;
-  KURLRequester *mEditorRequester;
+  KUrlRequester *mEditorRequester;
 };
 
 class ComposerPagePhrasesTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPagePhrasesTab( QWidget * parent=0, const char * name=0 );
+  ComposerPagePhrasesTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -648,7 +751,7 @@ private:
 class ComposerPageTemplatesTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageTemplatesTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageTemplatesTab( QWidget * parent = 0 );
   QString helpAnchor() const;
 
   void save();
@@ -665,7 +768,7 @@ private:
 class ComposerPageCustomTemplatesTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageCustomTemplatesTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageCustomTemplatesTab( QWidget * parent = 0 );
   QString helpAnchor() const;
 
   void save();
@@ -682,7 +785,7 @@ private:
 class ComposerPageSubjectTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageSubjectTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageSubjectTab( QWidget * parent = 0 );
   QString helpAnchor() const;
 
   void save();
@@ -700,7 +803,7 @@ private:
 class ComposerPageCharsetTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageCharsetTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageCharsetTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -721,7 +824,7 @@ private:
 class ComposerPageHeadersTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageHeadersTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageHeadersTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -742,7 +845,7 @@ private:
   QCheckBox   *mCreateOwnMessageIdCheck;
   QLineEdit   *mMessageIdSuffixEdit;
   QRegExpValidator *mMessageIdSuffixValidator;
-  QListView   *mTagList;
+  ListView    *mTagList;
   QPushButton *mRemoveHeaderButton;
   QLineEdit   *mTagNameEdit;
   QLineEdit   *mTagValueEdit;
@@ -753,7 +856,7 @@ private:
 class ComposerPageAttachmentsTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  ComposerPageAttachmentsTab( QWidget * parent=0, const char * name=0 );
+  ComposerPageAttachmentsTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -771,10 +874,10 @@ private:
   SimpleStringListEditor *mAttachWordsListEditor;
 };
 
-class KDE_EXPORT ComposerPage : public ConfigModuleWithTabs {
+class KMAIL_EXPORT ComposerPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  ComposerPage( QWidget * parent=0, const char * name=0 );
+  explicit ComposerPage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -808,7 +911,7 @@ private:
 class SecurityPageGeneralTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  SecurityPageGeneralTab( QWidget * parent=0, const char * name=0 );
+  SecurityPageGeneralTab( QWidget * parent=0 );
   QString helpAnchor() const;
 
   void save();
@@ -826,13 +929,20 @@ private:
   QButtonGroup *mMDNGroup;
   QButtonGroup *mOrigQuoteGroup;
   QCheckBox    *mAutomaticallyImportAttachedKeysCheck;
+  QCheckBox    *mAlwaysDecrypt;
+  QString       mHtmlWhatsThis;
+  QString       mExternalWhatsThis;
+  QString       mReceiptWhatsThis;
+
+private slots:
+    void slotLinkClicked( const QString & link );
 };
 
 
 class SecurityPageComposerCryptoTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  SecurityPageComposerCryptoTab( QWidget * parent=0, const char * name=0 );
+  SecurityPageComposerCryptoTab( QWidget * parent=0 );
 
   QString helpAnchor() const;
 
@@ -851,7 +961,7 @@ private:
 class SecurityPageWarningTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  SecurityPageWarningTab( QWidget * parent=0, const char * name=0 );
+  SecurityPageWarningTab( QWidget * parent=0 );
 
   QString helpAnchor() const;
 
@@ -870,16 +980,14 @@ private:
   WarningConfiguration* mWidget;
 };
 
-class SecurityPageSMimeTab : public ConfigModuleTab, public DCOPObject {
+class SecurityPageSMimeTab : public ConfigModuleTab {
   Q_OBJECT
-  K_DCOP
 public:
-  SecurityPageSMimeTab( QWidget * parent=0, const char * name=0 );
+  SecurityPageSMimeTab( QWidget * parent=0 );
   ~SecurityPageSMimeTab();
 
   QString helpAnchor() const;
 
-  // Can't use k_dcop here. dcopidl can't parse this file, dcopidlng has a namespace bug.
   void save();
   void installProfile( KConfig * profile );
 
@@ -900,7 +1008,7 @@ class SecurityPageCryptPlugTab : public ConfigModuleTab
 {
   Q_OBJECT
 public:
-  SecurityPageCryptPlugTab( QWidget * parent = 0, const char* name = 0 );
+  SecurityPageCryptPlugTab( QWidget * parent = 0 );
   ~SecurityPageCryptPlugTab();
 
   QString helpAnchor() const;
@@ -915,10 +1023,10 @@ private:
   Kleo::BackendConfigWidget * mBackendConfig;
 };
 
-class KDE_EXPORT SecurityPage : public ConfigModuleWithTabs {
+class KMAIL_EXPORT SecurityPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  SecurityPage( QWidget * parent=0, const char * name=0 );
+  explicit SecurityPage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -949,7 +1057,7 @@ private:
 class MiscPageFolderTab : public ConfigModuleTab {
   Q_OBJECT
 public:
-  MiscPageFolderTab( QWidget * parent=0, const char * name=0 );
+  MiscPageFolderTab( QWidget * parent=0 );
 
   void save();
  QString helpAnchor() const;
@@ -966,9 +1074,6 @@ private:
   QComboBox    *mMailboxPrefCombo;
   QComboBox    *mActionEnterFolder;
   QCheckBox    *mEmptyTrashCheck;
-#ifdef HAVE_INDEXLIB
-  QCheckBox    *mIndexingEnabled;
-#endif
   QCheckBox    *mDelayedMarkAsRead;
   KIntSpinBox  *mDelayedMarkTime;
   QCheckBox    *mShowPopupAfterDnD;
@@ -979,7 +1084,7 @@ private:
 class MiscPageGroupwareTab : public ConfigModuleTab  {
   Q_OBJECT
 public:
-  MiscPageGroupwareTab( QWidget * parent=0, const char * name=0 );
+  MiscPageGroupwareTab( QWidget * parent=0 );
   void save();
   QString helpAnchor() const;
 
@@ -995,21 +1100,20 @@ private:
   QCheckBox* mEnableImapResCB;
 
   QWidget* mBox;
-  QVBox* gBox;
+  KVBox* gBox;
 
   QComboBox* mStorageFormatCombo;
   QComboBox* mLanguageCombo;
 
   QLabel* mFolderComboLabel;
-  QWidgetStack* mFolderComboStack;
+  QStackedWidget* mFolderComboStack;
   KMail::FolderRequester* mFolderCombo; // in the widgetstack
   KMail::AccountComboBox* mAccountCombo; // in the widgetstack
 
   QCheckBox* mHideGroupwareFolders;
   QCheckBox* mOnlyShowGroupwareFolders;
-  QCheckBox* mAutoResCB;
-  QCheckBox* mAutoDeclConflCB;
-  QCheckBox* mAutoDeclRecurCB;
+  QCheckBox* mSyncImmediately;
+  QCheckBox* mDeleteInvitations;
 
   QCheckBox* mLegacyMangleFromTo;
   QCheckBox* mLegacyBodyInvites;
@@ -1017,10 +1121,10 @@ private:
   QCheckBox* mAutomaticSending;
 };
 
-class KDE_EXPORT MiscPage : public ConfigModuleWithTabs {
+class KMAIL_EXPORT MiscPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  MiscPage( QWidget * parent=0, const char * name=0 );
+  explicit MiscPage( const KComponentData &instance, QWidget *parent=0 );
   QString helpAnchor() const;
 
   typedef MiscPageFolderTab FolderTab;
@@ -1037,13 +1141,12 @@ private:
 //
 //
 
-class ListView : public KListView {
+class ListView : public QTreeWidget {
   Q_OBJECT
 public:
-  ListView( QWidget *parent=0, const char *name=0, int visibleItem=10 );
+  explicit ListView( QWidget *parent=0 );
   void resizeColums();
 
-  void setVisibleItem( int visibleItem, bool updateSize=true );
   virtual QSize sizeHint() const;
 
 protected:
