@@ -20,30 +20,32 @@
 
 #include "kmfolder.h"
 #include "kmfoldermgr.h"
-#include "kmfolderseldlg.h"
+#include "folderselectiondialog.h"
 #include "kmmainwidget.h"
 #include "kmailicalifaceimpl.h"
 #include "folderstorage.h"
 #include "kmfolderimap.h"
 #include "kmfoldercachedimap.h"
 #include "kmacctcachedimap.h"
-#include "folderviewtooltip.h"
 #include "korghelper.h"
 
 #include <libkdepim/maillistdrag.h>
-#include <libkdepim/kaddrbook.h>
+#include <libkdepim/kaddrbookexternal.h>
 
-#include <dcopclient.h>
+#include <kcolorscheme.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <kinputdialog.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kio/global.h>
 
-#include <qheader.h>
-#include <qtimer.h>
+//#include <QHelpEvent>
+#include <QtCore/QTimer>
+#include <QtGui/QToolTip>
+#include <QDBusConnection>
+#include <QDBusInterface>
 
 #include <cassert>
 
@@ -58,19 +60,67 @@ FavoriteFolderViewItem::FavoriteFolderViewItem(FavoriteFolderView * parent, cons
   connect( folder, SIGNAL(nameChanged()), SLOT(nameChanged()) );
   connect( folder, SIGNAL(iconsChanged()), SLOT(slotIconsChanged()) );
 
-  connect( folder, SIGNAL(msgAdded(KMFolder*,Q_UINT32)), SLOT(updateCount()) );
+  connect( folder, SIGNAL(msgAdded(KMFolder*,quint32)), SLOT(updateCount()) );
   connect( folder, SIGNAL(numUnreadMsgsChanged(KMFolder*)), SLOT(updateCount()) );
   connect( folder, SIGNAL(msgRemoved(KMFolder*)), SLOT(updateCount()) );
   connect( folder, SIGNAL(folderSizeChanged( KMFolder* )), SLOT(updateCount()) );
 
-  QTimer::singleShot( 0, this, SLOT(updateCount()) );
-
+  updateCount();
   if ( unreadCount() > 0 )
     setPixmap( 0, unreadIcon( iconSize() ) );
   else
     setPixmap( 0, normalIcon( iconSize() ) );
 }
 
+void FavoriteFolderViewItem::updateCount()
+{
+  // FIXME: share with KMFolderTree
+  if ( !folder() ) {
+    setTotalCount( -1 );
+    return;
+  }
+
+  // get the unread count
+  int count = 0;
+  if (folder() && folder()->noContent()) // always empty
+    count = -1;
+  else {
+    count = folder()->countUnread();
+  }
+   bool repaint = false;
+  if ( unreadCount() != count ) {
+     adjustUnreadCount( count );
+     repaint = true;
+  }
+
+  // get the total-count
+  if ( folder()->noContent() )
+    count = -1;
+  else {
+    // get the cached count if the folder is not open
+    count = folder()->count( !folder()->isOpened() );
+  }
+  if ( count != totalCount() ) {
+    setTotalCount(count);
+    repaint = true;
+  }
+
+  if ( !folder()->noContent() ) {
+    qint64 size = folder()->storage()->folderSize();
+    if ( size != folderSize() ) {
+      setFolderSize( size );
+      repaint = true;
+    }
+  }
+
+  if ( folderIsCloseToQuota() != folder()->storage()->isCloseToQuota() )
+    setFolderIsCloseToQuota( folder()->storage()->isCloseToQuota() );
+
+  if (repaint) {
+    this->repaint();
+  }
+}
+
 void FavoriteFolderViewItem::nameChanged()
 {
   QString txt = text( 0 );
@@ -79,11 +129,11 @@ void FavoriteFolderViewItem::nameChanged()
   mOldName = folder()->label();
 }
 
-QValueList<FavoriteFolderView*> FavoriteFolderView::mInstances;
+
+QList<FavoriteFolderView*> FavoriteFolderView::mInstances;
 
 FavoriteFolderView::FavoriteFolderView( KMMainWidget *mainWidget, QWidget * parent) :
     FolderTreeBase( mainWidget, parent ),
-    mContextMenuItem( 0 ),
     mReadingConfig( false )
 {
   assert( mainWidget );
@@ -93,17 +143,17 @@ FavoriteFolderView::FavoriteFolderView( KMMainWidget *mainWidget, QWidget * pare
   setDragEnabled( true );
   setAcceptDrops( true );
   setRootIsDecorated( false );
-  setSelectionModeExt( KListView::Single );
+  setSelectionMode( Q3ListView::Single );
   setSorting( -1 );
   setShowSortIndicator( false );
 
   connect( this, SIGNAL(selectionChanged()), SLOT(selectionChanged()) );
-  connect( this, SIGNAL(clicked(QListViewItem*)), SLOT(itemClicked(QListViewItem*)) );
-  connect( this, SIGNAL(dropped(QDropEvent*,QListViewItem*)), SLOT(dropped(QDropEvent*,QListViewItem*)) );
-  connect( this, SIGNAL(contextMenuRequested(QListViewItem*, const QPoint &, int)),
-           SLOT(contextMenu(QListViewItem*,const QPoint&)) );
+  connect( this, SIGNAL(mouseButtonClicked(int,Q3ListViewItem*,const QPoint&,int)),
+           SLOT(itemClicked(int,Q3ListViewItem*)) );
+  connect( this, SIGNAL(dropped(QDropEvent*,Q3ListViewItem*)), SLOT(dropped(QDropEvent*,Q3ListViewItem*)) );
+  connect( this, SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint &, int)),
+           SLOT(contextMenu(Q3ListViewItem*,const QPoint&)) );
   connect( this, SIGNAL(moved()), SLOT(notifyInstancesOnChange()) );
-  connect( this, SIGNAL(triggerRefresh()), SLOT(refresh()) );
 
   connect( kmkernel->folderMgr(), SIGNAL(changed()), SLOT(initializeFavorites()) );
   connect( kmkernel->dimapFolderMgr(), SIGNAL(changed()), SLOT(initializeFavorites()) );
@@ -119,24 +169,22 @@ FavoriteFolderView::FavoriteFolderView( KMMainWidget *mainWidget, QWidget * pare
   f.setItalic( true );
   setFont( f );
 
-  new FolderViewToolTip( this );
-
   mInstances.append( this );
 }
 
 FavoriteFolderView::~FavoriteFolderView()
 {
-  mInstances.remove( this );
+  mInstances.removeAll( this );
 }
 
 void FavoriteFolderView::readConfig()
 {
   mReadingConfig = true;
   clear();
-  QValueList<int> folderIds = GlobalSettings::self()->favoriteFolderIds();
+  QList<int> folderIds = GlobalSettings::self()->favoriteFolderIds();
   QStringList folderNames = GlobalSettings::self()->favoriteFolderNames();
-  QListViewItem *afterItem = 0;
-  for ( uint i = 0; i < folderIds.count(); ++i ) {
+  Q3ListViewItem *afterItem = 0;
+  for ( int i = 0; i < folderIds.count(); ++i ) {
     KMFolder *folder = kmkernel->folderMgr()->findById( folderIds[i] );
     if ( !folder )
       folder = kmkernel->imapFolderMgr()->findById( folderIds[i] );
@@ -161,9 +209,9 @@ void FavoriteFolderView::readConfig()
 
 void FavoriteFolderView::writeConfig()
 {
-  QValueList<int> folderIds;
+  QList<int> folderIds;
   QStringList folderNames;
-  for ( QListViewItemIterator it( this ); it.current(); ++it ) {
+  for ( Q3ListViewItemIterator it( this ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     folderIds << fti->folder()->id();
     folderNames << fti->text( 0 );
@@ -182,7 +230,7 @@ bool FavoriteFolderView::acceptDrag(QDropEvent * e) const
   return FolderTreeBase::acceptDrag( e );
 }
 
-KMFolderTreeItem* FavoriteFolderView::addFolder(KMFolder * folder, const QString &name, QListViewItem *after)
+KMFolderTreeItem* FavoriteFolderView::addFolder(KMFolder * folder, const QString &name, Q3ListViewItem *after)
 {
   if ( !folder )
     return 0;
@@ -192,7 +240,6 @@ KMFolderTreeItem* FavoriteFolderView::addFolder(KMFolder * folder, const QString
   else
     item->moveItem( lastItem() );
   ensureItemVisible( item );
-  insertIntoFolderToItemMap( folder, item );
   notifyInstancesOnChange();
   return item;
 }
@@ -204,9 +251,17 @@ void FavoriteFolderView::selectionChanged()
     return;
   KMFolderTree *ft = mainWidget()->folderTree();
   assert( ft );
-  assert( fti );
   ft->showFolder( fti->folder() );
-  handleGroupwareFolder( fti );
+}
+
+static void selectKontactPlugin( const QString &plugin )
+{
+  QDBusInterface *kontact = new QDBusInterface( "org.kde.kontact",
+      "/KontactInterface", "org.kde.kontact.KontactInterface",
+       QDBusConnection::sessionBus() );
+  if ( kontact->isValid() )
+    kontact->call( "selectPlugin", plugin );
+  delete kontact;
 }
 
 void FavoriteFolderView::handleGroupwareFolder( KMFolderTreeItem *fti )
@@ -215,53 +270,48 @@ void FavoriteFolderView::handleGroupwareFolder( KMFolderTreeItem *fti )
     return;
   switch ( fti->folder()->storage()->contentsType() ) {
     case KMail::ContentsTypeContact:
-      KAddrBookExternal::openAddressBook( this );
+      KPIM::KAddrBookExternal::openAddressBook( this );
       break;
     case KMail::ContentsTypeNote:
-    {
-      QByteArray arg;
-      QDataStream s( arg, IO_WriteOnly );
-      s << QString( "kontact_knotesplugin" );
-      kapp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(QString)", arg );
+      selectKontactPlugin( "kontact_knotesplugin" );
       break;
-    }
     case KMail::ContentsTypeCalendar:
     case KMail::ContentsTypeTask:
     case KMail::ContentsTypeJournal:
     {
       KMail::KorgHelper::ensureRunning();
-      QByteArray arg;
-      QDataStream s( arg, IO_WriteOnly );
+      QString plugin;
       switch ( fti->folder()->storage()->contentsType() ) {
         case KMail::ContentsTypeCalendar:
-          s << QString( "kontact_korganizerplugin" ); break;
+          plugin = QLatin1String( "kontact_korganizerplugin" ); break;
         case KMail::ContentsTypeTask:
-          s << QString( "kontact_todoplugin" ); break;
+          plugin = QLatin1String( "kontact_todoplugin" ); break;
         case KMail::ContentsTypeJournal:
-          s << QString( "kontact_journalplugin" ); break;
+          plugin = QLatin1String( "kontact_journalplugin" ); break;
         default: assert( false );
       }
-      kapp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(QString)", arg );
+      selectKontactPlugin( plugin );
       break;
     }
     default: break;
   }
 }
 
-void FavoriteFolderView::itemClicked(QListViewItem * item)
+void FavoriteFolderView::itemClicked(int button, Q3ListViewItem * item)
 {
   if ( !item ) return;
   if ( !item->isSelected() )
     item->setSelected( true );
   item->repaint();
-  handleGroupwareFolder( static_cast<KMFolderTreeItem*>( item ) );
+  if ( button & Qt::LeftButton )
+    handleGroupwareFolder( static_cast<KMFolderTreeItem*>( item ) );
 }
 
 void FavoriteFolderView::folderTreeSelectionChanged(KMFolder * folder)
 {
   blockSignals( true );
   bool found = false;
-  for ( QListViewItemIterator it( this ); it.current(); ++it ) {
+  for ( Q3ListViewItemIterator it( this ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     if ( fti->folder() == folder && !fti->isSelected() ) {
       fti->setSelected( true );
@@ -277,33 +327,32 @@ void FavoriteFolderView::folderTreeSelectionChanged(KMFolder * folder)
   blockSignals( false );
   if ( !found ) {
     clearSelection();
-    setSelectionModeExt( KListView::NoSelection );
-    setSelectionModeExt( KListView::Single );
+    setSelectionMode( Q3ListView::NoSelection );
+    setSelectionMode( Q3ListView::Single );
   }
 }
 
 void FavoriteFolderView::folderRemoved(KMFolder * folder)
 {
-  QValueList<KMFolderTreeItem*> delItems;
-  for ( QListViewItemIterator it( this ); it.current(); ++it ) {
+  QList<KMFolderTreeItem *> delItems;
+  for ( Q3ListViewItemIterator it( this ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     if ( fti->folder() == folder )
       delItems << fti;
     if ( fti == mContextMenuItem )
       mContextMenuItem = 0;
   }
-  for ( uint i = 0; i < delItems.count(); ++i )
+  for ( int i = 0; i < delItems.count(); ++i )
     delete delItems[i];
-  removeFromFolderToItemMap(folder);
 }
 
-void FavoriteFolderView::dropped(QDropEvent * e, QListViewItem * after)
+void FavoriteFolderView::dropped(QDropEvent * e, Q3ListViewItem * after)
 {
-  QListViewItem* afterItem = after;
+  Q3ListViewItem* afterItem = after;
   KMFolderTree *ft = mainWidget()->folderTree();
   assert( ft );
   if ( e->source() == ft->viewport() && e->provides( "application/x-qlistviewitem" ) ) {
-    for ( QListViewItemIterator it( ft ); it.current(); ++it ) {
+    for ( Q3ListViewItemIterator it( ft ); it.current(); ++it ) {
       if ( !it.current()->isSelected() )
         continue;
       KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
@@ -315,33 +364,73 @@ void FavoriteFolderView::dropped(QDropEvent * e, QListViewItem * after)
   }
 }
 
-void FavoriteFolderView::contextMenu(QListViewItem * item, const QPoint & point)
+void FavoriteFolderView::contextMenu(Q3ListViewItem * item, const QPoint & point)
 {
   KMFolderTree *ft = mainWidget()->folderTree();
   assert( ft );
   KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( item );
   mContextMenuItem = fti;
-  KPopupMenu contextMenu;
+  KMenu contextMenu;
   if ( fti && fti->folder() ) {
-    contextMenu.insertItem( SmallIconSet("editdelete"), i18n("Remove From Favorites"),
-                            this, SLOT(removeFolder()) );
-    contextMenu.insertItem( SmallIconSet("edit"), i18n("Rename Favorite"), this, SLOT(renameFolder()) );
-    contextMenu.insertSeparator();
+    contextMenu.addAction( SmallIcon( "edit-delete" ), i18n( "Remove From Favorites" ),
+                           this, SLOT( removeFolder() ) );
+    contextMenu.addAction( SmallIcon( "edit-rename" ), i18n( "Rename Favorite..." ),
+                           this, SLOT( renameFolder() ) );
+    contextMenu.addSeparator();
+
+    contextMenu.addAction( mainWidget()->action( "mark_all_as_read" ) );
+    if ( fti->folder()->folderType() == KMFolderTypeImap
+         || fti->folder()->folderType() == KMFolderTypeCachedImap ) {
+      contextMenu.addAction( mainWidget()->action( "refresh_folder" ) );
+    }
 
-    mainWidget()->action("mark_all_as_read")->plug( &contextMenu );
-    if ( fti->folder()->folderType() == KMFolderTypeImap || fti->folder()->folderType() == KMFolderTypeCachedImap )
-      mainWidget()->action("refresh_folder")->plug( &contextMenu );
     if ( fti->folder()->isMailingListEnabled() )
-      mainWidget()->action("post_message")->plug( &contextMenu );
+      contextMenu.addAction( mainWidget()->action( "post_message" ) );
 
-    contextMenu.insertItem( SmallIconSet("configure_shortcuts"), i18n("&Assign Shortcut..."), fti, SLOT(assignShortcut()) );
-    contextMenu.insertItem( i18n("Expire..."), fti, SLOT(slotShowExpiryProperties()) );
-    mainWidget()->action("modify")->plug( &contextMenu );
+    contextMenu.addAction( SmallIcon( "configure-shortcuts" ), i18n( "&Assign Shortcut..." ),
+                           fti, SLOT( assignShortcut() ) );
+    contextMenu.addAction( i18n( "Expire..." ), fti, SLOT(slotShowExpiryProperties()) );
+    contextMenu.addAction( mainWidget()->action( "modify" ) );
   } else {
-    contextMenu.insertItem( SmallIconSet("bookmark_add"), i18n("Add Favorite Folder..."),
-                            this, SLOT(addFolder()) );
+    contextMenu.addAction( SmallIcon( "bookmark-new" ), i18n( "Add Favorite Folder..." ),
+                           this, SLOT( addFolder() ) );
   }
-  contextMenu.exec( point, 0 );
+  contextMenu.exec( point );
+}
+
+//Port the code below to QTreeWidgetItem::setToolTip() once the folder tree stuff
+//is based on QTreeWidget. --tmcguire
+#ifdef __GNUC__
+#warning Port me!
+#endif
+bool FavoriteFolderView::event( QEvent *e )
+{
+  return FolderTreeBase::event( e );
+  /*
+  if ( e->type() == QEvent::ToolTip ) {
+    QHelpEvent *he = static_cast<QHelpEvent *>( e );
+
+    FavoriteFolderViewItem *item = static_cast<FavoriteFolderViewItem*>( itemAt( he->pos() ) );
+    if  ( !item )
+      return FolderTreeBase::event( e );
+    const QRect iRect = itemRect( item );
+    if ( !iRect.isValid() )
+      return FolderTreeBase::event( e );
+    const QRect headerRect = header()->sectionRect( 0 );
+    if ( !headerRect.isValid() )
+      return FolderTreeBase::event( e );
+
+    QString tipText = i18n("<qt><b>%1</b><br>Total: %2<br>Unread: %3<br>Size: %4",
+        item->folder()->prettyUrl().replace( " ", "&nbsp;" ),
+        item->totalCount() < 0 ? "-" : QString::number( item->totalCount() ),
+        item->unreadCount() < 0 ? "-" : QString::number( item->unreadCount() ),
+        KIO::convertSize( item->folderSize() ) );
+    QRect validIn( headerRect.left(), iRect.top(), headerRect.width(), iRect.height() );
+    QToolTip::showText( he->pos(), tipText, this, validIn );
+    return true;
+  } else {
+    return FolderTreeBase::event( e );
+  }*/
 }
 
 void FavoriteFolderView::removeFolder()
@@ -353,10 +442,10 @@ void FavoriteFolderView::removeFolder()
 
 void FavoriteFolderView::initializeFavorites()
 {
-  QValueList<int> seenInboxes = GlobalSettings::self()->favoriteFolderViewSeenInboxes();
+  QList<int> seenInboxes = GlobalSettings::self()->favoriteFolderViewSeenInboxes();
   KMFolderTree *ft = mainWidget()->folderTree();
   assert( ft );
-  for ( QListViewItemIterator it( ft ); it.current(); ++it ) {
+  for ( Q3ListViewItemIterator it( ft ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     if ( fti->type() == KFolderTreeItem::Inbox && fti->folder() && !seenInboxes.contains( fti->folder()->id() ) ) {
       seenInboxes.append( fti->folder()->id() );
@@ -375,7 +464,7 @@ void FavoriteFolderView::renameFolder()
   if ( !mContextMenuItem )
     return;
   bool ok;
-  QString name = KInputDialog::getText( i18n("Rename Favorite"), i18n("Name"), mContextMenuItem->text( 0 ), &ok, this );
+  QString name = KInputDialog::getText( i18n("Rename Favorite"), i18n("Name:"), mContextMenuItem->text( 0 ), &ok, this );
   if ( !ok )
     return;
   mContextMenuItem->setText( 0, name );
@@ -387,20 +476,20 @@ QString FavoriteFolderView::prettyName(KMFolderTreeItem * fti)
   assert( fti );
   assert( fti->folder() );
   QString name = fti->folder()->label();
-  QListViewItem *accountFti = fti;
+  Q3ListViewItem *accountFti = fti;
   while ( accountFti->parent() )
     accountFti = accountFti->parent();
   if ( fti->type() == KFolderTreeItem::Inbox ) {
     if ( fti->protocol() == KFolderTreeItem::Local || fti->protocol() == KFolderTreeItem::NONE ) {
       name = i18n( "Local Inbox" );
     } else {
-      name = i18n( "Inbox of %1" ).arg( accountFti->text( 0 ) );
+      name = i18n( "Inbox of %1", accountFti->text( 0 ) );
     }
   } else {
     if ( fti->protocol() != KFolderTreeItem::Local && fti->protocol() != KFolderTreeItem::NONE ) {
-      name = i18n( "%1 on %2" ).arg( fti->text( 0 ) ).arg( accountFti->text( 0 ) );
+      name = i18n( "%1 on %2", fti->text( 0 ), accountFti->text( 0 ) );
     } else {
-      name = i18n( "%1 (local)" ).arg( fti->text( 0 ) );
+      name = i18n( "%1 (local)", fti->text( 0 ) );
     }
   }
   return name;
@@ -411,25 +500,25 @@ void FavoriteFolderView::contentsDragEnterEvent(QDragEnterEvent * e)
   if ( e->provides( "application/x-qlistviewitem" ) ) {
     setDropVisualizer( true );
     setDropHighlighter( false );
-  } else if ( e->provides( KPIM::MailListDrag::format() ) ) {
+  } else if ( e->mimeData()->hasFormat( KPIM::MailList::mimeDataType() ) ) {
     setDropVisualizer( false );
     setDropHighlighter( true );
   } else {
     setDropVisualizer( false );
     setDropHighlighter( false );
   }
-  FolderTreeBase::contentsDragEnterEvent( e );
+  e->accept();
 }
 
 void FavoriteFolderView::readColorConfig()
 {
   FolderTreeBase::readColorConfig();
-  KConfig* conf = KMKernel::config();
   // Custom/System color support
-  KConfigGroupSaver saver(conf, "Reader");
-  QColor c = KGlobalSettings::alternateBackgroundColor();
-  if ( !conf->readBoolEntry("defaultColors", true) )
-    mPaintInfo.colBack = conf->readColorEntry( "AltBackgroundColor",&c );
+  KConfigGroup cg = KMKernel::config()->group( "Reader" );
+  QColor c = KColorScheme( QPalette::Normal, KColorScheme::View ).background(
+                           KColorScheme::AlternateBackground ).color();
+  if ( !cg.readEntry( "defaultColors", true ) )
+    mPaintInfo.colBack = cg.readEntry( "AltBackgroundColor", c );
   else
     mPaintInfo.colBack = c;
 
@@ -440,7 +529,7 @@ void FavoriteFolderView::readColorConfig()
 
 void FavoriteFolderView::addFolder()
 {
-  KMFolderSelDlg dlg( mainWidget(), i18n("Add Favorite Folder"), false );
+  FolderSelectionDialog dlg( mainWidget(), i18n("Add Favorite Folder"), false );
   if ( dlg.exec() != QDialog::Accepted )
     return;
   KMFolder *folder = dlg.folder();
@@ -462,7 +551,7 @@ KMFolderTreeItem * FavoriteFolderView::findFolderTreeItem(KMFolder * folder) con
   assert( folder );
   KMFolderTree *ft = mainWidget()->folderTree();
   assert( ft );
-  for ( QListViewItemIterator it( ft ); it.current(); ++it ) {
+  for ( Q3ListViewItemIterator it( ft ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     if ( fti->folder() == folder )
       return fti;
@@ -473,7 +562,7 @@ KMFolderTreeItem * FavoriteFolderView::findFolderTreeItem(KMFolder * folder) con
 void FavoriteFolderView::checkMail()
 {
   bool found = false;
-  for ( QListViewItemIterator it( this ); it.current(); ++it ) {
+  for ( Q3ListViewItemIterator it( this ); it.current(); ++it ) {
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>( it.current() );
     if ( fti->folder()->folderType() == KMFolderTypeImap || fti->folder()->folderType() == KMFolderTypeCachedImap ) {
       if ( !found )
@@ -496,22 +585,11 @@ void FavoriteFolderView::notifyInstancesOnChange()
   if ( mReadingConfig )
     return;
   writeConfig();
-  for ( QValueList<FavoriteFolderView*>::ConstIterator it = mInstances.begin(); it != mInstances.end(); ++it ) {
+  for ( QList<FavoriteFolderView*>::ConstIterator it = mInstances.begin(); it != mInstances.end(); ++it ) {
     if ( (*it) == this || (*it)->mReadingConfig )
       continue;
     (*it)->readConfig();
   }
 }
 
-void FavoriteFolderView::refresh()
-{
-  for ( QListViewItemIterator it( this ) ; it.current() ; ++it ) {
-    KMFolderTreeItem* fti = static_cast<KMFolderTreeItem*>(it.current());
-    if (!fti || !fti->folder())
-      continue;
-    fti->repaint();
-  }
-  update();
-}
-
 #include "favoritefolderview.moc"
