@@ -36,7 +36,6 @@
 #define FOLDERSTORAGE_H
 
 // for large file support
-#include <config.h>
 
 #include "kmfoldernode.h"
 #include "kmfoldertype.h"
@@ -45,12 +44,16 @@
 #include "folderjob.h"
 using KMail::FolderJob;
 
+#include <QList>
+#include <QByteArray>
+
 #include "mimelib/string.h"
 
 #include <sys/types.h>
 #include <stdio.h>
 
 class KMMessage;
+class KMAccount;
 class KMFolderDir;
 class KMMsgDict; // for the rDict manipulations
 class KMMsgDictREntry;
@@ -62,7 +65,7 @@ namespace KMail {
 }
 using KMail::AttachmentStrategy;
 
-typedef QValueList<Q_UINT32> SerNumList;
+typedef QList<quint32> SerNumList;
 
 /**
  * @short The FolderStorage class is the bass class for the storage related
@@ -85,7 +88,7 @@ public:
   /** Usually a parent is given. But in some cases there is no
     fitting parent object available. Then the name of the folder
     is used as the absolute path to the folder file. */
-  FolderStorage( KMFolder* folder, const char* name=0 );
+  explicit FolderStorage( KMFolder* folder, const char* name=0 );
   virtual ~FolderStorage();
 
   KMFolder* folder() const { return mFolder; }
@@ -99,7 +102,13 @@ public:
   QString location() const;
 
   /** Returns full path to index file */
-  virtual QString indexLocation() const = 0;
+  virtual QString indexLocation() const;
+
+  /** Returns full path to 'ids' file */
+  virtual QString idsLocation() const;
+
+  /** Returns full path to 'sorted' file */
+  virtual QString sortedLocation() const;
 
   /** Returns, if the folder can't contain mails, but only subfolder */
   virtual bool noContent() const { return mNoContent; }
@@ -142,6 +151,9 @@ public:
   /** Load message from file and do NOT store it, only return it.
       This is equivalent to, but faster than, getMsg+unGetMsg
       WARNING: the caller has to delete the returned value!
+      WARNING: Use this only for messages which are local, never for remote
+               messages, because remote messages could start a transfer, which
+               would trigger an assert when the message is deleted by the caller.
   */
   virtual KMMessage* readTemporaryMsg(int idx);
 
@@ -158,9 +170,9 @@ public:
    * for each derived KMFolder).
    */
   virtual FolderJob* createJob( KMMessage *msg, FolderJob::JobType jt = FolderJob::tGetMessage,
-                                KMFolder *folder = 0, QString partSpecifier = QString::null,
+                                KMFolder *folder = 0, const QString &partSpecifier = QString(),
                                 const AttachmentStrategy *as = 0 ) const;
-  virtual FolderJob* createJob( QPtrList<KMMessage>& msgList, const QString& sets,
+  virtual FolderJob* createJob( QList<KMMessage*>& msgList, const QString& sets,
                                 FolderJob::JobType jt = FolderJob::tGetMessage,
                                 KMFolder *folder = 0 ) const;
 
@@ -180,7 +192,7 @@ public:
   /** Detach message from this folder. Usable to call addMsg() afterwards.
     Loads the message if it is not loaded up to now. */
   virtual KMMessage* take(int idx);
-  virtual void take(QPtrList<KMMessage> msgList);
+  virtual void takeMessages(const QList<KMMessage*>& msgList);
 
   /** Add the given message to the folder. Usually the message
     is added at the end of the folder. Returns zero on success and
@@ -201,20 +213,20 @@ public:
    * Adds the given messages to the folder. Behaviour is identical
    * to addMsg(msg)
    */
-  virtual int addMsg( QPtrList<KMMessage>&, QValueList<int>& index_return );
+  virtual int addMessages( QList<KMMessage*>&, QList<int>& index_return );
 
   /** Called by derived classes implementation of addMsg.
       Emits msgAdded signals */
   void emitMsgAddedSignals(int idx);
 
-  /** Returns FALSE, if the message has to be retrieved from an IMAP account
+  /** Returns false, if the message has to be retrieved from an IMAP account
    * first. In this case this function does this and cares for the rest */
   virtual bool canAddMsgNow(KMMessage* aMsg, int* aIndex_ret);
 
   /** Remove (first occurrence of) given message from the folder. */
-  virtual void removeMsg(int i, bool imapQuiet = FALSE);
-  virtual void removeMsg(const QPtrList<KMMsgBase>& msgList, bool imapQuiet = FALSE);
-  virtual void removeMsg(const QPtrList<KMMessage>& msgList, bool imapQuiet = FALSE);
+  virtual void removeMsg(int i, bool imapQuiet = false);
+  virtual void removeMessages(const QList<KMMsgBase*>& msgList, bool imapQuiet = false);
+  virtual void removeMessages(const QList<KMMessage*>& msgList, bool imapQuiet = false);
 
   /** Delete messages in the folder that are older than days. Return the
    * number of deleted messages. */
@@ -225,7 +237,7 @@ public:
     code on failure. The index of the new message is stored in index_return
     if given. */
   virtual int moveMsg(KMMessage* msg, int* index_return = 0);
-  virtual int moveMsg(QPtrList<KMMessage>, int* index_return = 0);
+  virtual int moveMsg(QList<KMMessage*>, int* index_return = 0);
 
   /** Returns the index of the given message or -1 if not found. */
   virtual int find(const KMMsgBase* msg) const = 0;
@@ -237,26 +249,36 @@ public:
   /** Number of new or unread messages in this folder. */
   virtual int countUnread();
 
+  /** Total size of the contents of this folder. */
+  qint64 folderSize() const;
+
+  /** Return whether the folder is close to its quota limit, which can
+   * be reflected in the UI.  */
+  virtual bool isCloseToQuota() const;
+
   /** Called by KMMsgBase::setStatus when status of a message has changed
       required to keep the number unread messages variable current. */
-  virtual void msgStatusChanged( const KMMsgStatus oldStatus,
-                                 const KMMsgStatus newStatus,
-				 int idx);
+  virtual void msgStatusChanged( const MessageStatus& oldStatus,
+                                 const MessageStatus& newStatus,
+                                 int idx);
 
   /** Open folder for access.
-    Does nothing if the folder is already opened. To reopen a folder
-    call close() first.
+    open() and close() use reference counting.
     Returns zero on success and an error code equal to the c-library
-    fopen call otherwise (errno). */
-  virtual int open(const char *owner) = 0;
+    fopen call otherwise (errno).
+    @p owner is for debugging.
+    @see KMFolderOpener */
+  virtual int open( const char *owner ) = 0;
 
   /** Check folder for permissions
-    Returns zero if readable and writable. */
-  virtual int canAccess() = 0;
+    @return true if readable and writable. */
+  virtual bool canAccess() const = 0;
 
-  /** Close folder. If force is TRUE the files are closed even if
-    others still use it (e.g. other mail reader windows). */
-  virtual void close(const char * owner,bool force=FALSE) = 0;
+  /** Close folder. If force is true the files are closed even if
+    If @p force is TRUE the files are closed regardless of reference count,
+    and the reference count will be set to zero.
+    @p owner is for debugging. */
+  virtual void close( const char *owner, bool force = false ) = 0;
 
   /** Try releasing @p folder if possible, something is attempting an exclusive access to it.
       Currently used for KMFolderSearch and the background tasks like expiry. */
@@ -265,7 +287,7 @@ public:
   /** fsync buffers to disk */
   virtual void sync() = 0;
 
-  /** Test if folder is opened. */
+  /** Test if folder is opened, i.e. its reference count is greater than zero. */
   bool isOpened() const { return (mOpenCount>0); }
 
   /** Mark all new messages as unread. */
@@ -300,14 +322,14 @@ public:
     on failure. */
   virtual int rename(const QString& newName, KMFolderDir *aParent = 0);
 
-  /** Returns TRUE if a table of contents file is automatically created. */
+  /** Returns true if a table of contents file is automatically created. */
   bool autoCreateIndex() const { return mAutoCreateIndex; }
 
   /** Allow/disallow automatic creation of a table of contents file.
-    Default is TRUE. */
+    Default is true. */
   virtual void setAutoCreateIndex(bool);
 
-  /** Returns TRUE if the table of contents is dirty. This happens when
+  /** Returns true if the table of contents is dirty. This happens when
     a message is deleted from the folder. The toc will then be re-created
     when the folder is closed. */
   bool dirty() const { return mDirty; }
@@ -315,7 +337,7 @@ public:
   /** Change the dirty flag. */
   void setDirty(bool f);
 
-  /** Returns TRUE if the folder contains deleted messages */
+  /** Returns true if the folder contains deleted messages */
   bool needsCompacting() const { return needsCompact; }
   virtual void setNeedsCompacting(bool f) { needsCompact = f; }
 
@@ -351,10 +373,10 @@ public:
   void deregisterFromMessageDict();
 
   /** Set the status of the message at index @p idx to @p status. */
-  virtual void setStatus(int idx, KMMsgStatus status, bool toggle=false);
+  virtual void setStatus(int idx, const MessageStatus& status, bool toggle=false);
 
   /** Set the status of the message(s) in the QValueList @p ids to @p status. */
-  virtual void setStatus(QValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+  virtual void setStatus(QList<int>& ids, const MessageStatus& status, bool toggle=false);
 
   void removeJobs();
 
@@ -383,9 +405,10 @@ public:
   bool compactable() const { return mCompactable; }
 
   /// Set the type of contents held in this folder (mail, calendar, etc.)
-  // If quiet is true, the KMailIcalIface is not informed of the changed. That's usefull
-  // for folder that are being copied around, should retain their type, but not cause
-  // conflicts on copy because events are identical in two folders.
+  // If quiet is true, the KMailIcalIface is not informed of the changed.
+  // That's useful for folder that are being copied around, should retain
+  // their type, but not cause conflicts on copy because events are identical
+  // in two folders.
   virtual void setContentsType( KMail::FolderContentsType type, bool quiet = false );
   /// @return the type of contents held in this folder (mail, calendar, etc.)
   KMail::FolderContentsType contentsType() const { return mContentsType; }
@@ -400,11 +423,13 @@ public:
    * Check if the message matches the search criteria
    * The end is signaled with searchDone()
    */
-  virtual void search( const KMSearchPattern*, Q_UINT32 serNum );
+  virtual void search( const KMSearchPattern*, quint32 serNum );
 
   /** Returns true if this folder can be moved */
   virtual bool isMoveable() const;
 
+  virtual KMAccount* account() const;
+
 signals:
   /** Emitted when the status, name, or associated accounts of this
     folder changed. */
@@ -420,9 +445,9 @@ signals:
 
   /** Emitted when the folder was closed and ticket owners have to reopen */
   void closed( KMFolder* );
-  
+
   /** Emitted when the serial numbers of this folder were invalidated. */
-  void invalidated( KMFolder * );
+  void invalidated( KMFolder* );
 
   /** Emitted when the name of the folder changes. */
   void nameChanged();
@@ -440,18 +465,18 @@ signals:
   void readOnlyChanged(KMFolder*);
 
   /** Emitted before a message is removed from the folder. */
-  void msgRemoved(KMFolder*, Q_UINT32 sernum);
+  void msgRemoved(KMFolder*, quint32 sernum);
 
   /** Emitted after a message is removed from the folder. */
-  void msgRemoved( int idx, QString msgIdMD5 );
+  void msgRemoved( int idx, const QString &msgIdMD5 );
   void msgRemoved( KMFolder* );
 
   /** Emitted when a message is added from the folder. */
   void msgAdded(int idx);
-  void msgAdded(KMFolder*, Q_UINT32 sernum);
+  void msgAdded(KMFolder*, quint32 sernum);
 
   /** Emitted, when the status of a message is changed */
-  void msgChanged(KMFolder*, Q_UINT32 sernum, int delta);
+  void msgChanged(KMFolder*, quint32 sernum, int delta);
 
   /** Emitted when a field of the header of a specific message changed. */
   void msgHeaderChanged(KMFolder*, int);
@@ -470,14 +495,17 @@ signals:
    * The matching serial numbers are included
    * If @p complete is true the search is done
    */
-  void searchResult( KMFolder*, QValueList<Q_UINT32>,
+  void searchResult( KMFolder*, QList<quint32>,
                      const KMSearchPattern*, bool complete );
 
   /**
    * Emitted when a search for a single message is completed
    * The serial number and a bool matching yes/no is included
    */
-  void searchDone( KMFolder*, Q_UINT32, const KMSearchPattern*, bool );
+  void searchDone( KMFolder*, quint32, const KMSearchPattern*, bool );
+
+  /** Emitted when the folder's size changes. */
+  void folderSizeChanged();
 
 
 public slots:
@@ -509,8 +537,8 @@ protected:
    * @see createJob
    */
   virtual FolderJob* doCreateJob( KMMessage *msg, FolderJob::JobType jt, KMFolder *folder,
-                                  QString partSpecifier, const AttachmentStrategy *as ) const = 0;
-  virtual FolderJob* doCreateJob( QPtrList<KMMessage>& msgList, const QString& sets,
+                                  const QString &partSpecifier, const AttachmentStrategy *as ) const = 0;
+  virtual FolderJob* doCreateJob( QList<KMMessage*>& msgList, const QString& sets,
                                   FolderJob::JobType jt, KMFolder *folder ) const = 0;
 
   /** Tell the folder that a header field that is usually used for
@@ -578,6 +606,12 @@ friend class KMMsgDict;
   virtual void clearIndex(bool autoDelete=true, bool syncDict = false) = 0;
   virtual void truncateIndex() = 0;
 
+  virtual qint64 doFolderSize() const { return 0; };
+
+  /** Returns full path to .index, .index.ids or .index.sorted file (depending on @a suffix). 
+   The former path (in case of mmap-based implementation) is returned when @a suffix is empty. */
+  virtual QString location(const QString& suffix) const;
+
   int mOpenCount;
   int mQuiet;
   bool mChanged :1;
@@ -588,12 +622,13 @@ friend class KMMsgDict;
   bool mExportsSernums :1;
   /** if the index is dirty it will be recreated upon close() */
   bool mDirty :1;
-  /** TRUE if the files of the folder are locked (writable) */
+  /** true if the files of the folder are locked (writable) */
   bool mFilesLocked :1;
 
   /** number of unread messages, -1 if not yet set */
   int mUnreadMsgs, mGuessedUnreadMsgs;
   int mTotalMsgs;
+  qint64 mSize;
   bool mWriteConfigEnabled :1;
   /** sven: true if on destruct folder needs to be compacted. */
   bool needsCompact :1;
@@ -606,7 +641,7 @@ friend class KMMsgDict;
   /** Points at the reverse dictionary for this folder. */
   mutable KMMsgDictREntry *mRDict;
   /** List of jobs created by this folder. */
-  mutable QPtrList<FolderJob> mJobList;
+  mutable QList<FolderJob*> mJobList;
 
   QTimer *mDirtyTimer;
   enum { mDirtyTimerInterval = 600000 }; // 10 minutes
