@@ -1,61 +1,69 @@
 /*
-    This file is part of Kontact.
-    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-    Copyright (c) 2004 Allen Winter <winter@kde.org>
+  This file is part of Kontact.
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
+  Copyright (c) 2004 Allen Winter <winter@kde.org>
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+  GNU General Public License for more details.
 
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
+  As a special exception, permission is given to link this program
+  with any edition of Qt, and distribute the resulting executable,
+  without including the source code for Qt in the source distribution.
 */
 
-#include <qcursor.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qimage.h>
-#include <qtooltip.h>
+#include "sdsummarywidget.h"
+#include "coreinterface.h"
 
-#include <dcopclient.h>
-#include <dcopref.h>
-#include <kabc/stdaddressbook.h>
+#include <libkdepim/kpimprefs.h>
+#include <kontactinterfaces/core.h>
+#include <kontactinterfaces/plugin.h>
 #include <korganizer/stdcalendar.h>
-#include <kapplication.h>
+
+#include <kabc/stdaddressbook.h>
+#include <kcal/event.h>
+#include <kcal/resourcecalendar.h>
+#include <kcal/resourcelocal.h>
+
 #include <kdialog.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kparts/part.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kstandarddirs.h>
+#include <ktoolinvocation.h>
 #include <kurllabel.h>
-#include <libkcal/event.h>
-#include <libkcal/resourcecalendar.h>
-#include <libkcal/resourcelocal.h>
-#include <libkdepim/kpimprefs.h>
 
-#include "core.h"
-#include "plugin.h"
-
-#include "sdsummarywidget.h"
+#include <QCursor>
+#include <QLabel>
+#include <QLayout>
+#include <QImage>
+#include <QPixmap>
+#include <QGridLayout>
+#include <QEvent>
+#include <QVBoxLayout>
 
 enum SDIncidenceType {
-  IncidenceTypeContact, IncidenceTypeEvent
+  IncidenceTypeContact,
+  IncidenceTypeEvent
 };
 enum SDCategory {
-  CategoryBirthday, CategoryAnniversary, CategoryHoliday, CategoryOther
+  CategoryBirthday,
+  CategoryAnniversary,
+  CategoryHoliday,
+  CategoryOther
 };
 
 class SDEntry
@@ -77,49 +85,50 @@ class SDEntry
     }
 };
 
-SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent,
-                                    const char *name )
-  : Kontact::Summary( parent, name ), mPlugin( plugin ), mCalendar( 0 ), mHolidays( 0 )
+SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
+  : Kontact::Summary( parent ), mPlugin( plugin ), mCalendar( 0 ), mHolidays( 0 )
 {
   // Create the Summary Layout
-  QVBoxLayout *mainLayout = new QVBoxLayout( this, 3, 3 );
+  QVBoxLayout *mainLayout = new QVBoxLayout( this );
+  mainLayout->setSpacing( 3 );
+  mainLayout->setMargin( 3 );
 
-  QPixmap icon = KGlobal::iconLoader()->loadIcon( "cookie",
-                    KIcon::Desktop, KIcon::SizeMedium );
+  //TODO: we want our own special dates icon
+  QWidget *header = createHeader(
+    this, "favorites", i18n( "Upcoming Special Dates" ) );
+  mainLayout->addWidget( header );
 
-  QWidget *header = createHeader( this, icon, i18n( "Special Dates" ) );
-  mainLayout->addWidget(header);
-
-  mLayout = new QGridLayout( mainLayout, 7, 6, 3 );
+  mLayout = new QGridLayout();
+  mainLayout->addItem( mLayout );
+  mLayout->setSpacing( 3 );
   mLayout->setRowStretch( 6, 1 );
 
   // Setup the Addressbook
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
-  connect( ab, SIGNAL( addressBookChanged( AddressBook* ) ),
-           this, SLOT( updateView() ) );
-  connect( mPlugin->core(), SIGNAL( dayChanged( const QDate& ) ),
-           this, SLOT( updateView() ) );
+  connect( ab, SIGNAL(addressBookChanged(AddressBook*)),
+           this, SLOT(updateView()) );
+  connect( mPlugin->core(), SIGNAL(dayChanged(const QDate&)),
+           this, SLOT(updateView()) );
 
   // Setup the Calendar
-  mCalendar = new KCal::CalendarResources( KPimPrefs::timezone() );
+  mCalendar = new KCal::CalendarResources( KPIM::KPimPrefs::timeSpec() );
   mCalendar->readConfig();
 
   KCal::CalendarResourceManager *manager = mCalendar->resourceManager();
   if ( manager->isEmpty() ) {
-    KConfig config( "korganizerrc" );
-    config.setGroup( "General" );
-    QString fileName = config.readPathEntry( "Active Calendar" );
+    KConfig _config( "korganizerrc" );
+    KConfigGroup config( &_config, "General" );
+    QString fileName = config.readPathEntry( "Active Calendar", QString() );
 
     QString resourceName;
     if ( fileName.isEmpty() ) {
-      fileName = locateLocal( "data", "korganizer/std.ics" );
+      fileName = KStandardDirs::locateLocal( "data", "korganizer/std.ics" );
       resourceName = i18n( "Default KOrganizer resource" );
     } else {
       resourceName = i18n( "Active Calendar" );
     }
 
-    KCal::ResourceCalendar *defaultResource =
-      new KCal::ResourceLocal( fileName );
+    KCal::ResourceCalendar *defaultResource = new KCal::ResourceLocal( fileName );
 
     defaultResource->setResourceName( resourceName );
 
@@ -129,10 +138,10 @@ SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent,
   mCalendar = KOrg::StdCalendar::self();
   mCalendar->load();
 
-  connect( mCalendar, SIGNAL( calendarChanged() ),
-           this, SLOT( updateView() ) );
-  connect( mPlugin->core(), SIGNAL( dayChanged( const QDate& ) ),
-           this, SLOT( updateView() ) );
+  connect( mCalendar, SIGNAL(calendarChanged()),
+           this, SLOT(updateView()) );
+  connect( mPlugin->core(), SIGNAL(dayChanged(const QDate&)),
+           this, SLOT(updateView()) );
 
   // Update Configuration
   configUpdated();
@@ -142,37 +151,33 @@ void SDSummaryWidget::configUpdated()
 {
   KConfig config( "kcmsdsummaryrc" );
 
-  config.setGroup( "Days" );
-  mDaysAhead = config.readNumEntry( "DaysToShow", 7 );
+  KConfigGroup group = config.group( "Days" );
+  mDaysAhead = group.readEntry( "DaysToShow", 7 );
 
-  config.setGroup( "EventTypes" );
-  mShowBirthdaysFromKAB =
-    config.readBoolEntry( "ShowBirthdaysFromContacts", true );
-  mShowBirthdaysFromCal =
-    config.readBoolEntry( "ShowBirthdaysFromCalendar", true );
+  group = config.group( "Show" );
+  mShowBirthdaysFromKAB = group.readEntry( "BirthdaysFromContacts", true );
+  mShowBirthdaysFromCal = group.readEntry( "BirthdaysFromCalendar", true );
 
-  mShowAnniversariesFromKAB =
-    config.readBoolEntry( "ShowAnniversariesFromContacts", true );
-  mShowAnniversariesFromCal =
-    config.readBoolEntry( "ShowAnniversariesFromCalendar", true );
+  mShowAnniversariesFromKAB = group.readEntry( "AnniversariesFromContacts", true );
+  mShowAnniversariesFromCal = group.readEntry( "AnniversariesFromCalendar", true );
 
-  mShowHolidays =
-    config.readBoolEntry( "ShowHolidays", true );
+  mShowHolidays = group.readEntry( "HolidaysFromCalendar", true );
 
-  mShowSpecialsFromCal =
-    config.readBoolEntry( "ShowSpecialsFromCalendar", true );
+  mShowSpecialsFromCal = group.readEntry( "SpecialsFromCalendar", true );
 
   updateView();
 }
 
 bool SDSummaryWidget::initHolidays()
 {
-  KConfig hconfig( "korganizerrc" );
-  hconfig.setGroup( "Time & Date" );
+  KConfig _hconfig( "korganizerrc" );
+  KConfigGroup hconfig( &_hconfig, "Time & Date" );
   QString location = hconfig.readEntry( "Holidays" );
   if ( !location.isEmpty() ) {
-    if ( mHolidays ) delete mHolidays;
-    mHolidays = new KHolidays( location );
+    if ( mHolidays ) {
+      delete mHolidays;
+    }
+    mHolidays = new LibKHolidays::KHolidays( location );
     return true;
   }
   return false;
@@ -182,23 +187,23 @@ bool SDSummaryWidget::initHolidays()
 int SDSummaryWidget::span( KCal::Event *event )
 {
   int span=1;
-  if ( event->isMultiDay() && event->doesFloat() ) {
+  if ( event->isMultiDay() && event->allDay() ) {
     QDate d = event->dtStart().date();
     if ( d < QDate::currentDate() ) {
       d = QDate::currentDate();
     }
     while ( d < event->dtEnd().date() ) {
       span++;
-      d=d.addDays( 1 );
+      d = d.addDays( 1 );
     }
   }
   return span;
 }
 
 // day of a multiday Event
-int SDSummaryWidget::dayof( KCal::Event *event, const QDate& date )
+int SDSummaryWidget::dayof( KCal::Event *event, const QDate &date )
 {
-  int dayof=1;
+  int dayof = 1;
   QDate d = event->dtStart().date();
   if ( d < QDate::currentDate() ) {
     d = QDate::currentDate();
@@ -212,22 +217,20 @@ int SDSummaryWidget::dayof( KCal::Event *event, const QDate& date )
   return dayof;
 }
 
-
-
 void SDSummaryWidget::updateView()
 {
-  mLabels.setAutoDelete( true );
-  mLabels.clear();
-  mLabels.setAutoDelete( false );
-
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
-  QValueList<SDEntry> dates;
+  QList<SDEntry> dates;
   QLabel *label = 0;
 
-  // No reason to show the date year
-  QString savefmt = KGlobal::locale()->dateFormat();
-  KGlobal::locale()->setDateFormat( KGlobal::locale()->
-                                    dateFormat().replace( 'Y', ' ' ) );
+  // Remove all special date labels from the layout and delete them, as we
+  // will re-create all labels below.
+  setUpdatesEnabled( false );
+  foreach ( label, mLabels ) {
+    mLayout->removeWidget( label );
+    delete( label );
+  }
+  mLabels.clear();
 
   // Search for Birthdays and Anniversaries in the Addressbook
   KABC::AddressBook::Iterator it;
@@ -242,12 +245,12 @@ void SDSummaryWidget::updateView()
       entry.date = birthday;
       entry.addressee = *it;
       entry.span = 1;
-      if ( entry.daysTo <= mDaysAhead )
+      if ( entry.daysTo <= mDaysAhead ) {
         dates.append( entry );
+      }
     }
 
-    QString anniversaryAsString =
-      (*it).custom( "KADDRESSBOOK" , "X-Anniversary" );
+    QString anniversaryAsString = (*it).custom( "KADDRESSBOOK", "X-Anniversary" );
     if ( !anniversaryAsString.isEmpty() ) {
       QDate anniversary = QDate::fromString( anniversaryAsString, Qt::ISODate );
       if ( anniversary.isValid() && mShowAnniversariesFromKAB ) {
@@ -259,34 +262,42 @@ void SDSummaryWidget::updateView()
         entry.date = anniversary;
         entry.addressee = *it;
         entry.span = 1;
-        if ( entry.daysTo <= mDaysAhead )
+        if ( entry.daysTo <= mDaysAhead ) {
           dates.append( entry );
+        }
       }
     }
   }
 
   // Search for Birthdays, Anniversaries, Holidays, and Special Occasions
   // in the Calendar
+  KCal::ResourceCalendar *bdayRes = usingBirthdayResource();
+  KCal::ResourceCalendar *annvRes = bdayRes;
+  if ( !mShowBirthdaysFromKAB ) {
+    bdayRes = 0;
+  }
+  if ( !mShowAnniversariesFromKAB ) {
+    annvRes = 0;
+  }
+
   QDate dt;
-  QDate currentDate = QDate::currentDate();
-  for ( dt=currentDate;
-        dt<=currentDate.addDays( mDaysAhead - 1 );
+  for ( dt=QDate::currentDate();
+        dt<=QDate::currentDate().addDays( mDaysAhead - 1 );
         dt=dt.addDays(1) ) {
-    KCal::Event::List events = mCalendar->events( dt,
+    KCal::Event::List events = mCalendar->events( dt, mCalendar->timeSpec(),
                                                   KCal::EventSortStartDate,
                                                   KCal::SortDirectionAscending );
     KCal::Event *ev;
     KCal::Event::List::ConstIterator it;
-    for ( it=events.begin(); it!=events.end(); ++it ) {
+    for ( it = events.begin(); it != events.end(); ++it ) {
       ev = *it;
       if ( !ev->categoriesStr().isEmpty() ) {
         QStringList::ConstIterator it2;
         QStringList c = ev->categories();
-        for ( it2=c.begin(); it2!=c.end(); ++it2 ) {
+        for ( it2 = c.begin(); it2 != c.end(); ++it2 ) {
 
           // Append Birthday Event?
-          if ( mShowBirthdaysFromCal &&
-               ( ( *it2 ).upper() == i18n( "BIRTHDAY" ) ) ) {
+          if ( mShowBirthdaysFromCal && ( ( *it2 ).toUpper() == i18n( "BIRTHDAY" ) ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryBirthday;
@@ -295,13 +306,14 @@ void SDSummaryWidget::updateView()
             entry.desc = ev->description();
             dateDiff( ev->dtStart().date(), entry.daysTo, entry.yearsOld );
             entry.span = 1;
-            dates.append( entry );
+            if ( !check( bdayRes, dt, ev->summary() ) ) {
+              dates.append( entry );
+            }
             break;
           }
 
           // Append Anniversary Event?
-          if ( mShowAnniversariesFromCal &&
-               ( ( *it2 ).upper() == i18n( "ANNIVERSARY" ) ) ) {
+          if ( mShowAnniversariesFromCal && ( ( *it2 ).toUpper() == i18n( "ANNIVERSARY" ) ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryAnniversary;
@@ -310,13 +322,14 @@ void SDSummaryWidget::updateView()
             entry.desc = ev->description();
             dateDiff( ev->dtStart().date(), entry.daysTo, entry.yearsOld );
             entry.span = 1;
-            dates.append( entry );
+            if ( !check( annvRes, dt, ev->summary() ) ) {
+              dates.append( entry );
+            }
             break;
           }
 
           // Append Holiday Event?
-          if ( mShowHolidays &&
-               ( ( *it2 ).upper() == i18n( "HOLIDAY" ) ) ) {
+          if ( mShowHolidays && ( ( *it2 ).toUpper() == i18n( "HOLIDAY" ) ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryHoliday;
@@ -326,15 +339,15 @@ void SDSummaryWidget::updateView()
             dateDiff( dt, entry.daysTo, entry.yearsOld );
             entry.yearsOld = -1; //ignore age of holidays
             entry.span = span( ev );
-            if ( entry.span > 1 && dayof( ev, dt ) > 1 ) // skip days 2,3,...
+            if ( entry.span > 1 && dayof( ev, dt ) > 1 ) { // skip days 2,3,...
               break;
+            }
             dates.append( entry );
             break;
           }
 
           // Append Special Occasion Event?
-          if ( mShowSpecialsFromCal &&
-               ( ( *it2 ).upper() == i18n( "SPECIAL OCCASION" ) ) ) {
+          if ( mShowSpecialsFromCal && ( ( *it2 ).toUpper() == i18n( "SPECIAL OCCASION" ) ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryOther;
@@ -344,8 +357,9 @@ void SDSummaryWidget::updateView()
             dateDiff( dt, entry.daysTo, entry.yearsOld );
             entry.yearsOld = -1; //ignore age of special occasions
             entry.span = span( ev );
-            if ( entry.span > 1 && dayof( ev, dt ) > 1 ) // skip days 2,3,...
+            if ( entry.span > 1 && dayof( ev, dt ) > 1 ) { // skip days 2,3,...
               break;
+            }
             dates.append( entry );
             break;
           }
@@ -357,15 +371,16 @@ void SDSummaryWidget::updateView()
   // Seach for Holidays
   if ( mShowHolidays ) {
     if ( initHolidays() ) {
-      for ( dt=currentDate;
-            dt<=currentDate.addDays( mDaysAhead - 1 );
+      for ( dt=QDate::currentDate();
+            dt<=QDate::currentDate().addDays( mDaysAhead - 1 );
             dt=dt.addDays(1) ) {
-        QValueList<KHoliday> holidays = mHolidays->getHolidays( dt );
-        QValueList<KHoliday>::ConstIterator it = holidays.begin();
+        QList<LibKHolidays::KHoliday> holidays = mHolidays->getHolidays( dt );
+        QList<LibKHolidays::KHoliday>::ConstIterator it = holidays.begin();
         for ( ; it != holidays.end(); ++it ) {
           SDEntry entry;
           entry.type = IncidenceTypeEvent;
-          entry.category = ((*it).Category==KHolidays::HOLIDAY)?CategoryHoliday:CategoryOther;
+          entry.category = ( (*it).Category == LibKHolidays::KHolidays::HOLIDAY )?
+                           CategoryHoliday : CategoryOther;
           entry.date = dt;
           entry.summary = (*it).text;
           dateDiff( dt, entry.daysTo, entry.yearsOld );
@@ -378,11 +393,11 @@ void SDSummaryWidget::updateView()
   }
 
   // Sort, then Print the Special Dates
-  qHeapSort( dates );
+  qSort( dates );
 
   if ( !dates.isEmpty() ) {
     int counter = 0;
-    QValueList<SDEntry>::Iterator addrIt;
+    QList<SDEntry>::Iterator addrIt;
     QString lines;
     for ( addrIt = dates.begin(); addrIt != dates.end(); ++addrIt ) {
       bool makeBold = (*addrIt).daysTo == 0; // i.e., today
@@ -393,43 +408,44 @@ void SDSummaryWidget::updateView()
       KABC::Picture pic;
       switch( (*addrIt).category ) {  // TODO: better icons
       case CategoryBirthday:
-        icon_name = "cookie";
+        icon_name = "user-identity";
         pic = (*addrIt).addressee.photo();
         if ( pic.isIntern() && !pic.data().isNull() ) {
           QImage img = pic.data();
           if ( img.width() > img.height() ) {
-            icon_img = img.scaleWidth( 32 );
+            icon_img = img.scaledToWidth( 32 );
           } else {
-            icon_img = img.scaleHeight( 32 );
+            icon_img = img.scaledToHeight( 32 );
           }
         }
         break;
       case CategoryAnniversary:
-        icon_name = "kdmconfig";
+        icon_name = "favorites";
         pic = (*addrIt).addressee.photo();
         if ( pic.isIntern() && !pic.data().isNull() ) {
           QImage img = pic.data();
           if ( img.width() > img.height() ) {
-            icon_img = img.scaleWidth( 32 );
+            icon_img = img.scaledToWidth( 32 );
           } else {
-            icon_img = img.scaleHeight( 32 );
+            icon_img = img.scaledToHeight( 32 );
           }
         }
         break;
       case CategoryHoliday:
-        icon_name = "kdmconfig"; break;
+        icon_name = "favorites";
+        break;
       case CategoryOther:
-        icon_name = "cookie"; break;
+        icon_name = "user-identity";
+        break;
       }
       label = new QLabel( this );
       if ( icon_img.isNull() ) {
-        label->setPixmap( KGlobal::iconLoader()->loadIcon( icon_name,
-                                                           KIcon::Small ) );
+        label->setPixmap( KIconLoader::global()->loadIcon( icon_name, KIconLoader::Small ) );
       } else {
-        label->setPixmap( icon_img );
+        label->setPixmap( QPixmap::fromImage( icon_img ) );
       }
       label->setMaximumWidth( label->minimumSizeHint().width() );
-      label->setAlignment( AlignVCenter );
+      label->setAlignment( Qt::AlignVCenter );
       mLayout->addWidget( label, counter, 0 );
       mLabels.append( label );
 
@@ -437,16 +453,15 @@ void SDSummaryWidget::updateView()
       QString datestr;
 
       //Muck with the year -- change to the year 'daysTo' days away
-      int year = currentDate.addDays( (*addrIt).daysTo ).year();
-      QDate sD = QDate::QDate( year,
-                           (*addrIt).date.month(), (*addrIt).date.day() );
+      int year = QDate::currentDate().addDays( (*addrIt).daysTo ).year();
+      QDate sD = QDate( year, (*addrIt).date.month(), (*addrIt).date.day() );
 
       if ( (*addrIt).daysTo == 0 ) {
         datestr = i18n( "Today" );
       } else if ( (*addrIt).daysTo == 1 ) {
         datestr = i18n( "Tomorrow" );
       } else {
-        datestr = KGlobal::locale()->formatDate( sD );
+        datestr = KGlobal::locale()->formatDate( sD, KLocale::FancyLongDate );
       }
       // Print the date span for multiday, floating events, for the
       // first day of the event only.
@@ -457,7 +472,7 @@ void SDSummaryWidget::updateView()
       }
 
       label = new QLabel( datestr, this );
-      label->setAlignment( AlignLeft | AlignVCenter );
+      label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter );
       mLayout->addWidget( label, counter, 1 );
       mLabels.append( label );
       if ( makeBold ) {
@@ -471,10 +486,10 @@ void SDSummaryWidget::updateView()
       if ( (*addrIt).daysTo == 0 ) {
         label->setText( i18n( "now" ) );
       } else {
-        label->setText( i18n( "in 1 day", "in %n days", (*addrIt).daysTo ) );
+        label->setText( i18np( "in 1 day", "in %1 days", (*addrIt).daysTo ) );
       }
 
-      label->setAlignment( AlignLeft | AlignVCenter );
+      label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter );
       mLayout->addWidget( label, counter, 2 );
       mLabels.append( label );
 
@@ -482,34 +497,38 @@ void SDSummaryWidget::updateView()
       QString what;
       switch( (*addrIt).category ) {
       case CategoryBirthday:
-        what = i18n( "Birthday" ); break;
+        what = i18n( "Birthday" );
+        break;
       case CategoryAnniversary:
-        what = i18n( "Anniversary" ); break;
+        what = i18n( "Anniversary" );
+        break;
       case CategoryHoliday:
-        what = i18n( "Holiday" ); break;
+        what = i18n( "Holiday" );
+        break;
       case CategoryOther:
-        what = i18n( "Special Occasion" ); break;
+        what = i18n( "Special Occasion" );
+        break;
       }
       label = new QLabel( this );
       label->setText( what );
-      label->setAlignment( AlignLeft | AlignVCenter );
+      label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter );
       mLayout->addWidget( label, counter, 3 );
       mLabels.append( label );
 
       // Description
       if ( (*addrIt).type == IncidenceTypeContact ) {
-        KURLLabel *urlLabel = new KURLLabel( this );
+        KUrlLabel *urlLabel = new KUrlLabel( this );
         urlLabel->installEventFilter( this );
-        urlLabel->setURL( (*addrIt).addressee.uid() );
+        urlLabel->setUrl( (*addrIt).addressee.uid() );
         urlLabel->setText( (*addrIt).addressee.realName() );
         urlLabel->setTextFormat( Qt::RichText );
         mLayout->addWidget( urlLabel, counter, 4 );
         mLabels.append( urlLabel );
 
-        connect( urlLabel, SIGNAL( leftClickedURL( const QString& ) ),
-                 this, SLOT( mailContact( const QString& ) ) );
-        connect( urlLabel, SIGNAL( rightClickedURL( const QString& ) ),
-                 this, SLOT( popupMenu( const QString& ) ) );
+        connect( urlLabel, SIGNAL(leftClickedUrl(const QString&)),
+                 this, SLOT(mailContact(const QString&)) );
+        connect( urlLabel, SIGNAL(rightClickedUrl(const QString&)),
+                 this, SLOT(popupMenu(const QString&)) );
       } else {
         label = new QLabel( this );
         label->setText( (*addrIt).summary );
@@ -517,7 +536,7 @@ void SDSummaryWidget::updateView()
         mLayout->addWidget( label, counter, 4 );
         mLabels.append( label );
         if ( !(*addrIt).desc.isEmpty() ) {
-          QToolTip::add( label, (*addrIt).desc );
+          label->setToolTip( (*addrIt).desc );
         }
       }
 
@@ -528,9 +547,9 @@ void SDSummaryWidget::updateView()
         if ( (*addrIt).yearsOld <= 0 ) {
           label->setText( "" );
         } else {
-          label->setText( i18n( "one year", "%n years", (*addrIt).yearsOld  ) );
+          label->setText( i18np( "one year", "%1 years", (*addrIt).yearsOld ) );
         }
-        label->setAlignment( AlignLeft | AlignVCenter );
+        label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter );
         mLayout->addWidget( label, counter, 5 );
         mLabels.append( label );
       }
@@ -539,18 +558,20 @@ void SDSummaryWidget::updateView()
     }
   } else {
     label = new QLabel(
-        i18n( "No special dates within the next 1 day",
-              "No special dates pending within the next %n days",
-              mDaysAhead ), this, "nothing to see" );
-    label->setAlignment( AlignHCenter | AlignVCenter );
-    mLayout->addMultiCellWidget( label, 0, 0, 0, 4 );
+        i18np( "No special dates within the next 1 day",
+               "No special dates pending within the next %1 days",
+               mDaysAhead ), this );
+    label->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
+    mLayout->addWidget( label, 0, 2 );
     mLabels.append( label );
   }
 
-  for ( label = mLabels.first(); label; label = mLabels.next() )
-    label->show();
+  QList<QLabel*>::iterator lit;
+  for ( lit = mLabels.begin(); lit != mLabels.end(); ++lit ) {
+    (*lit)->show();
+  }
 
-  KGlobal::locale()->setDateFormat( savefmt );
+  setUpdatesEnabled( true );
 }
 
 void SDSummaryWidget::mailContact( const QString &uid )
@@ -558,46 +579,50 @@ void SDSummaryWidget::mailContact( const QString &uid )
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
   QString email = ab->findByUid( uid ).fullEmail();
 
-  kapp->invokeMailer( email, QString::null );
+  KToolInvocation::invokeMailer( email, QString() );
 }
 
 void SDSummaryWidget::viewContact( const QString &uid )
 {
-  if ( !mPlugin->isRunningStandalone() )
+  if ( !mPlugin->isRunningStandalone() ) {
     mPlugin->core()->selectPlugin( "kontact_kaddressbookplugin" );
-  else
+  } else {
     mPlugin->bringToForeground();
+  }
 
-  DCOPRef dcopCall( "kaddressbook", "KAddressBookIface" );
-  dcopCall.send( "showContactEditor(QString)", uid );
+  org::kde::KAddressbook::Core kaddressbook(
+    "org.kde.kaddressbook", "/KAddressBook", QDBusConnection::sessionBus() );
+  kaddressbook.showContactEditor( uid );
 }
 
 void SDSummaryWidget::popupMenu( const QString &uid )
 {
-  KPopupMenu popup( this );
-  popup.insertItem( KGlobal::iconLoader()->loadIcon( "kmail", KIcon::Small ),
-                    i18n( "Send &Mail" ), 0 );
-  popup.insertItem( KGlobal::iconLoader()->loadIcon( "kaddressbook", KIcon::Small ),
-                    i18n( "View &Contact" ), 1 );
+  KMenu popup( this );
+  QAction *sendMailAction = popup.addAction(
+    KIconLoader::global()->loadIcon( "internet-mail", KIconLoader::Small ),
+    i18n( "Send &Mail" ) );
+  QAction * viewContactAction = popup.addAction(
+    KIconLoader::global()->loadIcon( "office-address-book", KIconLoader::Small ),
+    i18n( "View &Contact" ) );
 
-  switch ( popup.exec( QCursor::pos() ) ) {
-    case 0:
-      mailContact( uid );
-      break;
-    case 1:
-      viewContact( uid );
-      break;
+  QAction *ret = popup.exec( QCursor::pos() );
+  if ( ret == sendMailAction ) {
+    mailContact( uid );
+  } else if ( ret == viewContactAction ) {
+    viewContact( uid );
   }
 }
 
-bool SDSummaryWidget::eventFilter( QObject *obj, QEvent* e )
+bool SDSummaryWidget::eventFilter( QObject *obj, QEvent *e )
 {
-  if ( obj->inherits( "KURLLabel" ) ) {
-    KURLLabel* label = static_cast<KURLLabel*>( obj );
-    if ( e->type() == QEvent::Enter )
-      emit message( i18n( "Mail to:\"%1\"" ).arg( label->text() ) );
-    if ( e->type() == QEvent::Leave )
-      emit message( QString::null );
+  if ( obj->inherits( "KUrlLabel" ) ) {
+    KUrlLabel* label = static_cast<KUrlLabel*>( obj );
+    if ( e->type() == QEvent::Enter ) {
+      emit message( i18n( "Mail to:\"%1\"", label->text() ) );
+    }
+    if ( e->type() == QEvent::Leave ) {
+      emit message( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
+    }
   }
 
   return Kontact::Summary::eventFilter( obj, e );
@@ -608,15 +633,18 @@ void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years )
   QDate currentDate;
   QDate eventDate;
 
-  if ( QDate::leapYear( date.year() ) && date.month() == 2 && date.day() == 29 ) {
+  if ( QDate::isLeapYear( date.year() ) && date.month() == 2 && date.day() == 29 ) {
     currentDate = QDate( date.year(), QDate::currentDate().month(), QDate::currentDate().day() );
-    if ( !QDate::leapYear( QDate::currentDate().year() ) )
+    if ( !QDate::isLeapYear( QDate::currentDate().year() ) ) {
       eventDate = QDate( date.year(), date.month(), 28 ); // celebrate one day earlier ;)
-    else
+    } else {
       eventDate = QDate( date.year(), date.month(), date.day() );
+    }
   } else {
-    currentDate = QDate( 0, QDate::currentDate().month(), QDate::currentDate().day() );
-    eventDate = QDate( 0, date.month(), date.day() );
+    currentDate = QDate( QDate::currentDate().year(),
+                         QDate::currentDate().month(),
+                         QDate::currentDate().day() );
+    eventDate = QDate( QDate::currentDate().year(), date.month(), date.day() );
   }
 
   int offset = currentDate.daysTo( eventDate );
@@ -629,6 +657,40 @@ void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years )
   }
 }
 
+KCal::ResourceCalendar *SDSummaryWidget::usingBirthdayResource()
+{
+  KCal::ResourceCalendar *resource = 0;
+
+  KCal::CalendarResourceManager *manager = mCalendar->resourceManager();
+  if ( !manager->isEmpty() ) {
+    KCal::CalendarResourceManager::Iterator it;
+    for ( it = manager->begin(); it != manager->end(); ++it ) {
+      if ( (*it)->type() == QLatin1String( "birthdays" ) ) {
+        resource = (*it);
+        break;
+      }
+    }
+  }
+  return resource;
+}
+
+bool SDSummaryWidget::check( KCal::ResourceCalendar *cal, const QDate &date,
+                             const QString &summary )
+{
+  if ( !cal ) {
+    return false;
+  }
+
+  KCal::Event::List events = cal->rawEventsForDate( date );
+  KCal::Event::List::ConstIterator it;
+  for ( it = events.begin(); it != events.end(); ++it ) {
+    if ( (*it)->summary() == summary ) {
+      return true;
+    }
+  }
+  return false;
+}
+
 QStringList SDSummaryWidget::configModules() const
 {
   return QStringList( "kcmsdsummary.desktop" );
