@@ -28,10 +28,11 @@
 #include <kdebug.h>
 #include <klocale.h>
 
-#include <qmap.h>
-#include <qobject.h>
-#include <qptrvector.h>
-#include <qstringlist.h>
+#include <QMap>
+#include <QObject>
+#include <QList>
+#include <QVector>
+#include <QStringList>
 
 const char* KMail_Protocol::kmailGroupName = "Account %1";
 const char* KMail_Protocol::kmailKeyType = "Type";
@@ -51,16 +52,22 @@ KMail_Protocol::~KMail_Protocol()
 {
 }
 
-const Protocol* KMail_Protocol::getProtocol( KConfigGroup* config ) const
+const Protocol* KMail_Protocol::getProtocol( AccountSettings* settings ) const
 {
-	KConfig kmailconfig( "kmailrc", true, false );
+	KConfig kmailconfig( "kmailrc", KConfig::NoGlobals );
 	int id;
-	QString type = getTypeAndConfig( config->readEntry( "kmailname" ), kmailconfig, id );
+	QString type;
+
+	QString grpname;
+	if( settings->readEntries().contains( "kmailname" ) )
+		type = getTypeAndConfig( settings->readEntries()[ "kmailname" ], kmailconfig, id, grpname );
+	else
+		type = getTypeAndConfig( "", kmailconfig, id,grpname );
 
 	if( type == "imap" )
 		return Protocols::getProto( "imap" );
-        if( type == "cachedimap" )
-                return Protocols::getProto( "imap" );
+	if( type == "cachedimap" )
+		return Protocols::getProto( "imap" );
 	if( type == "pop" )
 		return Protocols::getProto( "pop3" );
 	if( type == "local" )
@@ -69,102 +76,115 @@ const Protocol* KMail_Protocol::getProtocol( KConfigGroup* config ) const
 		return Protocols::getProto( "qmail" );
 
 	//Type not recognized, or does not exist in KOrn
-	kdWarning() << "KMail configuration not found" << endl;
+	kWarning() <<"KMail configuration not found";
 	return 0;
 }
 
-KMailDrop* KMail_Protocol::createMaildrop( KConfigGroup *config ) const
+KMailDrop* KMail_Protocol::createMaildrop( AccountSettings *settings ) const
 {
 	int id;
-	KConfig kmailconfig( "kmailrc", true, false );
-	QString type = getTypeAndConfig( config->readEntry( "kmailname" ), kmailconfig, id );
+	QString type;
+	
+	KConfig kmailconfig( "kmailrc", KConfig::NoGlobals );
+	QString grpname;
+	if( settings->readEntries().contains( "kmailname" ) )
+		type = getTypeAndConfig( settings->readEntries()[ "kmailname" ], kmailconfig, id, grpname );
+	else
+		type = getTypeAndConfig( "", kmailconfig, id, grpname );
 
 	if( type == "imap" || type == "cachedimap" || type == "pop" || type == "local" || type == "maildir" )
 		return new KKioDrop();
 	
-	kdWarning() << "KMail configuration not found" << endl;
+	kWarning() <<"KMail configuration not found";
 	return 0;
 }
 
-QMap< QString, QString > * KMail_Protocol::createConfig( KConfigGroup* config, const QString& ) const
+QMap< QString, QString > * KMail_Protocol::createConfig( AccountSettings* settings ) const
 {
 	QMap< QString, QString > *result = new QMap<QString, QString>;
 	int id;
-	KConfig kmailconfig( "kmailrc", true, false );
+	QString type;
+	
+	KConfig kmailconfig( "kmailrc", KConfig::NoGlobals );
+	QString grpname;
 	//First: find the account in the configuration and get the type and id out of it.
-	QString type = getTypeAndConfig( config->readEntry( "kmailname" ), kmailconfig, id );
+	if( settings->readEntries().contains( "kmailname" ) )
+		type = getTypeAndConfig( settings->readEntries()[ "kmailname" ], kmailconfig, id, grpname );
+	else
+		type = getTypeAndConfig( "", kmailconfig, id, grpname );
 	QString metadata;
 
+	KConfigGroup grp(&kmailconfig, grpname);
 	if( type == "imap" || type == "cachedimap" )
 	{
 		//Construct metadata
-		if( kmailconfig.hasKey( "auth" ) )
-			metadata += QString( "auth=%1," ).arg( kmailconfig.readEntry( "auth" ) );
-		if( !kmailconfig.hasKey( "use-tls" ) )
+		if( grp.hasKey( "auth" ) )
+			metadata += QString( "auth=%1," ).arg( grp.readEntry( "auth" ) );
+		if( !grp.hasKey( "use-tls" ) )
 			metadata += "tls=auto";
 		else
 		{
-			if( kmailconfig.readBoolEntry( "use-tls", false ) )
+			if( grp.readEntry( "use-tls", false ) )
 				metadata += "tls=on";
 			else
 				metadata += "tls=off";
 		}
 		//Add the fields into the mapping.
-		result->insert( "name", config->readEntry( "name", "" ) );
-		result->insert( "server", kmailconfig.readEntry( "host", "localhost" ) );
-		result->insert( "port", kmailconfig.readEntry( "port", "143" ) );
-		result->insert( "ssl", kmailconfig.readEntry( "use-ssl", "false" ) );
+		result->insert( "name", settings->accountName() );
+		result->insert( "server", grp.readEntry( "host", "localhost" ) );
+		result->insert( "port", grp.readEntry( "port", "143" ) );
+		result->insert( "ssl", grp.readEntry( "use-ssl", "false" ) );
 		result->insert( "metadata", metadata );
-		result->insert( "username", kmailconfig.readEntry( "login", "" ) );
+		result->insert( "username", grp.readEntry( "login", "" ) );
 		result->insert( "mailbox", "INBOX" ); //Didn't find a good way to get this out of the configuration yet.
-		result->insert( "password", readPassword( kmailconfig.readBoolEntry( "store-passwd", false ), kmailconfig, id ) );
-		result->insert( "savepassword", kmailconfig.readEntry( "store-passwd", "false" ) );
+		result->insert( "password", readPassword( grp.readEntry( "store-passwd", false ), kmailconfig, id ) );
+		result->insert( "savepassword", grp.readEntry( "store-passwd", "false" ) );
 	}
 	if( type == "pop" )
 	{
 		//Constructing metadata
-		if( kmailconfig.hasKey( "auth" ) )
-			metadata += QString( "auth=%1," ).arg( kmailconfig.readEntry( "auth" ) );
-		if( !kmailconfig.hasKey( "use-tls" ) )
+		if( grp.hasKey( "auth" ) )
+			metadata += QString( "auth=%1," ).arg( grp.readEntry( "auth" ) );
+		if( !grp.hasKey( "use-tls" ) )
 			metadata += "tls=auto";
 		else
 		{
-			if( kmailconfig.readBoolEntry( "use-tls", false ) )
+			if( grp.readEntry( "use-tls", false ) )
 				metadata += "tls=on";
 			else
 				metadata += "tls=off";
 		}
-		result->insert( "name", config->readEntry( "name", "" ) );
-		result->insert( "server", kmailconfig.readEntry( "host", "localhost" ) );
-		result->insert( "port", kmailconfig.readEntry( "port", "110" ) );
-		result->insert( "ssl", kmailconfig.readEntry( "use-ssl", "false" ) );
+		result->insert( "name", settings->accountName() );
+		result->insert( "server", grp.readEntry( "host", "localhost" ) );
+		result->insert( "port", grp.readEntry( "port", "110" ) );
+		result->insert( "ssl", grp.readEntry( "use-ssl", "false" ) );
 		result->insert( "metadata", metadata );
-		result->insert( "username", kmailconfig.readEntry( "login", "" ) );
+		result->insert( "username", grp.readEntry( "login", "" ) );
 		result->insert( "mailbox", "" );
-		result->insert( "password", readPassword( kmailconfig.readBoolEntry( "store-passwd", false ), kmailconfig, id ) );
-		result->insert( "savepassword", kmailconfig.readEntry( "store-password", "false" ) );
+		result->insert( "password", readPassword( grp.readEntry( "store-passwd", false ), kmailconfig, id ) );
+		result->insert( "savepassword", grp.readEntry( "store-password", "false" ) );
 	}
 	if( type == "local" ) //mbox
 	{
-		result->insert( "name", config->readEntry( "name", "" ) );
+		result->insert( "name", settings->accountName() );
 		result->insert( "server", "" );
 		result->insert( "port", "0" );
 		result->insert( "ssl", "false" );
 		result->insert( "metadata", "" );
 		result->insert( "username", "" );
-		result->insert( "mailbox", kmailconfig.readPathEntry( kmailKeyMBox, "" ) );
+		result->insert( "mailbox", grp.readPathEntry( kmailKeyMBox, "" ) );
 		result->insert( "password", "" );
 		result->insert( "savepassword", "false" );
 	}
 	if( type == "maildir" )
 	{
-		result->insert( "name", config->readEntry( "name", "" ) );
+		result->insert( "name", settings->accountName() );
 		result->insert( "server", "" );
 		result->insert( "port", "0" );
 		result->insert( "ssl", "false" );
 		result->insert( "metadata", "" );
 		result->insert( "username", "" );
-		result->insert( "mailbox", kmailconfig.readPathEntry( kmailKeyQMail, "" ) );
+		result->insert( "mailbox", grp.readPathEntry( kmailKeyQMail, "" ) );
 		result->insert( "password", "" );
 		result->insert( "savepassword", "false" );
 	}
@@ -177,26 +197,27 @@ void KMail_Protocol::configFillGroupBoxes( QStringList* lijst ) const
 	lijst->append( "KMail" );
 }
 
-void KMail_Protocol::configFields( QPtrVector< QWidget >* vector, const QObject*, QPtrList< AccountInput >* result ) const
+void KMail_Protocol::configFields( QVector< QWidget* >* vector, const QObject*, QList< AccountInput* >* result ) const
 {
 	QMap< QString, QString > accountList;
 	QString type;
 	QString name;
 	int nummer = kmailFirstGroup - 1;
 	
-	KConfig kmailconfig( "kmailrc", true, false );
+	KConfig kmailconfig( "kmailrc", KConfig::NoGlobals );
 	while( kmailconfig.hasGroup( QString( kmailGroupName ).arg( ++nummer ) ) )
 	{
-		kmailconfig.setGroup( QString( kmailGroupName ).arg( nummer ) );
-		type = kmailconfig.readEntry( kmailKeyType, QString::null );
-		name = kmailconfig.readEntry( kmailKeyName, QString::null );
+		
+		KConfigGroup group = kmailconfig.group( QString( kmailGroupName ).arg( nummer ) );
+		type = group.readEntry( kmailKeyType, QString() );
+		name = group.readEntry( kmailKeyName, QString() );
 		if( type == "imap" || type == "cachedimap" || type == "pop" || type == "local" )
 		{
 			accountList.insert( name, name );
 		}
 	}
 
-	result->append( new ComboInput( (QWidget*)vector->at( 0 ), i18n( "KMail name" ), accountList, *accountList.begin(), "kmailname" ) );
+	result->append( new ComboInput( vector->at( 0 ), i18n( "KMail name" ), accountList, *accountList.begin(), "kmailname" ) );
 }
 
 void KMail_Protocol::readEntries( QMap< QString, QString >* ) const
@@ -217,7 +238,7 @@ QString KMail_Protocol::readPassword( bool store, const KConfigBase& config, int
 	return KOrnPassword::readKMailPassword( id, config );
 }
 
-QString KMail_Protocol::getTypeAndConfig( const QString& kmailname, KConfig &kmailconfig, int &id ) const
+QString KMail_Protocol::getTypeAndConfig( const QString& kmailname, KConfig &kmailconfig, int &id, QString& groupname ) const
 {
 	int nummer = kmailFirstGroup - 1;
 	bool found = false;
@@ -226,10 +247,11 @@ QString KMail_Protocol::getTypeAndConfig( const QString& kmailname, KConfig &kma
 	
 	while( kmailconfig.hasGroup( QString( kmailGroupName ).arg( ++nummer ) ) )
 	{
-		kmailconfig.setGroup( QString( kmailGroupName ).arg( nummer ) );
-		if( kmailconfig.readEntry( kmailKeyName, QString::null ) == kmailname )
+		KConfigGroup group = kmailconfig.group( QString( kmailGroupName ).arg( nummer ) );
+		if( group.readEntry( kmailKeyName, QString() ) == kmailname )
 		{
-			id = kmailconfig.readNumEntry( kmailKeyId, 0 );	
+			id = group.readEntry( kmailKeyId, 0 );
+			groupname = group.name();
 			found = true;
 			break;
 		}
@@ -237,10 +259,10 @@ QString KMail_Protocol::getTypeAndConfig( const QString& kmailname, KConfig &kma
 	if( !found )
 	{
 		nummer = -1;
-		return QString::null;
+		return QString();
 	}
 
-	//The correct group is found, and kmailconfig.setGroup() is already called for the right group.
-	return kmailconfig.readEntry( kmailKeyType, QString::null );
+	//The correct group is found
+	return kmailconfig.group(groupname).readEntry( kmailKeyType, QString() );
 }
 
