@@ -40,25 +40,17 @@
 #include <qdir.h>
 
 #include <kconfig.h>
-#include <kmdcodec.h>
+#include <kcodecs.h>
 
 #include <pilotLocalDatabase.h>
 #include <pilotSerialDatabase.h>
 
-#include "doc-factory.h"
 #include "doc-conflictdialog.h"
 #include "DOC-converter.h"
 #include "pilotDOCHead.h"
 #include "docconduitSettings.h"
 
 
-// Something to allow us to check what revision
-// the modules are that make up a binary distribution.
-extern "C"
-{
-unsigned long version_conduit_doc = Pilot::PLUGIN_API;
-}
-
 QString dirToString(eSyncDirectionEnum dir) {
 	switch(dir) {
 //		case eSyncAll: return "eSyncAll";
@@ -78,7 +70,7 @@ QString dirToString(eSyncDirectionEnum dir) {
 
 
 DOCConduit::DOCConduit(KPilotLink * o,
-	const char *n, const QStringList & a):ConduitAction(o, n, a)
+	const QVariantList & a):ConduitAction(o, a)
 {
 	FUNCTIONSETUP;
 	fConduitName=i18n("DOC");
@@ -95,11 +87,15 @@ DOCConduit::~DOCConduit()
 bool DOCConduit::isCorrectDBTypeCreator(DBInfo dbinfo) {
 	return dbinfo.type == dbtype() && dbinfo.creator == dbcreator();
 }
+
+static const char *dbDOCtype = "TEXt";
+static const char *dbDOCcreator = "REAd";
+
 const unsigned long DOCConduit::dbtype() {
-	return get_long(DOCConduitFactory::dbDOCtype);
+	return get_long(dbDOCtype);
 }
 const unsigned long DOCConduit::dbcreator() {
-	return get_long(DOCConduitFactory::dbDOCcreator);
+	return get_long(dbDOCcreator);
 }
 
 
@@ -128,19 +124,6 @@ void DOCConduit::readConfig()
 	}
 
 	eSyncDirection = (enum eSyncDirectionEnum)(DOCConduitSettings::syncDirection() );
-
-#ifdef DEBUG
-	DEBUGCONDUIT << fname
-		<< ": Settings "
-		<< " tXTDirectory=" << DOCConduitSettings::tXTDirectory()
-		<< " pDBDirectory=" << DOCConduitSettings::pDBDirectory()
-		<< " keepPDBLocally=" << DOCConduitSettings::keepPDBsLocally()
-		<< " eConflictResolution=" << eConflictResolution
-		<< " tXTBookmarks=" << fTXTBookmarks
-		<< " pDBBookmarks=" << DOCConduitSettings::bookmarksToPC()
-		<< " compress=" << DOCConduitSettings::compress()
-		<< " eSyncDirection=" << eSyncDirection << endl;
-#endif
 }
 
 
@@ -151,22 +134,22 @@ bool DOCConduit::pcTextChanged(QString txtfn)
 	// How do I find out if a text file has changed shince we last synced it??
 	// Use KMD5 for now. If I realize it is too slow, then I have to go back to comparing modification times
 	// if there is no config setting yet, assume the file has been changed. the md5 sum will be written to the config file after the sync.
-	QString oldDigest=DOCConduitSettings::self()->config()->readEntry(txtfn);
+	QString oldDigest=DOCConduitSettings::self()->config()->readEntry(txtfn,QString());
 	if (oldDigest.length()<=0)
 	{
 		return true;
 	}
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Old digest is "<<oldDigest<<endl;
+	DEBUGKPILOT<<"Old digest is"<<oldDigest;
 #endif
 
 	KMD5 docmd5;
 	QFile txtfile(txtfn);
-	if (txtfile.open(IO_ReadOnly)){
+	if (txtfile.open(QIODevice::ReadOnly)){
 		docmd5.update(txtfile);
 		QString thisDigest(docmd5.hexDigest() /* .data() */);
 #ifdef DEBUG
-		DEBUGCONDUIT<<"New digest is "<<thisDigest<<endl;
+		DEBUGKPILOT<<"New digest is"<<thisDigest;
 #endif
 		return (thisDigest.length()<=0) || (thisDigest!=oldDigest);
 	} else {
@@ -195,7 +178,7 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	int modRecInd=-1;
 	PilotRecord*modRec=docdb->readNextModifiedRec(&modRecInd);
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Index of first changed record: "<<modRecInd<<endl;
+	DEBUGKPILOT<<"Index of first changed record:"<<modRecInd;
 #endif
 
 	KPILOT_DELETE(modRec);
@@ -204,7 +187,7 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	if (modRecInd==0) {
 		modRec=docdb->readNextModifiedRec(&modRecInd);
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Reread Index of first changed records: "<<modRecInd<<endl;
+		DEBUGKPILOT<<"Reread Index of first changed records:"<<modRecInd;
 #endif
 		KPILOT_DELETE(modRec);
 	}
@@ -212,16 +195,9 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	// The record index starts with 0, so only a negative number means
 	// no modified record was found
 	if (modRecInd >= 0) {
-#ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has changed, condition="<<
-			((!DOCConduitSettings::ignoreBmkChanges()) || (modRecInd <= storyRecs))<<endl;
-#endif
 		if ((!DOCConduitSettings::ignoreBmkChanges()) || (modRecInd <= storyRecs))
 			return true;
 	} else {
-#ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has NOT changed!"<<endl;
-#endif
 		return false;
 	}
 	return false;
@@ -238,7 +214,7 @@ QString DOCConduit::constructPDBFileName(QString name) {
 	QString fn;
 	QDir dr(DOCConduitSettings::pDBDirectory());
 	QFileInfo pth(dr, name);
-	if (!name.isEmpty()) fn=pth.absFilePath()+CSL1(".pdb");
+	if (!name.isEmpty()) fn=pth.absoluteFilePath()+CSL1(".pdb");
 	return fn;
 }
 QString DOCConduit::constructTXTFileName(QString name) {
@@ -246,7 +222,7 @@ QString DOCConduit::constructTXTFileName(QString name) {
 	QString fn;
 	QDir dr( DOCConduitSettings::tXTDirectory() );
 	QFileInfo pth(dr, name);
-	if (!name.isEmpty()) fn=pth.absFilePath()+CSL1(".txt");
+	if (!name.isEmpty()) fn=pth.absoluteFilePath()+CSL1(".txt");
 	return fn;
 }
 
@@ -285,7 +261,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 	if (sinfo.direction==eSyncDelete) {
 		if (!sinfo.txtfilename.isEmpty()) {
 			if (!QFile::remove(sinfo.txtfilename)) {
-				kdWarning()<<"Unable to delete the text file "<<sinfo.txtfilename<<" on the PC"<<endl;
+				WARNINGKPILOT <<"Unable to delete the text file" << sinfo.txtfilename <<" on the PC";
 			}
 			QString bmkfilename = sinfo.txtfilename;
 			if (bmkfilename.endsWith(CSL1(".txt"))){
@@ -294,7 +270,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 			bmkfilename+=CSL1(PDBBMK_SUFFIX);
 			if (!QFile::remove(bmkfilename)) {
 #ifdef DEBUG
-				DEBUGCONDUIT<<"Could not remove bookmarks file "<<bmkfilename<<" for database "<<sinfo.handheldDB<<endl;
+				DEBUGKPILOT<<"Could not remove bookmarks file"<<bmkfilename<<" for database"<<sinfo.handheldDB;
 #endif
 			}
 		}
@@ -303,7 +279,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 				QString::fromLatin1(sinfo.dbinfo.name), false);
 			if (database) {
 				if ( database->deleteDatabase() !=0 ) {
-					kdWarning()<<"Unable to delete database "<<sinfo.dbinfo.name<<" on the PC"<<endl;
+					WARNINGKPILOT <<"Unable to delete database" << sinfo.dbinfo.name <<" on the PC";
 				}
 				KPILOT_DELETE(database);
 			}
@@ -311,7 +287,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 		if (!DOCConduitSettings::localSync()) {
 			PilotDatabase *database=deviceLink()->database( sinfo.dbinfo.name );
 			if ( database->deleteDatabase() !=0 ) {
-					kdWarning()<<"Unable to delete database "<<sinfo.dbinfo.name<<" from the handheld"<<endl;
+					WARNINGKPILOT <<"Unable to delete database" << sinfo.dbinfo.name <<" from the handheld";
 			}
 			KPILOT_DELETE(database);
 		}
@@ -324,11 +300,11 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 
 	if (database && ( !database->isOpen() ) ) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Database "<<sinfo.dbinfo.name<<" does not yet exist. Creating it:"<<endl;
+		DEBUGKPILOT<<"Database"<<sinfo.dbinfo.name<<" does not yet exist. Creating it:";
 #endif
 		if (!database->createDatabase(dbcreator(), dbtype()) ) {
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Failed"<<endl;
+			DEBUGKPILOT<<"Failed";
 			emit logMessage(i18n("Database created."));
 #endif
 		}
@@ -361,35 +337,35 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 		{
 			KMD5 docmd5;
 			QFile txtfile(docconverter.txtFilename());
-			if (txtfile.open(IO_ReadOnly)) {
+			if (txtfile.open(QIODevice::ReadOnly)) {
 				docmd5.update(txtfile);
 				QString thisDigest(docmd5.hexDigest() /* .data() */);
 				DOCConduitSettings::self()->config()->writeEntry(docconverter.txtFilename(), thisDigest);
 				DOCConduitSettings::self()->config()->sync();
 #ifdef DEBUG
-				DEBUGCONDUIT<<"MD5 Checksum of the text "<<sinfo.txtfilename<<" is "<<thisDigest<<endl;
+				DEBUGKPILOT<<"MD5 Checksum of the text"<<sinfo.txtfilename<<" is"<<thisDigest;
 #endif
 			} else {
 #ifdef DEBUG
-				DEBUGCONDUIT<<"couldn't open file "<<docconverter.txtFilename()<<" for reading!!!"<<endl;
+				DEBUGKPILOT<<"couldn't open file"<<docconverter.txtFilename()<<" for reading!!!";
 #endif
 			}
 		}
 
 		if (!postSyncAction(database, sinfo, res))
-			emit logError(i18n("Unable to install the locally created PalmDOC %1 to the handheld.")
-				.arg(QString::fromLatin1(sinfo.dbinfo.name)));
+			emit logError(i18n("Unable to install the locally created PalmDOC %1 to the handheld.",
+				QString::fromLatin1(sinfo.dbinfo.name)));
 		if (!res)
-			emit logError(i18n("Conversion of PalmDOC \"%1\" failed.")
-				.arg(QString::fromLatin1(sinfo.dbinfo.name)));
+			emit logError(i18n("Conversion of PalmDOC \"%1\" failed.",
+				QString::fromLatin1(sinfo.dbinfo.name)));
 //		disconnect(&docconverter, SIGNAL(logError(const QString &)), SIGNAL(logError(const QString &)));
 //		disconnect(&docconverter, SIGNAL(logMessage(const QString &)), SIGNAL(logMessage(const QString &)));
 //		KPILOT_DELETE(database);
 	}
 	else
 	{
-		emit logError(i18n("Unable to open or create the database %1.")
-			.arg(QString::fromLatin1(sinfo.dbinfo.name)));
+		emit logError(i18n("Unable to open or create the database %1.",
+			QString::fromLatin1(sinfo.dbinfo.name)));
 	}
 	return res;
 }
@@ -409,7 +385,7 @@ void DOCConduit::syncNextDB() {
 	}
 	dbnr=dbinfo.index+1;
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Next Palm database to sync: "<<dbinfo.name<<", Index="<<dbinfo.index<<endl;
+	DEBUGKPILOT<<"Next Palm database to sync:"<<dbinfo.name<<", Index="<<dbinfo.index;
 #endif
 
 	// if creator and/or type don't match, go to next db
@@ -464,7 +440,7 @@ void DOCConduit::syncNextTXT()
 
 	QDir dr( DOCConduitSettings::tXTDirectory() );
 	QFileInfo fl(dr, fn );
-	QString txtfilename=fl.absFilePath();
+	QString txtfilename=fl.absoluteFilePath();
 	QString pdbfilename;
 	++dociterator;
 
@@ -472,9 +448,9 @@ void DOCConduit::syncNextTXT()
 	// Include all "extensions" except the last. This allows full stops inside the database name (e.g. abbreviations)
 	// first fill everything with 0, so we won't have a buffer overflow.
 	memset(&dbinfo.name[0], 0, 33);
-	strncpy(&dbinfo.name[0], fl.baseName(TRUE).latin1(), 30);
+	strncpy(&dbinfo.name[0], fl.baseName(true).latin1(), 30);
 
-	bool alreadySynced=fDBNames.contains(fl.baseName(TRUE));
+	bool alreadySynced=fDBNames.contains(fl.baseName(true));
 	if (!alreadySynced) {
 		docSyncInfo syncInfo(QString::fromLatin1(dbinfo.name),
 			txtfilename, pdbfilename, eSyncNone);
@@ -484,7 +460,7 @@ void DOCConduit::syncNextTXT()
 		fDBNames.append(QString::fromLatin1(dbinfo.name));
 	} else {
 #ifdef DEBUG
-		DEBUGCONDUIT<<txtfilename<<" has already been synced, skipping it."<<endl;
+		DEBUGKPILOT<<txtfilename<<" has already been synced, skipping it.";
 #endif
 	}
 
@@ -523,14 +499,14 @@ void DOCConduit::checkPDBFiles() {
 
 	QDir dr(DOCConduitSettings::pDBDirectory());
 	QFileInfo fl(dr, fn );
-	QString pdbfilename=fl.absFilePath();
+	QString pdbfilename=fl.absoluteFilePath();
 	++dociterator;
 
 	//  Get the doc title and check if it has already been synced (in the synced docs list of in fDBNames to be synced)
 	// If the doc title doesn't appear in either list, install it to the Handheld, and add it to the list of dbs to be synced.
-	QString dbname=fl.baseName(TRUE).left(30);
+	QString dbname=fl.baseName(true).left(30);
 	if (!fDBNames.contains(dbname) && !fDBListSynced.contains(dbname)) {
-		if (fHandle->installFiles(pdbfilename, false)) {
+		if (fHandle->installFiles( QStringList(pdbfilename), false)) {
 			DBInfo dbinfo;
 			// Include all "extensions" except the last. This allows full stops inside the database name (e.g. abbreviations)
 			// first fill everything with 0, so we won't have a buffer overflow.
@@ -544,7 +520,7 @@ void DOCConduit::checkPDBFiles() {
 			fDBNames.append(dbname);
 		} else {
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Could not install database "<<dbname<<" ("<<pdbfilename<<") to the handheld"<<endl;
+			DEBUGKPILOT<<"Could not install database"<<dbname<<" ("<<pdbfilename<<") to the handheld";
 #endif
 		}
 	}
@@ -588,25 +564,25 @@ void DOCConduit::resolve() {
 		// the remaining conflicts will be resolved in the resolution dialog
 		if ((*fSyncInfoListIterator).direction==eSyncConflict){
 #ifdef DEBUG
-			DEBUGCONDUIT<<"We have a conflict for "<<(*fSyncInfoListIterator).handheldDB<<", default="<<eConflictResolution<<endl;
+			DEBUGKPILOT<<"We have a conflict for"<<(*fSyncInfoListIterator).handheldDB<<", default="<<eConflictResolution;
 #endif
 			switch (eConflictResolution)
 			{
 				case eSyncPDAToPC:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"PDA overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"PDA overrides for database"<<(*fSyncInfoListIterator).handheldDB;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncPDAToPC;
 					break;
 				case eSyncPCToPDA:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"PC overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"PC overrides for database"<<(*fSyncInfoListIterator).handheldDB;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncPCToPDA;
 					break;
 				case eSyncNone:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"No sync for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"No sync for database"<<(*fSyncInfoListIterator).handheldDB;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncNone;
 					break;
@@ -614,7 +590,7 @@ void DOCConduit::resolve() {
 				case eSyncConflict:
 				default:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"Conflict remains due to default resolution setting for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"Conflict remains due to default resolution setting for database"<<(*fSyncInfoListIterator).handheldDB;
 #endif
 					break;
 			}
@@ -657,24 +633,20 @@ void DOCConduit::syncDatabases() {
 
 	switch (sinfo.direction) {
 		case eSyncConflict:
-#ifdef DEBUG
-			DEBUGCONDUIT<<"Entry "<<sinfo.handheldDB<<"( txtfilename: "<<sinfo.txtfilename<<
-				", pdbfilename: "<<sinfo.pdbfilename<<") had sync direction eSyncConflict!!!"<<endl;
-#endif
 			break;
 		case eSyncDelete:
 		case eSyncPDAToPC:
 		case eSyncPCToPDA:
-			emit logMessage(i18n("Synchronizing text \"%1\"").arg(sinfo.handheldDB));
+			emit logMessage(i18n("Synchronizing text \"%1\"",sinfo.handheldDB));
 			if (!doSync(sinfo)) {
 				// The sync could not be done, so inform the user (the error message should probably issued inside doSync)
-#ifdef DEBUG
-				DEBUGCONDUIT<<"There was some error syncing the text \""<<sinfo.handheldDB<<"\" with the file "<<sinfo.txtfilename<<endl;
-#endif
+				DEBUGKPILOT << "There was some error syncing ["
+					<< sinfo.handheldDB
+					<< "] with file ["
+					<< sinfo.txtfilename << ']';
 			}
 			break;
 		case eSyncNone:
-//		case eSyncAll:
 			break;
 	}
 	if (sinfo.direction != eSyncDelete) fDBNames.append(sinfo.handheldDB);
@@ -705,7 +677,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	if (!fDBListSynced.contains(sinfo.handheldDB)) {
 		// the database wasn't included on last sync, so it has to be new.
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Database "<<sinfo.dbinfo.name<<" wasn't included in the previous sync!"<<endl;
+		DEBUGKPILOT<<"Database"<<sinfo.dbinfo.name<<" wasn't included in the previous sync!";
 #endif
 
 		/* Resolution Table:
@@ -741,11 +713,6 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 					if (sinfo.fPalmStatus==eStatNew) sinfo.direction=eSyncPDAToPC;
 					else {
 						sinfo.direction=eSyncNone;
-#ifdef DEBUG
-						DEBUGCONDUIT<<"I'm supposed to find a sync direction, but the "<<
-						" text "<<sinfo.dbinfo.name<<" doesn't exist on either "<<
-						" the handheld or the PC"<<endl;
-#endif
 					}
 				}
 				break;
@@ -760,24 +727,24 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	else if(pcTextChanged(sinfo.txtfilename)) {
 		sinfo.fPCStatus=eStatChanged;
 #ifdef DEBUG
-		DEBUGCONDUIT<<"PC side has changed!"<<endl;
+		DEBUGKPILOT<<"PC side has changed!";
 #endif
 		// TODO: Check for changed bookmarks on the PC side
 #ifdef DEBUG
 	} else {
-		DEBUGCONDUIT<<"PC side has NOT changed!"<<endl;
+		DEBUGKPILOT<<"PC side has NOT changed!";
 #endif
 	}
 
 	if (!docdb || !docdb->isOpen()) sinfo.fPalmStatus=eStatDeleted;
 	else if (hhTextChanged(docdb)) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has changed!"<<endl;
+		DEBUGKPILOT<<"Handheld side has changed!";
 #endif
 		sinfo.fPalmStatus=eStatChanged;
 #ifdef DEBUG
 	} else {
-		DEBUGCONDUIT<<"Handheld side has NOT changed!"<<endl;
+		DEBUGKPILOT<<"Handheld side has NOT changed!";
 #endif
 	}
 	KPILOT_DELETE(docdb);
@@ -802,7 +769,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 
 	if (sinfo.fPCStatus == eStatNone && sinfo.fPalmStatus==eStatNone) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Nothing has changed, not need for a sync."<<endl;
+		DEBUGKPILOT<<"Nothing has changed, not need for a sync.";
 #endif
 		sinfo.direction=eSyncNone;
 		return false;
@@ -833,10 +800,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	if ( ((sinfo.fPCStatus==eStatDeleted) && (sinfo.fPalmStatus!=eStatChanged)) ||
 	     ((sinfo.fPalmStatus==eStatDeleted) && (sinfo.fPCStatus!=eStatChanged)) )
 	{
-#ifdef DEBUG
-		DEBUGCONDUIT<<"DB was deleted on one side and not changed on "
-			"the other -> Delete it."<<endl;
-#endif
+		DEBUGKPILOT << "DB was deleted on one side and not changed on the other -> Delete it.";
 		sinfo.direction=eSyncDelete;
 		return true;
 	}
@@ -844,9 +808,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	// eStatDeleted (and both not changed) have already been treated, for all
 	// other values in combination with eStatNone, just copy the texts.
 	if (sinfo.fPCStatus==eStatNone) {
-#ifdef DEBUG
-		DEBUGCONDUIT<<"PC side has changed!"<<endl;
-#endif
+		DEBUGKPILOT << "PC side has changed!";
 		sinfo.direction=eSyncPDAToPC;
 		return true;
 	}
@@ -891,16 +853,18 @@ PilotDatabase *DOCConduit::preSyncAction(docSyncInfo &sinfo) const
 				{
 					dir.mkdir(dir.absPath());
 				}
-#ifdef DEBUG
-				DEBUGCONDUIT<<"Need to fetch database "<<dbinfo.name<<
-					" to the directory "<<dir.absPath()<<endl;
-#endif
+				DEBUGKPILOT << "Need to fetch database "
+					<< dbinfo.name
+					<< " to the directory ["
+					<< dir.absPath() << ']';
 				dbinfo.flags &= ~dlpDBFlagOpen;
 
 				if (!fHandle->retrieveDatabase(sinfo.pdbfilename, &dbinfo) )
 				{
-					kdWarning(0)<<"Unable to retrieve database "<<dbinfo.name<<
-						" from the handheld into "<<sinfo.pdbfilename<<"."<<endl;
+					WARNINGKPILOT << "Unable to retrieve database"
+						<< dbinfo.name
+						<< " from the handheld into [" 
+						<< sinfo.pdbfilename << ']';
 					return 0L;
 				}
 			}
@@ -943,28 +907,18 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 	{
 	case eSyncPDAToPC:
 		// also reset the sync flags on the handheld
-#ifdef DEBUG
-		DEBUGCONDUIT<<"Resetting sync flags for database "
-			<<sinfo.dbinfo.name<<endl;
-#endif
+		DEBUGKPILOT << "Resetting sync flags for database ["
+			<< sinfo.dbinfo.name << ']';
 		if (DOCConduitSettings::keepPDBsLocally() && !DOCConduitSettings::localSync())
 		{
 			PilotDatabase*db=deviceLink()->database(
 				QString::fromLatin1(sinfo.dbinfo.name));
-#ifdef DEBUG
-			DEBUGCONDUIT<<"Middle 1 Resetting sync flags for database "
-				<<sinfo.dbinfo.name<<endl;
-#endif
 			if (db)
 			{
 				db->resetSyncFlags();
 				KPILOT_DELETE(db);
 			}
 		}
-#ifdef DEBUG
-		DEBUGCONDUIT<<"End Resetting sync flags for database "
-			<<sinfo.dbinfo.name<<endl;
-#endif
 		break;
 	case eSyncPCToPDA:
 		if (DOCConduitSettings::keepPDBsLocally() && !DOCConduitSettings::localSync() && res)
@@ -973,20 +927,18 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 			PilotLocalDatabase*localdb=dynamic_cast<PilotLocalDatabase*>(database);
 			if (localdb)
 			{
-#ifdef DEBUG
-				DEBUGCONDUIT<<"Installing file "<<localdb->dbPathName()<<" ("
-					<<sinfo.handheldDB<<") to the handheld"<<endl;
-#endif
+				DEBUGKPILOT << "Installing file ["
+					<< localdb->dbPathName() << "] DB ["
+					<< sinfo.handheldDB
+					<< "] to the handheld.";
 				QString dbpathname=localdb->dbPathName();
 				// This deletes localdb as well, which is just a cast from database
 				KPILOT_DELETE(database);
-				if (!fHandle->installFiles(dbpathname, false))
+				if (!fHandle->installFiles( QStringList(dbpathname), false))
 				{
 					rs = false;
-#ifdef DEBUG
-					DEBUGCONDUIT<<"Could not install the database "<<dbpathname<<" ("
-						<<sinfo.handheldDB<<")"<<endl;
-#endif
+					DEBUGKPILOT << "Could not install ["
+						<< dbpathname << ']';
 				}
 			}
 		}
@@ -995,12 +947,12 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 	}
 
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Vor KPILOT_DELETE(database)"<<endl;
+	DEBUGKPILOT<<"Vor KPILOT_DELETE(database)";
 #endif
 
 	KPILOT_DELETE(database);
 #ifdef DEBUG
-	DEBUGCONDUIT<<"End postSyncAction"<<endl;
+	DEBUGKPILOT<<"End postSyncAction";
 #endif
 	return rs;
 }
