@@ -6,7 +6,7 @@
 ** Copyright (C) 1999,2000 Michael Kropfberger
 **
 ** This file is part of the popmail conduit, a conduit for KPilot that
-** synchronises the Pilot's email application with the outside world,
+** synchronizes the Pilot's email application with the outside world,
 ** which currently means:
 **	-- sendmail or SMTP for outgoing mail
 **	-- POP or mbox for incoming mail
@@ -36,17 +36,14 @@
 
 #include "plugin.h"
 
-class KSocket;
 
 class PilotRecord;
-class PilotDatabase;
 
 class PopMailConduit : public ConduitAction
 {
 public:
-	PopMailConduit(KPilotDeviceLink *d,
-		const char *n=0L,
-		const QStringList &l=QStringList());
+	PopMailConduit(KPilotLink *d,
+		const QVariantList &l=QVariantList());
 	virtual ~PopMailConduit();
 
 protected:
