@@ -1,6 +1,6 @@
 /* KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 **
 ** This is a C++ wrapper for the todo-list entry structures.
@@ -26,20 +26,15 @@
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
-#include "options.h"
-
+#include "pilotTodoEntry.h"
 
 #include <stdlib.h>
 
-#include <qdatetime.h>
-#include <qnamespace.h>
+#include <QtCore/QDateTime>
 
 #include <kglobal.h>
-#include <kdebug.h>
-
-
-#include "pilotTodoEntry.h"
 
+#include "options.h"
 
 PilotTodoEntry::PilotTodoEntry() :
 	fDescriptionSize(0),
@@ -115,7 +110,7 @@ PilotTodoEntry & PilotTodoEntry::operator = (const PilotTodoEntry & e)
 	return *this;
 }
 
-QString PilotTodoEntry::getTextRepresentation(Qt::TextFormat richText)
+QString PilotTodoEntry::getTextRepresentation(Qt::TextFormat richText) const
 {
 	QString text, tmp;
 	QString par = (richText==Qt::RichText) ?CSL1("<p>"): QString();
@@ -130,9 +125,13 @@ QString PilotTodoEntry::getTextRepresentation(Qt::TextFormat richText)
 
 	text += par;
 	if (getComplete())
-		text += i18n("Completed");
+	{
+		text += i18nc("This todo entry is completed.","Completed");
+	}
 	else
+	{
 		text += i18n("Not completed");
+	}
 	text += ps;
 
 	if (!getIndefinite())
@@ -140,7 +139,7 @@ QString PilotTodoEntry::getTextRepresentation(Qt::TextFormat richText)
 		QDate dt(readTm(getDueDate()).date());
 		QString dueDate(dt.toString(Qt::LocalDate));
 		text+=par;
-		text+=i18n("Due date: %1").arg(dueDate);
+		text+=i18n("Due date: %1",dueDate);
 		text+=ps;
 	}
 
@@ -148,14 +147,14 @@ QString PilotTodoEntry::getTextRepresentation(Qt::TextFormat richText)
 	text+=ps;
 
 	text+=par;
-	text+=i18n("Priority: %1").arg(getPriority());
+	text+=i18n("Priority: %1",getPriority());
 	text+=ps;
 
 	if (!getNote().isEmpty())
 	{
 		text += (richText==Qt::RichText) ?CSL1("<hr/>"):CSL1("-------------------------\n");
 		text+=par;
-		text+= (richText==Qt::RichText) ?i18n("<b><em>Note:</em></b><br>"):i18n("Note:\n");
+		text+= (richText==Qt::RichText) ?i18n("<b><em>Note:</em></b><br/>"):i18n("Note:\n");
 		text+=rtExpand(getNote(), richText);
 		text+=ps;
 	}
@@ -179,7 +178,7 @@ PilotRecord *PilotTodoEntry::pack() const
 
 void PilotTodoEntry::setDescription(const QString &desc)
 {
-	if (desc.length() < fDescriptionSize)
+	if (desc.length() < (int)fDescriptionSize)
 	{
 		Pilot::toPilot(desc, fTodoInfo.description, fDescriptionSize);
 	}
@@ -208,8 +207,7 @@ void PilotTodoEntry::setDescriptionP(const char *desc, int len)
 		}
 		else
 		{
-			WARNINGKPILOT << "malloc() failed, description not set"
-				<< endl;
+			WARNINGKPILOT << "malloc() failed, description not set";
 		}
 	}
 	else
@@ -225,7 +223,7 @@ QString PilotTodoEntry::getDescription() const
 
 void PilotTodoEntry::setNote(const QString &note)
 {
-	if (note.length() < fNoteSize)
+	if (note.length() < (int)fNoteSize)
 	{
 		Pilot::toPilot(note, fTodoInfo.note, fNoteSize);
 	}
@@ -254,7 +252,7 @@ void PilotTodoEntry::setNoteP(const char *note, int len)
 		}
 		else
 		{
-			WARNINGKPILOT << "malloc() failed, note not set" << endl;
+			WARNINGKPILOT << "malloc() failed, note not set";
 		}
 	}
 	else
